package CyberCalendar::Admin;
###################################################################
# CyberCalendar v1.8.2
#
# Administration Module
# Copyright 1999, 2000, 2001 Shawn Ewald <shawn@cyberweavers.com>
#
###################################################################
# License:                                                        #
# ----------------------------------------------------------------#
# This program is free software; you can redistribute it and/or   #
# modify it under the terms of the GNU General Public License     #
# as published by the Free Software Foundation; either version 2  #
# of the License, or (at your option) any later version.          #
#                                                                 #
# This program is distributed in the hope that it will be useful, #
# but WITHOUT ANY WARRANTY; without even the implied warranty of  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
###################################################################
# For the full text of the GNU General Public License, go to:     #
# http://www.gnu.org/copyleft/gpl.html                            #
###################################################################
# IMPORT MODULES
use vars qw($config $user $http_in $db $app $today $today_fmt1 $today_fmt2 $now);
use CyberCalendar::Application;
use CyberCalendar::Auth;
use strict;

sub new {
   my $self = shift || 0;
   my $hashref = {};

   $app = CyberCalendar::Application->new();
   $app->init();

   # get today's date and format it
   $today = $CyberCalendar::Calendar::todaysdate;
   $today_fmt1 = "$today->[1]\/$today->[2]\/$today->[0]";
   $today_fmt2 = "$today->[0]\-$today->[1]\-$today->[2]";
   $now = CyberCalendar::Calendar::timenow();

   $http_in = $CyberCalendar::Application::http_in;
   $config = $CyberCalendar::Application::config;

   # Get database connection
   $db = $CyberCalendar::Application::db;

   if ($config->{session_type} != 0) {
      my $auth = CyberCalendar::Auth->new();
      $user = $auth->authenticate($config, $http_in, $db);
      $user->{session} = $http_in->{session};
   }
   if ($config->{public_event_submit} == 1
       and $config->{public_direct_submit} == 0) {
      $user->{sub_edit} = qq(&\#149; <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Submissions&session=$user->{session}">Manage User Submissions</a><p>);
   } # if
   if ($user->{full_ctrl} == 1
      || $user->{accesslevel} == 1) {
      $user->{cal_conf} = qq(&\#149; <a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">Calendar Configuration</a><p>);
   } # if
   bless $hashref, $self;
} # endsub new

##
## Spits out the calendar admin page,
## there are no templates for the admin
## interface.
##
sub show_page {
   print <<"ADMINPAGE";
<html>
<head>
<!-- START HEAD -->
<title>CyberCalendar</title>
<!-- START POPUP WINDOW SCRIPT -->
<script language="JavaScript">
<!--
function openBrWindow(theURL,winName,features) {
  window.open(theURL,winName,features);
}
//-->
</script>
<!-- END POPUP WINDOW SCRIPT -->
<!-- END HEAD -->
</head>
<body bgcolor="#FFFFFF">
<!-- START BODY -->
<table border="0" align="left" valign="top" width="650">
  <tr valign="top"><td colspan="2" valign="top">
  <div align="center"><a href="http://www.cyberweavers.com"><img src="images/hd_cal.png" border="0" valign="top" alt="CyberCalendar" width="395" height="76"></a></div>
  </td></tr>
  <tr valign="top">        
    <td valign="top" width="450">
ADMINPAGE
   show_admin_info();
   print "\n</td>\n<td>\n";
   show_calendar();
   print qq(\n<div align="left"><hr size="1" width="128" /></div>\n);
   show_calendar_list();
   show_links();
print "\n</td>\n</tr>\n</table>\n</body>\n</html>\n";
   my_exit();
} # endsub show_page

sub  show_admin_info {
SWITCH:
   for ($http_in->{View}) {
      /Day/o && do { show_events(); last; };
      /Edit/o && do { edit_event();  last; };
      /Add/o && do { add_event(); last; };
      /Delete/o && do { delete_event(); last; };
      /Repeat/o && do { repeat_event(); last; };
      /Submissions/ && do { manage_submissions(); last; };
      admin_index(); last;
   } # for
} # endsub show_admin_info

sub show_calendar {
   CyberCalendar::Application::show_calendar($user->{session});
}

sub show_calendar_list {
   CyberCalendar::Application::show_calendar_list($user->{uid},
                                                  $user->{accesslevel},
                                                  qq(<input type="hidden" name="session" value="$user->{session}" />),
                                                  $config->{admin_url}, $config->{select_img});
} # endsub show_calendar_list

sub page_heading {
   print <<"PAGEHEADING";
<center><font face="arial,helvetica" size="+2">$config->{calendar_name} ($http_in->{Calendar})</font><hr size="1" />
<font face="arial,helvetica" size="+1"><b>$_[0]</b></font><center><br />\n
PAGEHEADING
} # endsub page_heading

sub admin_index {
   print qq(<table border="0" align="center"><tr><td align="center" valign="top"><center>\n);
   page_heading("Add Event");
   print add_form();
} # endsub admin_index

sub edit_event {
   if (exists $http_in->{Edit}) { save_edits(); }
   # if
   else {
      print qq(<table border="0" align="center"><tr><td align="center" valign="top"><center>\n);
      page_heading("Edit Event");
      my $query = qq(SELECT * from $http_in->{Calendar} WHERE dateid = ? and repeatid = ?);
      $db->query($query, CyberCalendar::Application::http2dateid(), $http_in->{Repeatid});
      my $event = $db->result("hashref");
      my $edit = add_form('Edit', $event);
      $db->finish;
      my $cal = CyberCalendar::Calendar->new();
      show_event($event, $cal, $config);
      print $edit;
   } # else
} # endsub edit_event

sub show_result {
   print qq(<table border="0" align="center"><tr><td align="center" valign="top"><center>\n);
   page_heading();
   my $query = qq(SELECT * from $http_in->{Calendar} WHERE dateid = ? AND repeatid = ?);
   $db->query($query, $_[0], $_[1]);
   my $cal = CyberCalendar::Calendar->new();
   while ( my $data = $db->result("hashref") ) {
       show_event($data, $cal, $config);
       next;
   }
   $db->finish;
   print qq(<font face="arial,helvetica" size="+1"><b>$_[2]</b></center></td></tr></table>);
} # endsub show_result

sub add_event {
   my $featured = 0;
   $featured = 1 if $http_in->{featured} == 1;
   if ($http_in->{Category} eq "NULL"
      or $http_in->{Category} eq ""
      and $http_in->{NewCategory} eq "") {
      $http_in->{Category} = 'Default';
   } # if
   if ($http_in->{NewCategory} ne "") {
      $http_in->{Category} = $http_in->{NewCategory};
   } # if
   if ($http_in->{url} eq ""
      or $http_in->{url} eq "http://") {
      $http_in->{url} = ""
   } # if

   if ($http_in->{event_year} == 0 || $http_in->{event_month} == 0 || $http_in->{event_day} == 0) {
      $http_in->{event_year} = $today->[0];
      $http_in->{event_month} = $today->[1];
      $http_in->{event_day} = $today->[2];
   } # if
   my $dateid = "$http_in->{event_year}\-$http_in->{event_month}\-$http_in->{event_day}";
   my $enddate = '0000-00-00';
   if (exists $http_in->{end_month}
      and exists $http_in->{end_day}
      and exists $http_in->{end_year}) {
      $enddate = "$http_in->{end_year}\-$http_in->{end_month}\-$http_in->{end_day}";
   } # if
   my $starttime = '';
   if (exists $http_in->{TBA}
      || $http_in->{hour} == 0) {
      $starttime = '00:00:00';
   } # if
   else {
      $starttime = sprintf("%02d:%02d:00", ($http_in->{hour}, $http_in->{min}));
   } # else
   my $endtime = '';
   if (exists $http_in->{end_TBA}) {
      $endtime = '00:00:00';
   } # if
   else {
      $endtime = sprintf("%02d:%02d:00", ($http_in->{end_hour}, $http_in->{end_min}));
   } # else
   my @chars = ( "A" .. "Z", "a" .. "z", 0 .. 9 );
   my $repeatid = join("", @chars[ map { rand @chars } (1 .. 25) ]);

   my $query = qq(INSERT into $http_in->{Calendar}
                  (featured, repeatid, dateid, enddate, event_day,
                  event_month, event_year, subject, desctext,
                  url, email, location, category,
                  starttime, endtime)
                  VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?));
   $db->query($query, $featured, $repeatid, $dateid, $enddate,
              $http_in->{event_day}, $http_in->{event_month},
              $http_in->{event_year}, $http_in->{subject},
              $http_in->{desctext}, $http_in->{url},
              $http_in->{email}, $http_in->{location},
              $http_in->{Category}, $starttime, $endtime);
   $db->finish;
   if ($http_in->{AutoRepeat} == 1
      and $http_in->{end_year} != 0
      and $http_in->{end_month} != 0) {
      $http_in->{RepeatArb} = "yes";
      my $repeat = $http_in;
      $repeat->{category} = $repeat->{Category};
      $repeat->{featured} = $featured;
      $repeat->{repeatid} = $repeatid;
      $repeat->{enddate} = $enddate;
      $repeat->{starttime} = $starttime;
      $repeat->{endtime} = $endtime;
      auto_repeat($repeat);
   } # if
   show_result($dateid,$repeatid, 'Event Added') if $_[0] ne 'noresult';
} # endsub add_event

sub save_edits {
   my $featured = 0;
   $featured = 1 if $http_in->{featured} == 1;
   if ($http_in->{NewCategory} ne "") {
      $http_in->{Category} = $http_in->{NewCategory};
   } # if
   if ($http_in->{url} eq ""
      or $http_in->{url} eq "http://") {
      $http_in->{url} = ""
   } # if
   my $dateid = "$http_in->{event_year}\-$http_in->{event_month}\-$http_in->{event_day}";
   my $enddate = '0000-00-00';
   if (exists $http_in->{end_month}
      and exists $http_in->{end_day}
      and exists $http_in->{end_year}) {
      $enddate = "$http_in->{end_year}\-$http_in->{end_month}\-$http_in->{end_day}";
   } # if
   my $starttime = '';
   if (exists $http_in->{TBA}) {
      $starttime = '00:00:00';
   } # if
   else {
      $starttime = sprintf("%02d:%02d:00", ($http_in->{hour}, $http_in->{min}));
   } # else
   my $endtime = '';
   if (exists $http_in->{end_TBA}) {
      $endtime = '00:00:00';
   } # if
   else {
      $endtime = sprintf("%02d:%02d:00", ($http_in->{end_hour}, $http_in->{end_min}));
   } # else
   my $query = '';
   if (exists $http_in->{ApplyAll}) {
   $query = qq(UPDATE $http_in->{Calendar}
                  SET featured = ?,
                      enddate = ?,
                      subject = ?,
                      desctext = ?,
                      url = ?,
                      email = ?,
                      location = ?,
                      category = ?,
                      starttime = ?,
                      endtime = ?
                      WHERE repeatid = ?);
   $db->query($query, $featured, $enddate, $http_in->{subject},
              $http_in->{desctext}, $http_in->{url},
              $http_in->{email}, $http_in->{location},
              $http_in->{Category}, $starttime, $endtime, $http_in->{Repeatid});
   $db->finish;
   } # if
   else {
   $query = qq(UPDATE $http_in->{Calendar}
                  SET featured = ?,
                      dateid = ?,
                      enddate = ?,
                      event_day = ?,
                      event_month = ?,
                      event_year = ?,
                      subject = ?,
                      desctext = ?,
                      url = ?,
                      email = ?,
                      location = ?,
                      category = ?,
                      starttime = ?,
                      endtime = ?
                      WHERE repeatid = ? AND dateid = ?);
   $db->query($query, $featured, $dateid, $enddate,
              $http_in->{event_day}, $http_in->{event_month},
              $http_in->{event_year}, $http_in->{subject},
              $http_in->{desctext}, $http_in->{url},
              $http_in->{email}, $http_in->{location},
              $http_in->{Category}, $starttime, $endtime,
              $http_in->{Repeatid}, $http_in->{OldDateID});
   $db->finish;
   } # else
   show_result($dateid, $http_in->{Repeatid}, 'Event Edited Successfully') if $_[0] ne 'noresult';
} # endsub save_edits

sub delete_event {
   print qq(<center><font face="arial,helvetica" size="+2">$config->{calendar_name} ($http_in->{Calendar})</font>
         <hr size="1" /><font face="arial,helvetica" size="+1"><b>Delete Event</b></font><center><br />);
   if (!exists $http_in->{delete}) {
      my $query = qq(SELECT * from $http_in->{Calendar}
                     WHERE dateid = ?
                     AND repeatid = ?);
      $db->query($query,
                 CyberCalendar::Application::http2dateid(),
                 $http_in->{Repeatid});
      my $data = $db->result("hashref");
      $db->finish;
      my $cal = CyberCalendar::Calendar->new();
      show_event($data, $cal, $config);
      delete_form();
   } # if
   else {
      my $msg = qq(<p><center><font face="arial,helvetica" size="+1"><b>Event(s) deleted successfully!</b></font></center>);
      if ($http_in->{delete} eq "one") {
         my $query = qq(DELETE from $http_in->{Calendar}
                      WHERE dateid = ?
                      AND repeatid = ?);
         $db->query($query,
                    CyberCalendar::Application::http2dateid(),
                    $http_in->{Repeatid});
         $db->finish;
         print $msg;
      } # if
      elsif ($http_in->{delete} eq "all") {
         my $query = qq(DELETE from $http_in->{Calendar}
                      WHERE repeatid = ?);
         $db->query($query, $http_in->{Repeatid});
         $db->finish;
         print $msg;
      } # elsif
      else { my_error("no", "Can't delete event!"); }
   } # else
} # endsub delete_event

sub repeat_event {
   page_heading("Repeat Event");
   my $query = qq(SELECT * from $http_in->{Calendar}
                  WHERE dateid = ?
                  AND repeatid = ?);
   $db->query($query,
              CyberCalendar::Application::http2dateid(),
              $http_in->{Repeatid});
   my $data = $db->result("hashref");
   $db->finish;
   if ($http_in->{RepeatArb} eq "yes") {
      $data->{event_year} = $http_in->{event_year};
      $data->{event_month} = $http_in->{event_month};
      $data->{event_day} = $http_in->{event_day};
   } # if
   my $cal = CyberCalendar::Calendar->new();
   my %event = ();
   while ( my($name, $value) = each( %{ $data } ) ) { $event{$name} = $value; }
   show_event(\%event, $cal, $config);
   
   print repeat_form() if !exists $http_in->{Repeat};
   do_repeat($data, $cal) if exists $http_in->{Repeat};

} # endsub repeat_event

sub do_repeat {
   my $i = 1;
   my $msg = qq(<p><center><font face="arial,helvetica" size="+1"><b>Event Repeated Successfully.</b></font>);
   my @start_ary = ($_[0]->{event_year},
                    $_[0]->{event_month},
                    $_[0]->{event_day});
   my @end_ary = ();
   if ($http_in->{RepeatDays} ne "NULL"
      and $http_in->{RepeatDays} ne '') {
      $http_in->{RepeatDays} = $http_in->{RepeatDays} + 1;
      while ($i < $http_in->{RepeatDays}) {
         @end_ary = $_[1]->add_days($i, @start_ary);
         my $dateid = "$end_ary[0]\-$end_ary[1]\-$end_ary[2]";
         my $query = qq(INSERT into $http_in->{Calendar}
                       (featured, repeatid, dateid, enddate, event_day,
                       event_month, event_year, subject, desctext,
                       url, email, location, category,
                       starttime, endtime)
                       VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?));
         $db->query($query, $_[0]->{featured}, $_[0]->{repeatid}, $dateid, $_[0]->{enddate},
                    $end_ary[2], $end_ary[1], $end_ary[0],
                    $_[0]->{subject}, $_[0]->{desctext},
                    $_[0]->{url}, $_[0]->{email},
                    $_[0]->{location}, $_[0]->{category},
                    $_[0]->{starttime}, $_[0]->{endtime});
         $db->finish;
         $i++;
      } # while
      print $msg;
   } # if
   elsif ($http_in->{RepeatWeeks} ne "NULL"
      and $http_in->{RepeatWeeks} ne '') {
      my $w = 7;
      $http_in->{RepeatWeeks} = $http_in->{RepeatWeeks} + 1;
      @end_ary = @start_ary;
      while ($i < $http_in->{RepeatWeeks}) {
         @end_ary = $_[1]->add_days($w, @end_ary);
         my $dateid = "$end_ary[0]\-$end_ary[1]\-$end_ary[2]";
         my $query = qq(INSERT into $http_in->{Calendar}
                       (featured, repeatid, dateid, enddate, event_day,
                       event_month, event_year, subject, desctext,
                       url, email, location, category,
                       starttime, endtime)
                       VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?));
         $db->query($query, $_[0]->{featured}, $_[0]->{repeatid}, $dateid, $_[0]->{enddate},
                    $end_ary[2], $end_ary[1], $end_ary[0],
                    $_[0]->{subject}, $_[0]->{desctext},
                    $_[0]->{url}, $_[0]->{email},
                    $_[0]->{location}, $_[0]->{category},
                    $_[0]->{starttime}, $_[0]->{endtime});
         $db->finish;
         $i++;
      } # while
      print $msg;
   } # elsif
   elsif ($http_in->{RepeatMonths} ne "NULL"
      and $http_in->{RepeatMonths} ne '') {
      $http_in->{RepeatMonths} = $http_in->{RepeatMonths} +1;
      @end_ary = @start_ary;
      while ($i < $http_in->{RepeatMonths}) {
         my $dim = $_[1]->days_in_month($end_ary[0], $end_ary[1]);
         $end_ary[2] = 1;
         @end_ary = $_[1]->add_days($dim, @end_ary);
         my $dim2 = $_[1]->days_in_month($end_ary[0], $end_ary[1]);
         $end_ary[2] = $start_ary[2];
         $end_ary[2] = $dim2 if $end_ary[2] > $dim2;
         my $dateid = "$end_ary[0]\-$end_ary[1]\-$end_ary[2]";
         my $query = qq(INSERT into $http_in->{Calendar}
                       (featured, repeatid, dateid, enddate, event_day,
                       event_month, event_year, subject, desctext,
                       url, email, location, category,
                       starttime, endtime)
                       VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?));
         $db->query($query, $_[0]->{featured}, $_[0]->{repeatid}, $dateid, $_[0]->{enddate},
                    $end_ary[2], $end_ary[1], $end_ary[0],
                    $_[0]->{subject}, $_[0]->{desctext},
                    $_[0]->{url}, $_[0]->{email},
                    $_[0]->{location}, $_[0]->{category},
                    $_[0]->{starttime}, $_[0]->{endtime});
         $db->finish;
         $i++;
      }
      print $msg;
   } # elsif
   elsif ($http_in->{RepeatArb} eq "yes") {
      my $dateid = "$_[0]->{event_year}\-$_[0]->{event_month}\-$_[0]->{event_day}";
      my $query = qq(INSERT into $http_in->{Calendar}
                    (featured, repeatid, dateid, enddate, event_day,
                    event_month, event_year, subject, desctext,
                    url, email, location, category,
                    starttime, endtime)
                    VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?));
      $db->query($query, $_[0]->{featured}, $_[0]->{repeatid}, $dateid, $_[0]->{enddate},
                 $_[0]->{event_day}, $_[0]->{event_month}, $_[0]->{event_year},
                 $_[0]->{subject}, $_[0]->{desctext},
                 $_[0]->{url}, $_[0]->{email},
                 $_[0]->{location}, $_[0]->{category},
                 $_[0]->{starttime}, $_[0]->{endtime});
      $db->finish;
      print $msg if $_[2] ne 'nomsg';
   } # elsif
   else {
      print my_error("no", "Can't repeat event!");
   } # else
} # endsub do_repeat

sub auto_repeat {
   my $cal = CyberCalendar::Calendar->new();
   my @start = ($_[0]->{event_year}, $_[0]->{event_month}, $_[0]->{event_day});
   my @end = ($_[0]->{end_year}, $_[0]->{end_month}, $_[0]->{end_day});
   my $delta = $cal->delta_days(@start, @end);
   $delta = $delta + 1;
   my $i = 1;
   while ($i < $delta) {
      my @rep = $cal->add_days($i, @start);
      $_[0]->{event_year} = @rep[0];
      $_[0]->{event_month} = @rep[1];
      $_[0]->{event_day} = @rep[2];
      do_repeat($_[0], 'NULL', 'nomsg');
      $i++;
   } # while
} # endsub auto_repeat

sub show_events {
   print qq(<center><font face="arial,helvetica" size="+2">$config->{calendar_name} ($http_in->{Calendar})</font><hr size="1" />
           <font face="arial,helvetica" size="+1"><b>$http_in->{DateID}</b></font><center><br />);
   my $query = qq(SELECT * from $http_in->{Calendar}
               WHERE dateid = ?
               ORDER BY starttime ASC);
   $db->query($query, CyberCalendar::Application::http2dateid());
   my $rows = $db->rowcount;
   if ($rows == 0) { print qq(<div align="center"><font face="arial,helvetica" size="+1">No events found. Please select another date.</font></div>);  }
   else {
      my $i = 0;
      my $nav_string = '';
      my $prev = -1;
      my $next = 5;
      my $qstring = '';
      if ($rows > 5) { 
         if (!exists $http_in->{Next}
            or $http_in->{Next} == 0
            or $http_in->{Next} == 5) {
            $http_in->{Next} = 5;
            $nav_string = qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
                          <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Day&DateID=$http_in->{DateID}&Next=10&session=$user->{session}"
                          style="text-decoration:none">Next Results &gt;&gt;</a></font></b></div>);
         } # if
         elsif ($http_in->{Next} >= $rows) {
            $prev = $http_in->{Next} - 5;
            $next = $http_in->{Next} + 5;
            $nav_string = qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
                          <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Day&DateID=$http_in->{DateID}&Next=$prev&session=$user->{session}"
                          style="text-decoration:none">&lt;&lt;Previous Results</a></font></b></div>);
         } # elsif
         else {
            $prev = $http_in->{Next} - 5;
            $next = $http_in->{Next} + 5;
            $nav_string = qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
                          <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Day&DateID=$http_in->{DateID}&Next=$prev&session=$user->{session}"
                          style="text-decoration:none">&lt;&lt;Previous Results</a>&nbsp;&nbsp;&nbsp;
                          <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Day&DateID=$http_in->{DateID}&Next=$next&session=$user->{session}"
                          style="text-decoration:none">Next Results&gt;&gt;</a></font></b></div>);
         } # else
       } # if
      my $cal = CyberCalendar::Calendar->new();
      while (my $data = $db->result("hashref")) {
         if ($rows > 5) {
            if ($i <= $next
               and $i >= $prev) { $i++; }
            else { $i++; next; }
            if ($i > $http_in->{Next}
               or $i > $rows) { print $nav_string; last; }
         }
         show_event($data, $cal, $config);
         print $nav_string if $i == $rows;
      } # while
   } # else
   $db->finish;
} # endsub show_events

sub show_event {
   $_[0] = CyberCalendar::Application::process_event($_[0], $_[1]);
   $_[0]->{infolink} = qq(<table border="0" width="100%">
<tr><td align="left">
<font face="arial,helvetica" size="-2">
<p><a href="$_[2]->{admin_url}?Calendar=$http_in->{Calendar}&View=Edit&DateID=$_[0]->{event_month}/$_[0]->{event_day}/$_[0]->{event_year}&Repeatid=$_[0]->{repeatid}&session=$user->{session}">
EDIT EVENT</a></font>
</td><td align="center">
<font face="arial,helvetica" size="-2">
<p><a href="$_[2]->{admin_url}?Calendar=$http_in->{Calendar}&View=Repeat&DateID=$_[0]->{event_month}/$_[0]->{event_day}/$_[0]->{event_year}&Repeatid=$_[0]->{repeatid}&session=$user->{session}">
REPEAT EVENT</a></font>
</td><td align="right">
<font face="arial,helvetica" size="-2">
<p><a href="$_[2]->{admin_url}?Calendar=$http_in->{Calendar}&View=Delete&DateID=$_[0]->{event_month}/$_[0]->{event_day}/$_[0]->{event_year}&Repeatid=$_[0]->{repeatid}&session=$user->{session}">
DELETE EVENT</a></font>
</td></tr></table>);
   $_[0]->{url} = CyberCalendar::Application::fix_event_url($_[0]->{url});
   print  CyberCalendar::Application::event_long($_[0], $_[2]);
} # endsub show_event

sub manage_submissions {
SWITCH:
   for ($http_in->{Action}) {
      /Show/o && do { show_submissions(); last; };
      /Approve/o && do { approve_submission(); last; };
      /Delete/o && do { delete_submission(); last; };
      show_submissions(); last;
   } # for   
} # endsub show_submissions

sub show_submissions {
   print qq(<center><font face="arial,helvetica" size="+2">Event Submissions for: $config->{calendar_name} </font><hr size="1" /><center><br />);
   my $query = qq(SELECT * from submitted_events
               WHERE calendar = ?
               ORDER BY dateid ASC);
   $db->query($query, $http_in->{Calendar});
   my $rows = $db->rowcount;
   if ($rows == 0) { print qq(<font face="arial,helvetica" size="+1"><b>No Event Submissions Found</b></font>); }
   else {
      my $i = 0;
      my $nav_string = '';
      my $prev = -1;
      my $next = 5;
      my $qstring = '';
      if ($rows > 5) { 
         if (!exists $http_in->{Next}
            or $http_in->{Next} == 0
            or $http_in->{Next} == 5) {
            $http_in->{Next} = 5;
            $nav_string = qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
                         <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Submissions&Action=Show&Next=10&session=$user->{session}"
                         style="text-decoration:none">Next Results &gt;&gt;</a></font></b></div>);
         } # if
         elsif ($http_in->{Next} >= $rows) {
            $prev = $http_in->{Next} - 5;
            $next = $http_in->{Next} + 5;
            $nav_string = qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
                          <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Submissions&Action=Show&Next=$prev&session=$user->{session}"
                          style="text-decoration:none">&lt;&lt;Previous Results</a></font></b></div>);
         } # elsif
         else {
            $prev = $http_in->{Next} - 5;
            $next = $http_in->{Next} + 5;
            $nav_string = qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
                          <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Submissions&Action=Show&Next=$prev&session=$user->{session}"
                          style="text-decoration:none">&lt;&lt;Previous Results</a>&nbsp;&nbsp;&nbsp;
                          <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Submissions&Action=Show&Next=$next&session=$user->{session}"
                          style="text-decoration:none">Next Results&gt;&gt;</a></font></b></div>);
         } # else
       } # if
      print qq(<div align="center"><font face="arial,helvetica" size="+1"><b>$rows Events Have Been Submitted.</b></font></div>);
      my $cal = CyberCalendar::Calendar->new();
      while (my $data = $db->result("hashref")) {
         if ($rows > 5) {
            if ($i <= $next
               and $i >= $prev) { $i++; }
            else { $i++; next; }
            if ($i > $http_in->{Next}
               or $i > $rows) { print $nav_string; last; }
         }
         show_submission($data, $cal, $config);
         print $nav_string if $i == $rows;
      } # while
   } # else
   $db->finish;
} # endsub show_submissions

sub show_submission {
   $_[0] = CyberCalendar::Application::process_event($_[0], $_[1]);
   $_[0]->{infolink} = qq(<table border=0 width="100%">
<tr><td align="left">
<font face="arial,helvetica" size="-2">
<p><a href="$_[2]->{admin_url}?Calendar=$http_in->{Calendar}&View=Submissions&Action=Approve&Next=$http_in->{Next}&DateID=$_[0]->{event_month}/$_[0]->{event_day}/$_[0]->{event_year}&Repeatid=$_[0]->{repeatid}&session=$user->{session}">
APPROVE EVENT</a></font>
</td><td align="center">
<font face="arial,helvetica" size="-2">
<p>&nbsp;</font>
</td><td align="right">
<font face="arial,helvetica" size="-2">
<p><a href="$_[2]->{admin_url}?Calendar=$http_in->{Calendar}&View=Submissions&Action=Delete&Next=$http_in->{Next}&DateID=$_[0]->{event_month}/$_[0]->{event_day}/$_[0]->{event_year}&Repeatid=$_[0]->{repeatid}&session=$user->{session}">
DELETE EVENT</a></font>
</td></tr></table>);
   $_[0]->{url} = CyberCalendar::Application::fix_event_url($_[0]->{url});
   $_[0]->{desctext} .= qq(\n<p>Submitted by: $_[0]->{sub_name} &lt;<a href="mailto:$_[0]->{sub_email}">$_[0]->{sub_email}</a>&gt;\n);
   print  CyberCalendar::Application::event_long($_[0], $_[2]);
} # endsub show_submission

sub approve_submission {
   my $query = "SELECT * FROM submitted_events WHERE calendar = ? and dateid = ? and repeatid = ?";
   $db->query($query, $http_in->{Calendar}, CyberCalendar::Application::http2dateid(), $http_in->{Repeatid});
   my $data = $db->result("hashref");
   $db->finish;
   $query = qq(INSERT into $http_in->{Calendar}
               (repeatid, dateid, enddate, event_day,
               event_month, event_year, subject, desctext,
               url, email, location, category,
               starttime, endtime)
               VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?));
   $db->query($query, $data->{repeatid}, $data->{dateid}, $data->{enddate},
              $data->{event_day}, $data->{event_month},
              $data->{event_year}, $data->{subject},
              $data->{desctext}, $data->{url},
              $data->{email}, $data->{location},
              $data->{category}, $data->{starttime}, $data->{endtime});
   $db->finish;
   my $query = "DELETE FROM submitted_events WHERE calendar = ? and dateid = ? and repeatid = ?";
   $db->query($query, $http_in->{Calendar}, CyberCalendar::Application::http2dateid(), $http_in->{Repeatid});
   $db->finish;
   print qq(<center><font face="arial,helvetica" size="+2">Event Submissions for: $config->{calendar_name}</font>
         <hr size="1" /><font face="arial,helvetica" size="+1"><b>Event Added Successfully.<br />
         <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Submissions&Action=Show&Next=$http_in->{Next}&session=$user->{session}"
         style="text-decoration:none">&lt;&lt;Back</a></b></font><center>);
} # endsub approve_submissions

sub delete_submission {
   my $query = "DELETE FROM submitted_events WHERE calendar = ? and dateid = ? and repeatid = ?";
   $db->query($query, $http_in->{Calendar}, CyberCalendar::Application::http2dateid(), $http_in->{Repeatid});
   $db->finish;
   print qq(<center><font face="arial,helvetica" size="+2">Event Submissions for: $config->{calendar_name}</font>
         <hr size="1" /><font face="arial,helvetica" size="+1"><b>Event Successfully Deleted.<br />
         <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&View=Submissions&Action=Show&Next=$http_in->{Next}&session=$user->{session}"
         style="text-decoration:none">&lt;&lt;Back</a></b></font><center>);
} # endsub delete_submissions

#===============================================================================
# Here Documents
#===============================================================================

sub show_links {
   print <<"ADMLINKS";
<p><b><font face="$config->{cal_font}" size="2">
&#149; <a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">Add Event</a><p>
$user->{sub_edit}
$user->{cal_conf}
&#149; <a href="$config->{calendar_homepage}$config->{cal_url}?Calendar=$http_in->{Calendar}">Calendar Home</a>
</b>
</font>
</p>
ADMLINKS
}

sub add_form {
   my $form = '';
   my $repeatid = '';
   my $date_month = "<option value=\"0\" selected>Month</option>";
   my $date_day = "<option value=\"0\" selected>Day</option>";
   my $date_year = "<option value=\"0\" selected>Year</option>";
   my $time_hr = "<option value=\"0\" selected>Hr</option>";
   my $time_min = "<option value=\"0\" selected>Min</option>";
   my $endtime_hr = "<option value=\"0\" selected>Hr</option>";
   my $endtime_min = "<option value=\"0\" selected>Min</option>";
   my $enddate_month = "<option value=\"0\" selected>Month</option>";
   my $enddate_day = "<option value=\"0\" selected>Day</option>";
   my $enddate_year = "<option value=\"0\" selected>Year</option>";
   my $subject = '';
   my $location = '';
   my $cat_label = 'Select a Category';
   my $desctext = '';
   my $website = 'http://';
   my $contact = '';
   my $view = 'Add';
   my $featured = '';
   my $apply = '';
   my $edit = '';
   my $OldDateID = '';
   my $autorepeat = qq(<b><input type="checkbox" name="AutoRepeat" value="1" /> Auto-Repeat?</b>) if $_[0] ne 'Edit';
   if ($_[0] eq "Edit") {
      $featured = "CHECKED" if $_[1]->{featured} == 1;
      $apply = qq(<b><input type="checkbox" name="ApplyAll" value="yes" /> Apply Changes to All Occurrences of this Event in this calendar?</b>);
      $repeatid = $http_in->{Repeatid};
      $date_month = "<option value=$_[1]->{event_month} selected>$_[1]->{event_month}</option>";
      $date_day = "<option value=$_[1]->{event_day} selected>$_[1]->{event_day}</option>";
      $date_year = "<option value=$_[1]->{event_year} selected>$_[1]->{event_year}</option>";
      if ($_[1]->{starttime} != 0) {
         my ($hr, $m, $s) = split(/:/, $_[1]->{starttime});
         my $am_pm = 'AM';
         my $hr_hidden = $hr;
         $am_pm = 'PM' if $hr >= 12 and $hr <= 23;
         $hr = $hr - 12 if $hr > 12;
         $time_hr = "<option value=$hr_hidden selected>$am_pm $hr</option>";
         $time_min = "<option value=$m selected>$m</option>";
      }
      if ($_[1]->{endtime} != 0) {
         my ($hr, $m, $s) = split(/:/, $_[1]->{endtime});
         my $am_pm = 'AM';
         my $hr_hidden = $hr;
         $am_pm = 'PM' if $hr >= 12 and $hr <= 23;
         $hr = $hr - 12 if $hr > 12;
         $endtime_hr = "<option value=$hr_hidden selected>$am_pm $hr</option>";
         $endtime_min = "<option value=$m selected>$m</option>";
      }
      if ($_[1]->{enddate} != 0) {
         my ($y, $m, $d) = split('-', $_[1]->{enddate});
         $enddate_month = "<option value=\"$m\" selected>$m</option>\n<option value=\"0\">0</option>\n";
         $enddate_day = "<option value=\"$d\" selected>$d<option value=\"0\">0</option>\n";
         $enddate_year = "<option value=\"$y\" selected>$y<option value=\"0\">0</option>\n";
      }
      $subject = $_[1]->{subject};
      $location = $_[1]->{location};
      $cat_label = $_[1]->{category};
      $desctext = $_[1]->{desctext};
      $website = $_[1]->{url} if $_[1]->{url} ne '';
      $contact = $_[1]->{email};
      $view = 'Edit';
      $edit = qq(<input type="hidden" name="Edit" value="Edit" />);
      my ($m, $d, $y) = split('/', $http_in->{DateID});
      $OldDateID = "$y\-$m\-$d";
   }

$form = <<"ADDFORMA";
<center>
  <form name="menu" method="post" action="$config->{admin_url}">
    <font face="Verdana, Arial, Helvetica, sans-serif"><b><input type="checkbox" name="featured" value="1" $featured />  This is a featured event.</b></font><br />
    <table cellspacing="0" cellpadding="0" border="0" align="center">
      <tr align="center" valign="center"> 
        <td align="center" valign="middle"> 
          <table cellspacing="0" cellpadding="0" border="0" width="400" align="center">
            <tr> 
              <td align="left" bgcolor="#000000" valign="bottom" width="400"> 
                <font face="Verdana, Arial, Helvetica" color="white" size=" 1"><b> 
                &nbsp;DATE:<br />
                </b></font></td>
            </tr>
            <tr valign="top"> 
              <td> 
                <table cellspacing="0" cellpadding="4" border="0" width="400">
                  <tr valign="top"> 
                    <td align="left" bgcolor="#FEFEE2" width="275"> 
                      <select name="event_month">
                        $date_month
                        <option value="01">January</option> 
                        <option value="02">February</option> 
                        <option value="03">March</option> 
                        <option value="04">April</option> 
                        <option value="05">May</option> 
                        <option value="06">June</option> 
                        <option value="07">July</option> 
                        <option value="08">August</option> 
                        <option value="09">September</option> 
                        <option value="10">October</option> 
                        <option value="11">November</option> 
                        <option value="12">December</option>
                      </select>
                      <select name="event_day">
                        $date_day 
                        <option value="01">1</option> 
                        <option value="02">2</option> 
                        <option value="03">3</option> 
                        <option value="04">4</option> 
                        <option value="05">5</option> 
                        <option value="06">6</option> 
                        <option value="07">7</option> 
                        <option value="08">8</option> 
                        <option value="09">9</option> 
                        <option value="10">10</option> 
                        <option value="11">11</option> 
                        <option value="12">12</option> 
                        <option value="13">13</option> 
                        <option value="14">14</option> 
                        <option value="15">15</option> 
                        <option value="16">16</option> 
                        <option value="17">17</option> 
                        <option value="18">18</option> 
                        <option value="19">19</option> 
                        <option value="20">20</option> 
                        <option value="21">21</option> 
                        <option value="22">22</option> 
                        <option value="23">23</option> 
                        <option value="24">24</option> 
                        <option value="25">25</option> 
                        <option value="26">26</option> 
                        <option value="27">27</option> 
                        <option value="28">28</option> 
                        <option value="29">29</option> 
                        <option value="30">30</option> 
                        <option value="31">31</option> 
                      </select>
                      <select name="event_year">
                        $date_year 
                        <option value="1999">1999</option> 
                        <option value="2000">2000</option> 
                        <option value="2001">2001</option> 
                        <option value="2002">2002</option> 
                        <option value="2003">2003</option> 
                        <option value="2004">2004</option> 
                        <option value="2005">2005</option> 
                        <option value="2006">2006</option>
                        <option value="2007">2007</option>
                        <option value="2008">2008</option>
                        <option value="2009">2009</option>
                        <option value="2010">2010</option>
                      </select>
                    </td>
                  </tr>
                  <tr> 
                    <td align="left" valign="bottom" width="400" height="1">&nbsp;</td>
                  </tr>
                  <tr valign="top" bgcolor="#000000"> 
                    <td align="left" width="275"><font color="#FFFFFF" size="1" face="Verdana, Arial, Helvetica, sans-serif"><b>START 
                      TIME:</b></font><font face="Verdana, Arial, Helvetica" color="white" size=" 1"></font></td>
                  </tr>
                  <tr valign="top"> 
                    <td align="left" bgcolor="#FEFEE2" width="275"> 
                      <select name="hour">
                        $time_hr
                        <option value="24">AM 12</option>
                        <option value="01">AM 1</option>
                        <option value="02">AM 2</option>
                        <option value="03">AM 3</option>
                        <option value="04">AM 4</option>
                        <option value="05">AM 5</option>
                        <option value="06">AM 6</option>
                        <option value="07">AM 7</option>
                        <option value="08">AM 8</option>
                        <option value="09">AM 9</option>
                        <option value="10">AM 10</option>
                        <option value="11">AM 11</option>
                        <option value="12">PM 12</option>
                        <option value="13">PM 1</option>
                        <option value="14">PM 2</option>
                        <option value="15">PM 3</option>
                        <option value="16">PM 4</option>
                        <option value="17">PM 5</option>
                        <option value="18">PM 6</option>
                        <option value="19">PM 7</option>
                        <option value="20">PM 8</option>
                        <option value="21">PM 9</option>
                        <option value="22">PM 10</option>
                        <option value="23">PM 11</option>
                      </select>
                      <select name="min">
                        $time_min
                        <option value="00">00</option>
                        <option value="01">01</option>
                        <option value="02">02</option>
                        <option value="03">03</option>
                        <option value="04">04</option>
                        <option value="05">05</option>
                        <option value="06">06</option>
                        <option value="07">07</option>
                        <option value="08">08</option>
                        <option value="09">09</option>
                        <option value="10">10</option>
                        <option value="11">11</option>
                        <option value="12">12</option>
                        <option value="13">13</option>
                        <option value="14">14</option>
                        <option value="15">15</option>
                        <option value="16">16</option>
                        <option value="17">17</option>
                        <option value="18">18</option>
                        <option value="19">19</option>
                        <option value="20">20</option>
                        <option value="21">21</option>
                        <option value="22">22</option>
                        <option value="23">23</option>
                        <option value="24">24</option>
                        <option value="25">25</option>
                        <option value="26">26</option>
                        <option value="28">28</option>
                        <option value="29">29</option>
                        <option value="30">30</option>
                        <option value="31">31</option>
                        <option value="32">32</option>
                        <option value="33">33</option>
                        <option value="34">34</option>
                        <option value="35">35</option>
                        <option value="36">36</option>
                        <option value="37">37</option>
                        <option value="38">38</option>
                        <option value="39">39</option>
                        <option value="40">40</option>
                        <option value="41">41</option>
                        <option value="42">42</option>
                        <option value="43">43</option>
                        <option value="44">44</option>
                        <option value="45">45</option>
                        <option value="46">46</option>
                        <option value="47">47</option>
                        <option value="48">48</option>
                        <option value="49">49</option>
                        <option value="50">50</option>
                        <option value="51">51</option>
                        <option value="52">52</option>
                        <option value="53">53</option>
                        <option value="54">54</option>
                        <option value="55">55</option>
                        <option value="56">56</option>
                        <option value="57">57</option>
                        <option value="58">58</option>
                        <option value="59">59</option>
                      </select>
                      <input type="checkbox" name="TBA" value="TBA" />
                      <b>To be announced.</b> </td>
                  </tr>
                  <tr valign="top"> 
                    <td align="left" width="400" bgcolor="#000000"><font color="#FFFFFF" size="1" face="Verdana, Arial, Helvetica, sans-serif"><b>END 
                      TIME (optional):</b></font></td>
                  </tr>
                  <tr valign="top"> 
                    <td align="left" bgcolor="#FEFEE2" width="400"> 
                      <select name="end_hour">
                        $endtime_hr
                        <option value="24">AM 12</option>
                        <option value="01">AM 1</option>
                        <option value="02">AM 2</option>
                        <option value="03">AM 3</option>
                        <option value="04">AM 4</option>
                        <option value="05">AM 5</option>
                        <option value="06">AM 6</option>
                        <option value="07">AM 7</option>
                        <option value="08">AM 8</option>
                        <option value="09">AM 9</option>
                        <option value="10">AM 10</option>
                        <option value="11">AM 11</option>
                        <option value="12">PM 12</option>
                        <option value="13">PM 1</option>
                        <option value="14">PM 2</option>
                        <option value="15">PM 3</option>
                        <option value="16">PM 4</option>
                        <option value="17">PM 5</option>
                        <option value="18">PM 6</option>
                        <option value="19">PM 7</option>
                        <option value="20">PM 8</option>
                        <option value="21">PM 9</option>
                        <option value="22">PM 10</option>
                        <option value="23">PM 11</option>
                      </select>
                      <select name="end_min">
                        $endtime_min
                        <option value="00">00</option>
                        <option value="01">01</option>
                        <option value="02">02</option>
                        <option value="03">03</option>
                        <option value="04">04</option>
                        <option value="05">05</option>
                        <option value="06">06</option>
                        <option value="07">07</option>
                        <option value="08">08</option>
                        <option value="09">09</option>
                        <option value="10">10</option>
                        <option value="11">11</option>
                        <option value="12">12</option>
                        <option value="13">13</option>
                        <option value="14">14</option>
                        <option value="15">15</option>
                        <option value="16">16</option>
                        <option value="17">17</option>
                        <option value="18">18</option>
                        <option value="19">19</option>
                        <option value="20">20</option>
                        <option value="21">21</option>
                        <option value="22">22</option>
                        <option value="23">23</option>
                        <option value="24">24</option>
                        <option value="25">25</option>
                        <option value="26">26</option>
                        <option value="28">28</option>
                        <option value="29">29</option>
                        <option value="30">30</option>
                        <option value="31">31</option>
                        <option value="32">32</option>
                        <option value="33">33</option>
                        <option value="34">34</option>
                        <option value="35">35</option>
                        <option value="36">36</option>
                        <option value="37">37</option>
                        <option value="38">38</option>
                        <option value="39">39</option>
                        <option value="40">40</option>
                        <option value="41">41</option>
                        <option value="42">42</option>
                        <option value="43">43</option>
                        <option value="44">44</option>
                        <option value="45">45</option>
                        <option value="46">46</option>
                        <option value="47">47</option>
                        <option value="48">48</option>
                        <option value="49">49</option>
                        <option value="50">50</option>
                        <option value="51">51</option>
                        <option value="52">52</option>
                        <option value="53">53</option>
                        <option value="54">54</option>
                        <option value="55">55</option>
                        <option value="56">56</option>
                        <option value="57">57</option>
                        <option value="58">58</option>
                        <option value="59">59</option>
                      </select>
                      <!-- <input type="checkbox" name="end_TBA" value="TBA" />
                      <b>To be announced.</b> --> </td>
                  </tr>
                  <tr> 
                    <td align="left" valign="bottom" width="400" height="1">&nbsp;</td>
                  </tr>
                  <tr valign="top"> 
                    <td align="left" bgcolor="#000000" width="400" height="1"><font color="#FFFFFF" size="1" face="Verdana, Arial, Helvetica, sans-serif"><b> 
                      </b></font><font face="Verdana, Arial, Helvetica" color="white" size=" 1"><b>&nbsp;END 
                      DATE (optional):</b></font><font color="#FFFFFF" size="1" face="Verdana, Arial, Helvetica, sans-serif"></font></td>
                  </tr>
                  <tr valign="top"> 
                    <td align="left" bgcolor="#FEFEE2" width="400"> 
                      <select name="end_month">
                        $enddate_month 
                        <option value="01">January</option> 
                        <option value="02">February</option> 
                        <option value="03">March</option> 
                        <option value="04">April</option> 
                        <option value="05">May</option> 
                        <option value="06">June</option> 
                        <option value="07">July</option> 
                        <option value="08">August</option> 
                        <option value="09">September</option> 
                        <option value="10">October</option> 
                        <option value="11">November</option> 
                        <option value="12">December</option> 
                      </select>
                      <select name="end_day">
                        $enddate_day 
                        <option value="01">1</option> 
                        <option value="02">2</option>  
                        <option value="03">3</option> 
                        <option value="04">4</option>
                        <option value="05">5</option> 
                        <option value="06">6</option> 
                        <option value="07">7</option> 
                        <option value="08">8</option> 
                        <option value="09">9</option> 
                        <option value="10">10</option> 
                        <option value="11">11</option> 
                        <option value="12">12</option> 
                        <option value="13">13</option> 
                        <option value="14">14</option> 
                        <option value="15">15</option> 
                        <option value="16">16</option> 
                        <option value="17">17</option> 
                        <option value="18">18</option> 
                        <option value="19">19</option> 
                        <option value="20">20</option> 
                        <option value="21">21</option> 
                        <option value="22">22</option> 
                        <option value="23">23</option> 
                        <option value="24">24</option> 
                        <option value="25">25</option>
                        <option value="26">26</option> 
                        <option value="27">27</option> 
                        <option value="28">28</option> 
                        <option value="29">29</option> 
                        <option value="30">30</option> 
                        <option value="31">31</option> 
                      </select>
                      <select name="end_year">
                        $enddate_year 
                        <option value="1999">1999</option> 
                        <option value="2000">2000</option> 
                        <option value="2001">2001</option> 
                        <option value="2002">2002</option> 
                        <option value="2003">2003</option> 
                        <option value="2004">2004</option>
                        <option value="2005">2005</option>
                        <option value="2006">2006</option>
                        <option value="2007">2007</option>
                        <option value="2008">2008</option>
                        <option value="2009">2009</option>
                        <option value="2010">2010</option>
                      </select>
                     $autorepeat
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
        </td>
      </tr>
    </table>
    <br />
    <table cellspacing="0" cellpadding="0" border="0" width="400" align="center">
      <tr> 
        <td align="left" bgcolor="#000000"> <font face="Verdana, Arial, Helvetica" color="white" size="1"><b> 
          &nbsp;&nbsp;&nbsp;SUBJECT:<br />
          </b></font></td>
      </tr>
      <tr> 
        <td> 
          <table cellspacing="0" cellpadding="4" border="0" width="400">
            <tr> 
              <td align="left" bgcolor="#FEFEE2">&nbsp;&nbsp; 
                <input type="text" maxlength="50" size="45" name="subject" value="$subject" />
              </td>
            </tr>
          </table>
        </td>
      </tr>
    </table>
    <br />
    <table cellspacing="0" cellpadding="0" border="0" width="400" align="center">
      <tr> 
        <td align="left" bgcolor="#000000"> <font face="Verdana, Arial, Helvetica" color="white" size="1"><b> 
          &nbsp;&nbsp;&nbsp;LOCATION:<br />
          </b></font></td>
      </tr>
      <tr> 
        <td> 
          <table cellspacing="0" cellpadding="4" border="0" width="400">
            <tr> 
              <td align="left" bgcolor="#FEFEE2">&nbsp;&nbsp; 
                <input type="text" maxlength="255" size="45" name="location" value="$location" />
              </td>
            </tr>
          </table>
        </td>
      </tr>
    </table>
    <p> 
    <table cellspacing="0" cellpadding="0" border="0" align="CENTER">
      <tr align="center" valign="middle"> 
        <td align="center" valign="middle"> 
          <table cellspacing="0" cellpadding="0" border="0" width="400" align="center">
            <tr> 
              <td align="left" bgcolor="#000000"> <font face="Verdana, Arial, Helvetica" color="white" size="1"><b> 
                &nbsp;&nbsp;&nbsp;CATEGORY:<br />
                </b></font></td>
            </tr>
            <tr> 
              <td> 
                <table cellspacing="0" cellpadding="4" border="0" width="400">
                  <tr> 
                    <td align="left" bgcolor="#FEFEE2">&nbsp;&nbsp;
ADDFORMA

   my $query = "SELECT DISTINCT category from $http_in->{Calendar}";
   $db->query($query);
   
   my $categories = {};
   while (my $tmp = $db->result("hashref")) {
      my ($name, $value) = each(%{ $tmp });
      $categories->{$value} = $value;
   } # while
   $db->finish;

   $form .= qq(\n<font face="$config->{event_head_font}" size="2">\n<select name="Category">\n<option value="$_[1]->{category}" SELECTED>$_[1]->{category}</option>\n);
   while (my ($name, $value) = each(%{ $categories })) { $form .= "<option value=\"$value\">$value</option>\n"; }
   # while
   $form .= "</select>\n</font>\n";

$form .= <<"ADDFORMB";
                  </tr>
                  <tr> 
                    <td align="left" bgcolor="#FEFEE2"> <font face="Arial, Helvetica, sans-serif" size="-1"><b> 
                      New Category: </b></font> 
                      <input type="text" maxlength="50" size="25" name="NewCategory" />
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
        </td>
      </tr>
    </table>
    <p> 
    <table cellspacing="0" cellpadding="0" border="0" align="center" width="400">
      <tr align="center" valign="center"> 
        <td align="left" bgcolor="#000000" valign="left"> <font face="Verdana, Arial, Helvetica" color="white" size="1"><b> 
          &nbsp;&nbsp;&nbsp;TEXT:<br />
          </b></font> </td>
    </table>
    <table cellspacing="0" cellpadding="0" border="0" align="center" width="400">
      <tr> 
        <td bgcolor="#FEFEE2" width="400" align="center" valign="middle"> <font face="Verdana, Arial, Helvetica" color="#FEFEE2" size="1"> 
          &nbsp;<br />
          </font>&nbsp;&nbsp; 
          <textarea cols="45" rows="10" wrap="virtual" name="desctext">$desctext</textarea>
        </td>
      </tr>
    </table>
    <p> 
    <table cellspacing="0" cellpadding="0" border="0" align="CENTER">
      <tr align="center" valign="middle">
        <td align="center" valign="middle"> 
          <table cellspacing="0" cellpadding="0" border="0" width="400" align="center">
            <tr> 
              <td align="left" bgcolor="#000000"> <font face="Verdana, Arial, Helvetica" color="white" size="1"><b> 
                &nbsp;&nbsp;&nbsp;WEBSITE (optional):<br />
                </b></font></td>
            </tr>
            <tr> 
              <td> 
                <table cellspacing="0" cellpadding="4" border="0" width="400">
                  <tr> 
                    <td align="left" bgcolor="#FEFEE2"> &nbsp;&nbsp; 
                      <input type="text" maxlength="255" size="45" name="url" value="$website" />
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
        </td>
      </tr>
    </table>
    <table cellspacing="0" cellpadding="0" border="0" align="center">
      <tr align="center" valign="middle"> 
        <td align="center" valign="middle"> 
          <table cellspacing="0" cellpadding="0" border="0" width="400" align="center">
            <tr> 
              <td align="left">&nbsp;</td>
            </tr>
            <tr> 
              <td align="left" bgcolor="#000000"> <font face="Verdana, Arial, Helvetica" color="white" size="1"><b> 
                &nbsp;&nbsp;&nbsp;E-MAIL CONTACT (optional):<br />
                </b></font></td>
            </tr>
            <tr> 
              <td> 
                <table cellspacing="0" cellpadding="4" border="0" width="400">
                  <tr> 
                    <td align="left" bgcolor="#FEFEE2"> &nbsp;&nbsp; 
                      <input type="text" maxlength="255" size="45" name="email" value="$contact" />
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
        </td>
      </tr>
    </table>
    <br />
    <font face="Verdana, Arial, Helvetica, sans-serif">$apply</font> 
    <p> 
    <table cellspacing="0" cellpadding="0" border="0" width="400" align="center" valign="middle">
      <tr> 
        <td align="left" valign="middle">
          <input type="hidden" name="View" value="$view" />
          <input type="hidden" name="Repeatid" value="$repeatid" />
          <input type="hidden" name="Calendar" value="$http_in->{Calendar}" />
          <input type="hidden" name="DateID" value="$http_in->{DateID}" />
          <input type="hidden" name="OldDateID" value="$OldDateID" />
          $edit
          <input type="hidden" name="session" value="$user->{session}" />
          </td>
        <td align="center" valign="middle" bgcolor="#000000"><input type="image" src="images/save.png" border="0" width="126" height="15" name="Save" /></td>
      </tr>
    </table>
  </form>
          </td>
      </tr>
    </table>
  <p> 
</center>
ADDFORMB
}

sub repeat_form {
return <<"REPEATFORM";
<form method="post" action="$config->{admin_url}">
<input type="hidden" name="Repeat" value="Repeat" /> 
<table cellspacing="0" cellpadding="0" border="0" align="center">
<tr align="center" valign="middle"><td align="center" valign="middle">
          <table cellspacing="0" cellpadding="0" border="0" width="450">
            <tr>
              <td> 
                <table cellspacing="0" cellpadding="4" border="0" width="450">
                  <tr> 
                    <td align="left" bgcolor="#FEFEE2"> &nbsp;Repeat for 
                      <select name="RepeatDays">
                        <option value="NULL" selected> </option>
                        <option value="1">1 </option>
                        <option value="2">2 </option>
                        <option value="3">3 </option>
                        <option value="4">4 </option>
                        <option value="5">5 </option>
                        <option value="6">6 </option>
                        <option value="7">7 </option>
                        <option value="8">8</option>
                        <option value="9">9 </option>
                        <option value="10">10 </option>
                        <option value="11">11 </option>
                        <option value="12">12 </option>
                        <option value="13">13 </option>
                        <option value="14">14 </option>
                        <option value="15">15 </option>
                        <option value="16">16 </option>
                        <option value="17">17 </option>
                        <option value="18">18 </option>
                        <option value="19">19 </option>
                        <option value="20">20 </option>
                        <option value="21">21 </option>
                        <option value="22">22 </option>
                        <option value="23">23 </option>
                        <option value="24">24 </option>
                        <option value="25">25 </option>
                        <option value="26">26 </option>
                        <option value="27">27 </option>
                        <option value="28">28 </option>
                        <option value="29">29 </option>
                        <option value="30">30 </option>
                        <option value="31">31 </option>
                      </select>
                      consecutive days. </td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
</td></tr></table><p>
<table cellspacing="0" cellpadding="0" border="0" align="center">
<tr align="center" valign="middle"><td align="center" valign="middle">
          <table cellspacing="0" cellpadding="0" border="0" width="450">
            <tr>
              <td>
                <table cellspacing="0" cellpadding="4" border="0" width="450">
                  <tr> 
                    <td align="left" bgcolor="#FEFEE2"> &nbsp;Repeat on this day of week
                      for the next 
                      <select name="RepeatWeeks">
                        <option value="NULL" selected>
                        <option value="1">1</option>
                        <option value="2">2</option> 
                        <option value="3">3</option> 
                        <option value="4">4</option> 
                        <option value"=5">5</option> 
                        <option value="6">6</option> 
                        <option value="7">7</option> 
                        <option value="8">8</option> 
                        <option value="9">9</option> 
                        <option value="10">10</option> 
                        <option value="11">11</option> 
                        <option value="12">12</option> 
                        <option value="13">13</option> 
                        <option value="14">14</option> 
                        <option value="15">15</option> 
                        <option value="16">16</option> 
                        <option value="17">17</option> 
                        <option value="18">18</option> 
                        <option value="19">19</option> 
                        <option value="20">20</option> 
                        <option value="21">21</option> 
                        <option value="22">22</option> 
                        <option value="23">23</option> 
                        <option value="24">24</option> 
                        <option value="25">25</option> 
                        <option value="26">26</option> 
                        <option value="27">27</option> 
                        <option value="28">28</option> 
                        <option value="29">29</option> 
                        <option value="30">30</option> 
                        <option value="31">31</option> 
                        <option value="32">32</option> 
                        <option value="33">33</option> 
                        <option value="34">34</option> 
                        <option value="35">35</option> 
                        <option value="36">36</option> 
                        <option value="37">37</option> 
                        <option value="38">38</option> 
                        <option value="39">39</option>
                        <option value="40">40</option> 
                        <option value="41">41</option> 
                        <option value="42">42</option> 
                        <option value="43">43</option> 
                        <option value="44">44</option> 
                        <option value="45">45</option> 
                        <option value="46">46</option> 
                        <option value="47">47</option> 
                        <option value="48">48</option> 
                        <option value="49">49</option> 
                        <option value="50">50</option> 
                        <option value="51">51</option> 
                        <option value="52">52</option> 
                      </select>
                      weeks. </td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
</td></tr></table>
<p><table cellspacing="0" cellpadding="0" border="0" align="center">
<tr align="center" valign="middle"><td align="center" valign="middle">
          <table cellspacing="0" cellpadding="0" border="0" width="450">
            <tr>
              <td> 
                <table cellspacing="0" cellpadding="4" border="0" width="450">
                  <tr> 
                    <td align="left" bgcolor="#FEFEE2" width="450"> &nbsp;<font face="Verdana, Arial, Helvetica, sans-serif" size="2"> 
                      Repeat on this date for the next 
                      <select name="RepeatMonths">
                        <option value="NULL"> </option>
                        <option value="1">1</option>
                        <option value="2">2</option>
                        <option value="3">3</option>
                        <option value="4">4</option>
                        <option value="5">5</option>
                        <option value="6">6</option>
                        <option value="7">7</option>
                        <option value="8">8</option>
                        <option value="9">9</option>
                        <option value="10">10</option>
                        <option value="11">11</option>
                        <option value="12">12</option>
                      </select>
                      months.</font></td>
                  </tr>
                </table>
               </td>
            </tr>
          </table>
        </td></tr></table>
<p><table cellspacing="0" cellpadding="0" border="0" align="center">
<tr align="center" valign="middle"><td align="center" valign="middle">
          <table cellspacing="0" cellpadding="0" border="0" width="450">
            <tr>
              <td> 
                <table cellspacing="0" cellpadding="4" border="0" width="450">
                  <tr> 
                    <td align="left" bgcolor="#FEFEE2" width="450"> &nbsp;<font face="Verdana, Arial, Helvetica, sans-serif" size="2"> 
                      Repeat this event on an arbitrary date:
                      <input type="checkbox" name="RepeatArb" value="yes" /><br /> 
                        Month: <select name="event_month">
			<option value="NULL" selected> </option>
                        <option value="1">January</option>
                        <option value="2">February</option> 
                        <option value="3">March</option> 
                        <option value="4">April</option> 
                        <option value="5">May</option> 
                        <option value="6">June</option> 
                        <option value="7">July</option> 
                        <option value="8">August</option> 
                        <option value="9">September</option> 
                        <option value="10">October</option> 
                        <option value="11">November</option> 
                        <option value="12">December</option> 
                      </select>
                      Date: <select name="event_day">
                        <option value="NULL" selected> </option>
                        <option value="1">1</option> 
                        <option value="2">2</option> 
                        <option value="3">3</option>
                        <option value="4">4</option> 
                        <option value="5">5</option> 
                        <option value="6">6</option> 
                        <option value="7">7</option> 
                        <option value="8">8</option> 
                        <option value="9">9</option> 
                        <option value="10">10</option> 
                        <option value="11">11</option> 
                        <option value="12">12</option> 
                        <option value="13">13</option> 
                        <option value="14">14</option> 
                        <option value="15">15</option> 
                        <option value="16">16</option> 
                        <option value="17">17</option> 
                        <option value="18">18</option> 
                        <option value="19">19</option> 
                        <option value="20">20</option> 
                        <option value="21">21</option> 
                        <option value="22">22</option> 
                        <option value="23">23</option>
                        <option value="24">24</option>
                        <option value="25">25</option> 
                        <option value="26">26</option> 
                        <option value="27">27</option> 
                        <option value="28">28</option> 
                        <option value="29">29</option> 
                        <option value="30">30</option> 
                        <option value="31">31</option> 
                      </select>
                      Year: <select name="event_year">
                        <option value="NULL" selected> </option>
                        <option value="1999">1999</option> 
                        <option value="2000">2000</option> 
                        <option value="2001">2001</option> 
                        <option value="2002">2002</option> 
                        <option value="2003">2003</option>
                        <option value="2004">2004</option> 
                        <option value="2005">2005</option>
                        <option value="2006">2006</option>
                        <option value="2007">2007</option>
                        <option value="2008">2008</option>
                        <option value="2009">2009</option>
                        <option value="2010">2010</option>
                      </select>
                      </font></td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
        </td></tr></table>
<br />
<center>
<table cellspacing="0" cellpadding="0" border="0" width="450" align="center" valign="middle">
<tr bgcolor="#000000" align="center"><td align="left" valign="middle">
<input type="hidden" name="DateID" value="$http_in->{DateID}" />
<input type="hidden" name="View" value="Repeat" />
<input type="hidden" name="Repeat" value="Repeat" />
<input type="hidden" name="Repeatid" value="$http_in->{Repeatid}" />
<input type="hidden" name="Calendar" value="$http_in->{Calendar}" />
<input type="hidden" name="session" value="$user->{session}" />
</td><td align="center" valign="middle"><input type="image" src="images/save.png" border="0" alt="Next" width="126" height="15" /></td>
</tr></table>
</center>
</form>
REPEATFORM
}

sub delete_form {
   print <<"DELOPTIONS";
<table border="0" width="250" align="center"><tr><td align="center">
<form method="post" action="$config->{admin_url}">
<input type="hidden" name="Calendar" value="$http_in->{Calendar}" />
<input type="hidden" name="DateID" value="$http_in->{DateID}" />
<input type="hidden" name="Repeatid" value="$http_in->{Repeatid}" />
<input type="hidden" name="delete" value="one" />
<input type="hidden" name="View" value="Delete" />
<input type="hidden" name="session" value="$user->{session}" />
<input type="submit" name="submit" value="Delete this occurance." />
</form><p>
<form method="post" action="$config->{admin_url}">
<input type="hidden" name="Calendar" value="$http_in->{Calendar}" />
<input type="hidden" name="DateID" value="$http_in->{DateID}" />
<input type="hidden" name="Repeatid" value="$http_in->{Repeatid}" />
<input type="hidden" name="View" value="Delete" />
<input type="hidden" name="delete" value="all" />
<input type="hidden" name="session" value="$user->{session}" />
<input type="submit" name="submit" value="Delete all occurances." />
</form>
<form method="get" action="$config->{admin_url}">
<input type="hidden" name="Calendar" value="$http_in->{Calendar}" />
<input type="hidden" name="session" value="$user->{session}" />
<input type="submit" name="submit" value="Cancel" />
</form>
</td></tr></table>
DELOPTIONS
}

#===============================================================================

sub my_error {
   CyberCalendar::Application::my_error($_[0], $_[1]);
} # endsub my_error

sub my_exit {
   CyberCalendar::Application::my_exit();
} # endsub my_exit

sub DESTROY {
   my $self = shift || 0;
   my $input = {};
} # endsub DESTROY

1;
