package CyberCalendar::Application;
###################################################################
# CyberCalendar v1.8.2
#
# Main Application Module
# Copyright 1999, 2000, 2001 Shawn Ewald <shawn@cyberweavers.com>
#
###################################################################
# License:                                                        #
# ----------------------------------------------------------------#
# This program is free software; you can redistribute it and/or   #
# modify it under the terms of the GNU General Public License     #
# as published by the Free Software Foundation; either version 2  #
# of the License, or (at your option) any later version.          #
#                                                                 #
# This program is distributed in the hope that it will be useful, #
# but WITHOUT ANY WARRANTY; without even the implied warranty of  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
###################################################################
# For the full text of the GNU General Public License, go to:     #
# http://www.gnu.org/copyleft/gpl.html                            #
###################################################################
# IMPORT MODULES
use vars qw($config $http_in $db $today_aref $today $t_dateid $VERSION);
use CyberCalendar::Config;
use CyberCalendar::Util;
use CyberCalendar::Http;
use CyberCalendar::Database;
use CyberCalendar::Calendar;
use CGI::Carp qw(croak fatalsToBrowser);
#use Carp qw(croak);
use strict;

# Set $VERSION
$CyberCalendar::Application::VERSION = 1.8.2;

###################################################################
# Callable Methods

sub new {
   my $self = shift || 0;
   my $hashref = {};

   # Open database connection
   $db = CyberCalendar::Database->new();
   $db->connect($config->{datasource},
                $config->{db_user},
                $config->{db_password});

   # Get full name of calendar
   my $query = "SELECT DISTINCT calendar from config where is_default = ?";
   $db->query($query, '1');
   my $rows = $db->rowcount();
   croak( my_error("yes", "Default calendar not found.\n") ) if $rows != 1;
   my $temp = $db->result("arrayref");
   $db->finish;
   $config->{default_calendar} = $temp->[0];

   # Get and format today's date
   my $cal = CyberCalendar::Calendar->new($config);
   $today_aref = $CyberCalendar::Calendar::todaysdate;
   $today = "$today_aref->[0]\-$today_aref->[1]\-$today_aref->[2]";
   $t_dateid = "$today_aref->[1]/$today_aref->[2]/$today_aref->[0]";

   bless $hashref, $self;
} # endsub new

sub init {
   my $self = shift || 0;

   # Get HTTP input
   my $http = CyberCalendar::Http->new();
   $http_in = $http->get_input(\%ENV);

   # If there is no calendar name defined in the
   # query string set the calendar to the default.
   $http_in->{Calendar} = $config->{default_calendar} if !exists $http_in->{Calendar} or $http_in->{Calendar} eq '';
   $http_in->{DateID} = $t_dateid if $http_in->{DateID} eq '';

   calendar_config($http_in->{Calendar});

   if ($_[0] ne 'NULL') {
      my $type = $_[0] if $_[0] ne '';
      $http->header(type => $type);
   } # if
} # endsub init

sub show_page {
   my $self = shift || 0;

   # Get the file name from the $config->{template} variable (which contains a path).
   # The reason for doing this is so that if there is an error opening
   # the template file the error message will print out just the filename
   # and not the full physical path to the file.
   my @tmpl_file = split("/", $config->{template}) if $config->{template} =~ /\//;
   @tmpl_file = split("\\134", $config->{template}) if $config->{template} =~ /\\/;

   # Open template page and store it in an array reference
   my $util = CyberCalendar::Util->new();
   my $template = $util->open_template($config->{template}, $tmpl_file[$#tmpl_file]);

   # Search for special tags and execute appropriate chunks o' code.
   if ($config->{show_large_calendar} == 1) {
   SWITCH:
      for (@{ $template }) {
         /(<!-- SHOW_PAGE_TITLE -->)/o && do { print; show_page_title($config->{calendar_name}); next; };
         /(<!-- SHOW_BODY_TAG -->)/o && do { print; show_body_tag(); next; };
         /(<!-- SHOW_LARGE_CALENDAR_AND_DATA -->)/o && do { print; show_large_calendar_and_data(); next; };
         print;
      } # for
   } # if
   else {
   SWITCH:
      for (@{ $template }) { 
         /(<!-- SHOW_PAGE_TITLE -->)/o && do { print; show_page_title($config->{calendar_name}); next; };
         /(<!-- SHOW_BODY_TAG -->)/o && do { print; show_body_tag(); next; };
         /(<!-- SHOW_EVENT_INFO -->)/o && do { print; show_event_info(); next; };
         /(<!-- SHOW_CALENDAR -->)/o && do { print; show_calendar(); next; };
         /(<!-- SHOW_CATEGORIES -->)/o && do { print; show_categories(); next; };
         /(<!-- SHOW_SEARCH -->)/o && do { print; show_search(); next; };
         /(<!-- SHOW_CALENDAR_LIST -->)/o && do { print; show_calendar_list(); next; };
         print;
      } # for
   } # else
   undef $template;
   my_exit();
} # endsub show_page

###################################################################
# Internal (sort of) Subroutines

##
## This subroutine gets the rest of configuration data from the database
##
sub calendar_config {   
   # Get full name of calendar
   my $query = "SELECT name from calendars where calendar = ?";
   $db->query($query, $_[0]);
   my $rows = $db->rowcount();
   croak( my_error("yes", "Calendar not found.\n") ) if $rows != 1;
   my $temp = $db->result("arrayref");
   $db->finish;
   $config->{calendar_name} = $temp->[0];
   
   # Get calendar configuration stored in database
   $query = "SELECT * from config where calendar = ?";
   $db->query($query,"$_[0]");
   $rows = $db->rowcount();
   $temp = $db->result("hashref");

   if ($rows != 1) { croak(my_error("yes", "Configuration for calendar \"$_[0]\" not found!\n")); }
   # if
   else {
      # Add calendar configuration data to %{ $config } hash
      while (my($name, $value) = each(%{ $temp })) { $config->{$name} = $value; }
      # while
   } # else
   $db->finish();
} # endsub calendar_config

sub show_page_title {
   print "<title>$_[0]</title>";
}

sub show_body_tag {
   my $body_content = '';
   if ($config->{body_bg_img} eq "") { $body_content = "bgcolor=\"$config->{body_bg_color}\"" }
   # if
   else { $body_content = "bgcolor=\"$config->{body_bg_color}\" background=\"$config->{body_bg_img}\""}
   # else
   print "<body $body_content>\n";
} # endsub show_body_tag

##
## Determine what event data to display.
##
sub show_event_info {
SWITCH:
   for ($http_in->{View}) {
      /Week/o && do { week_view($_[0]); last; };
      /Day/o && do { day_view(); last; };
      /Event/o && do { event_view(); last; };
      /Search/o && do { search_view(); last; };
      /Category/o && do { category_view(); last; };
      /Message/o && do { message_view(); last; };
      default_view($_[0]); last;
   } # for
} # endsub show_event_info

##################################
# Event Display Subroutines
##################################

sub default_view {
   if ($config->{show_large_calendar} == 1) { large_calendar($_[0]); }
   else { main_view(); }
} # endsub default_view

sub main_view {
   my $nextdate = '';
   my $dateid = '';
   if ($config->{show_days} == 0) {
      $nextdate = $today;
      print qq(<b><div align="center"><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
               Events For: <font color="$config->{page_title_var_color}">
	       $today_aref->[1]/$today_aref->[2]/$today_aref->[0]</font></font></div></b>);
   } # if
   else {
      my $cal = CyberCalendar::Calendar->new();
      my $nextday = [$cal->add_days($config->{show_days}, @{ $today_aref })];
      $nextdate = "$nextday->[0]\-$nextday->[1]\-$nextday->[2]";
      print qq(<b><div align="center"><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
               Events From: <font color="$config->{page_title_var_color}">
               $today_aref->[1]/$today_aref->[2]/$today_aref->[0]</font>
               To: <font color="$config->{page_title_var_color}">
               $nextday->[1]/$nextday->[2]/$nextday->[0]</font></font></div></b>);
   } # else

   my $query = qq(SELECT * from $http_in->{Calendar}
                  WHERE dateid >= ? AND dateid <= ?
                  ORDER BY dateid ASC);
   show_events($query,
               $today,
               $nextdate);
} # endsub main_view

sub week_view {
   my $week = '';
   my $query = '';
   my $i = 0;
   my @mdy = split("/", $http_in->{DateID});
   my $cal = CyberCalendar::Calendar->new();
   my @week = $cal->week_of_year($mdy[2], $mdy[0], $mdy[1]);
   @week = $cal->monday_of_week(@week);
   @week = $cal->minus_days(1, @week);
   my $theweek = "$week[1]/$week[2]/$week[0]";
   @week = $cal->minus_days(1, @week);
   while ($i != 7) {
      $i++;
      $db->finish;
      @week = $cal->add_days(1, @week);
      $query = "SELECT dateid, event_day, event_month, event_year, subject, starttime, repeatid from $http_in->{Calendar}
               WHERE dateid = ? ORDER BY starttime ASC"; 
      $db->query($query, "$week[0]-$week[1]-$week[2]");
      my $rows = $db->rowcount;
      $week .= qq(<td width="14%" valign="top" bgcolor="$config->{cal_bg_color}"><font face="$config->{cal_font}"
               color="$config->{cal_text_color}" size="$config->{cal_dates_font_size}">);
      if ($rows != 0) {
         while (my $tmp = $db->result("hashref")) {
            my $thetime = $cal->hr24_2_hr12($tmp->{starttime});
            $week .= qq(&\#149; <a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=Event&DateID=$tmp->{event_month}/$tmp->{event_day}/$tmp->{event_year}&Repeatid=$tmp->{repeatid}">$thetime $tmp->{subject}</a><br /><br />);
         } # while
      } # if
      else { $week .= "&\#149; No events.&nbsp;"; }
      # else
      $week .= "</font></td>";
   } # while
   $db->finish;
   print <<"WEEKVIEW";
<!-- BEGIN_WEEK_VIEW -->
<table border="0" width="$config->{large_calendar_width}" celpadding="0" cellspacing="1">
<tr>
<td align="center" valign="top" colspan="7"><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
Events for the week of: <font color="$config->{page_title_var_color}">$theweek</font></font></td>
</tr>
<tr bgcolor="$config->{cal_bg_color}">
<td width="14%" align="center" valign="top" bgcolor="$config->{cal_bg_color}"><b><font face="$config->{cal_head_font}" size="2">Sunday</font></b></td>
<td width="14%" align="center" valign="top" bgcolor="$config->{cal_bg_color}"><b><font face="$config->{cal_head_font}" size="2">Monday</font></b></td>
<td width="14%" align="center" valign="top" bgcolor="$config->{cal_bg_color}"><b><font face="$config->{cal_head_font}" size="2">Tuesday</font></b></td>
<td width="14%" align="center" valign="top" bgcolor="$config->{cal_bg_color}"><b><font face="$config->{cal_head_font}" size="2">Wednesday</font></b></td>
<td width="14%" align="center" valign="top" bgcolor="$config->{cal_bg_color}"><b><font face="$config->{cal_head_font}" size="2">Thursday</font></b></td>
<td width="14%" align="center" valign="top" bgcolor="$config->{cal_bg_color}"><b><font face="$config->{cal_head_font}" size="2">Friday</font></b></td>
<td width="14%" align="center" valign="top" bgcolor="$config->{cal_bg_color}"><b><font face="$config->{cal_head_font}" size="2">Saturday</font></b></td></tr>
<tr "$config->{cal_bgcolor}">
$week
</tr>
</table>
<!-- END_WEEK_VIEW -->
WEEKVIEW
} # endsub week_view

sub day_view {
   my $query = qq(SELECT * from $http_in->{Calendar}
                  WHERE dateid = ?
                  ORDER BY starttime ASC);
   my $back_link = '';
   if ($config->{show_large_calendar} == 1) {
      $back_link = qq(<br /><div align="center"><a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&DateID=$http_in->{DateID}"
                   style="text-decoration:none">&lt;&lt;Back</a></div>);
   } # if
   print qq(<b><div align="center"><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
            Events For: <font color="$config->{page_title_var_color}">
            $http_in->{DateID}</font>$back_link</font></div></b>);
   show_events($query, http2dateid());
} # endsub day_view

sub event_view {
   my $query = qq(SELECT * from $http_in->{Calendar}
                  WHERE dateid = ?
                  AND repeatid = ?);
   my $back_link = "$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=Day&DateID=$http_in->{DateID}";
   show_events($query,
               http2dateid(),
               $http_in->{Repeatid});
   print qq(<b><div align="center"><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
            <a href="$back_link" style="text-decoration:none">&lt;&lt;Back</a></font></b></div><br />);
   print event_options($http_in, $config);

   print qq(<br /><b><div align="center"><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
            <a href="$back_link" style="text-decoration:none">&lt;&lt;Back</a></font></b></div><p></p>);
} # endsub event_view

sub search_view {
   my $query = qq(SELECT * from $http_in->{Calendar}
                  WHERE subject LIKE ?
                  OR desctext LIKE ?
                  ORDER BY dateid DESC);
   my $back_link = '';
   if ($config->{show_large_calendar} == 1) {
      $back_link = qq(<br /><div align="center"><a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}"
                   style="text-decoration:none">&lt;&lt;Back</a></div>);
   } # if
   print qq(<div align="center"><font face="$config->{page_title_font}" size="$config->{page_title_font_size}"><b>
            Search Results for Query: <font color="$config->{page_title_var_color}">
            $http_in->{searchtext}</font>$back_link</b></font></div>);

   if ($http_in->{searchtext} eq '') {
      print qq(\n<br /><div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
            Sorry. No events were found that matched your query.</b></font></div><p>&nbsp;</p>\n);
   } # if
   else {
      show_events($query,
                  "%$http_in->{searchtext}%",
                  "%$http_in->{searchtext}%");
   } # else
} # endsub search_view

sub category_view {
   my $query = qq(SELECT * from $http_in->{Calendar}
                  WHERE dateid >= ?
                  AND category = ?
                  ORDER BY dateid ASC);
   my $back_link = '';
   if ($config->{show_large_calendar} == 1) {
      $back_link = qq(<br /><div align="center"><a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&DateID=$t_dateid"
                   style="text-decoration:none">&lt;&lt;Back</a></div>);
   } # if
   print qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
            Category: <font color="$config->{page_title_var_color}">
            $http_in->{Category}</font>$back_link</font></b></div>);

   show_events($query,
               $today,
               $http_in->{Category});
} # endsub category_view

sub message_view {
   print $http_in->{Message};
} # endsub message_view

sub show_events {
   $db->query(@_);
   my $rows = $db->rowcount;
   my $error_string = '';
   my $back_link = '';

   if ($config->{show_large_calendar} == 1) {
      $back_link = qq(<div align="center"><a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&DateID=$t_dateid"
                   style="text-decoration:none">&lt;&lt;Back</a></div><br />);
   } # if
   if ($rows == 0) {
      if ($http_in->{View} eq "Search") {
         $error_string = "Sorry. No events were found that matched your query.<p></p>";
      } # if
      elsif ($http_in->{View} eq "Category") {
         $error_string = "No events found in this category.<p></p>"; 
      } # elsif
      else {
         $error_string = "No Events Found: Please select another date.<p></p>"; 
      } # else
      print qq(<p align="center">
               <b><font face="$config->{page_title_font}"
               size="$config->{page_title_font_size}">
               $error_string\n$back_link</font></b></p>);
   } # if
   else {
      if (!exists $http_in->{View}
	  or $http_in->{View} eq '') { $rows = 1; }
      my $i = 0;
      my $nav_string = '';
      my $prev = -1;
      my $next = 5;
      my $qstring = '';
      # Create by-the-page navigation links if event results are greater than 5
      if ($rows > 5) {
         if ($http_in->{View} eq 'Search') { $http_in->{searchtext} = CyberCalendar::Http::webify('',$http_in->{searchtext}); $qstring = "&searchtext=$http_in->{searchtext}"; }
         if ($http_in->{View} eq 'Category') { $http_in->{Category} = CyberCalendar::Http::webify('',$http_in->{Category}); $qstring = "&Category=$http_in->{Category}"; } 
         if (!exists $http_in->{Next}
	    or $http_in->{Next} == 0
            or $http_in->{Next} == 5) {
            $http_in->{Next} = 5;
            $nav_string = qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
                          <a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=$http_in->{View}&DateID=$http_in->{DateID}&Next=10$qstring"
                          style="text-decoration:none">Next Results &gt;&gt;</a></font></b></div>);
         } # if
         elsif ($http_in->{Next} >= $rows) {
            $prev = $http_in->{Next} - 5;
            $next = $http_in->{Next} + 5;
            $nav_string = qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
                          <a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=$http_in->{View}&DateID=$http_in->{DateID}&Next=$prev$qstring"
                          style="text-decoration:none">&lt;&lt;Previous Results</a></font></b></div>);
         } # elsif
         else {
            $prev = $http_in->{Next} - 5;
            $next = $http_in->{Next} + 5;
            $nav_string = qq(<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">
                          <a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=$http_in->{View}&DateID=$http_in->{DateID}&Next=$prev$qstring"
                          style="text-decoration:none">&lt;&lt;Previous Results</a>&nbsp;&nbsp;&nbsp;
                          <a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=$http_in->{View}&DateID=$http_in->{DateID}&Next=$next$qstring"
                          style="text-decoration:none">Next Results&gt;&gt;</a></font></b></div>);
         } # else
      } # if
      my $cal = CyberCalendar::Calendar->new();
      while (my $event = $db->result("hashref")) {
         # If there are more then 5 event results, display
         # 5 events per page.
         if ($rows > 5) {
            if ($i <= $next
               and $i >= $prev) { $i++; }
            else { $i++; next; }
            if ($i > $http_in->{Next}
               or $i > $rows) { print $nav_string; last; }
         }
         $event = process_event($event, $cal);
	 if ($config->{show_lines} == 0
            or exists $http_in->{Repeatid}) {
            $event->{url} = fix_event_url($event->{url});
            print  event_long($event, $config);
            print $nav_string if $i == $rows;
            next;
         } # if
         elsif ($config->{show_lines} > 0
               and !exists $http_in->{Repeatid}) {
	    print  event_short($event, $config);
            print $nav_string if $i == $rows;
            next;
         } # elsif
         else { croak(my_error("no", "Configuration Error: Unable to display events.\n")); }
         # else
      } # while
   } # else
   $db->finish;
} # endsub show_events

##
## Format event data (i.e. put e-mail addresses in mailto: links
## format 24hr time stored in database to 12hr time, etc.)
##
sub process_event {
   $_[0]->{datetext} = $_[1]->datestring($_[0]->{event_year},
                                         $_[0]->{event_month},
                                         $_[0]->{event_day});
   if ($_[0]->{enddate} != 0) {
      my ($y, $m , $d) = split("-", $_[0]->{enddate});
      my $enddate_datetext = $_[1]->datestring($y, $m, $d);
      $_[0]->{datetext} = "$_[0]->{datetext} - $enddate_datetext";
   } # if
   $_[0]->{starttime} = $_[1]->hr24_2_hr12($_[0]->{starttime});
   if ($_[0]->{endtime} != 0) {
      $_[0]->{endtime} = $_[1]->hr24_2_hr12($_[0]->{endtime});
      $_[0]->{starttime} = "$_[0]->{starttime} - $_[0]->{endtime}";
   } # if
   $_[0]->{contact} = qq(Contact: <a href="mailto:$_[0]->{email}">$_[0]->{email}</a><br />) if $_[0]->{email} ne '';
   if ($http_in->{View} eq "Event") {
      $_[0]->{infolink} = qq(<a href="$config->{print_url}?Calendar=$http_in->{Calendar}&DateID=$_[0]->{event_month}\/$_[0]->{event_day}\/$_[0]->{event_year}&Repeatid=$_[0]->{repeatid}">View Printable Version</a>);
   } # if
   else {
      $_[0]->{infolink} = qq(<a href="$config->{calendar_homepage}$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=Event&DateID=$_[0]->{event_month}\/$_[0]->{event_day}\/$_[0]->{event_year}&Repeatid=$_[0]->{repeatid}">Event Options...</a>);
   } # else
   return $_[0];
} # endsub process_event

##
## This code is seperate from the above subroutine because
## some functions that call process_event() do not need the
## website URL of an event to be linked.
##
sub fix_event_url {
   if ($_[0] ne "") { return qq(<b>Website: <A HREF="$_[0]">$_[0]</A></b><br />); }
   # if
   else { return "<br />"; }
   # else
} # endsub fix_event_url

#
##################################

sub get_date {
   if (exists $http_in->{DateID}) {
      my ($m, $d, $y) = split('/', $http_in->{DateID});
      return ( [$y, $m, $d], http2dateid() );
   } # if
   else {
      return ($today_aref, $today);
  } # else
} # endsub check_date

##
## Displays the large calendar head and calendar controls
## and calls the function that displays the event data.
##
sub show_large_calendar_and_data {
   # Determine dimensions of the large calendar table
   my %dimension = ();
   if ($config->{large_calendar_width} == 595) {
      %dimension = (cal_list_cell => 158,
                    browse_cell => 158,
                    search_cell => 158,
                    help_cell => 116,
                    month_cell => 110,
                    mo_yr_cell => 375,
                    cell_width => 84,
                    cell_height => 84);
   } # if
   elsif ($config->{large_calendar_width} == 581) {
      %dimension = (cal_list_cell => 155,
                    browse_cell => 153,
                    search_cell => 152,
                    help_cell => 116,
                    month_cell => 105,
                    mo_yr_cell => 371,
                    cell_width => 82,
                    cell_height => 82);
   } # elsif
   elsif ($config->{large_calendar_width} == 574) {
      %dimension = (cal_list_cell => 151,
                    browse_cell => 151,
                    search_cell => 151,
                    help_cell => 116,
                    prev_mo_cell => 105,
                    mo_yr_cell => 364,
                    cell_width => 81,
                    cell_height => 81);
   } # elsif
   elsif ($config->{large_calendar_width} == 567) {
      %dimension = (cal_list_cell => 148,
                    browse_cell => 149,
                    search_cell => 147,
                    help_cell => 116,
                    prev_mo_cell => 105,
                    mo_yr_cell => 357,
                    cell_width => 80,
                    cell_height => 80);
   } # elsif
   else {
      $config->{large_calendar_width} = 595;
      %dimension = (cal_list_cell => 158,
                    browse_cell => 158,
                    search_cell => 158,
                    help_cell => 116,
                    month_cell => 110,
                    mo_yr_cell => 375,
                    cell_width => 84,
                    cell_height => 84);
   } # else


   print qq(\n<div align="center">\n<!-- START CALENDAR HEAD -->\n
<table width="$config->{large_calendar_width}" border="0" cellspacing="0" cellpadding="0" align="center">
<tr bgcolor="$config->{cal_trimcolor}"><td align="center" valign="middle">
<table width="$config->{large_calendar_width}" border="0" cellspacing="0" cellpadding="0" align="center">
<tr valign="top" bgcolor="$config->{cal_head_color}"> 
<td align="left" width="$dimension{cal_list_cell}">\n);
   show_calendar_list();
   print qq(\n</td><td width="5">&nbsp;</td><td align="left" width="$dimension{browse_cell}">\n);
   show_categories();
   print qq(\n</td><td align="left" width="$dimension{search_cell}">\n);
   show_search();
   print qq(\n</td><td align="center" width="$dimension{help_cell}">
           <a href="#" onClick="openBrWindow('$config->{help_index}','CalendarHelp','menubar=yes,scrollbars=yes,width=450,height=450')"><img src="$config->{help_img}" height="$config->{help_img_height}" width="$config->{help_img_width}" border="0" alt="$config->{help_img_alt}"></a>
	    </div></td></tr><tr colspan="5"><td colspan="5" align="center" valign="top" bgcolor="$config->{cal_head_color}"><div>);
   show_week_list() if $http_in->{View} ne 'Event';
   print qq(</td></tr></table>\n<!-- END CALENDAR HEAD -->\n);

   show_event_info(\%dimension);

   print "\n</td></tr></table>\n</div>\n";

} # endsub show_large_calendar_and_data

##
## Displays the actual large calendar
##
sub large_calendar {
   my ($dateid_ref, $dateid) = get_date();
   my $cal = CyberCalendar::Calendar->new($config);
   my @cal_data = $cal->prepare_calendar_formatted(@{ $dateid_ref });
   my $query1 = qq(SELECT DISTINCT(dateid), event_month, event_day from $http_in->{Calendar}
                  WHERE dateid >= ?
                  AND dateid <= ?);
   $db->query($query1, $cal_data[5], $cal_data[6]);
   my $events = {};
   while (my $event = $db->result("hashref")) { $events->{"$event->{event_month}\/$event->{event_day}"} = "$event->{dateid}"; }
   # while
   $db->finish;
   my $query2 = qq(SELECT event_year, event_month, event_day , subject, repeatid from $http_in->{Calendar}
                   WHERE dateid = ?
                   AND featured = 1
                   ORDER BY starttime ASC);
   while ( my($name, $value) = each(%{ $events }) ) {
      my $event_ary = [];
      $db->query($query2, $value);
      my $rows = $db->rowcount;
      $events->{$name} = '';
      if ($rows == 0) {
         my ($y, $m, $d) = split("-", $value);         
         $events->{$name} = "&\#149; <a href=\"$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=Day&DateID=$m\/$d\/$y\">Click for events.</a><br />\n";
      } # if
      else {
         while (my $event = $db->result("hashref")) {
            $events->{$name} .= "&\#149; <a href=\"$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=Event&DateID=$event->{event_month}\/$event->{event_day}\/$event->{event_year}&Repeatid=$event->{repeatid}\">$event->{subject}</a><br />\n";
         } # while
      } # else
      $db->finish;
   } # while
   $cal->show_large_calendar_formatted($dateid, $events, @cal_data, $_[0]);
} # endsub large_calendar

##
## Displays the small calendar
##
sub show_calendar {
   if ($config->{show_calendars} > 0
      and $config->{show_calendars} <= 3) {
      my ($dateid_ref, $dateid) = get_date();

      my $cal = CyberCalendar::Calendar->new($config);
      my @cal_data = $cal->prepare_calendar_formatted(@{ $dateid_ref });
      
      my $query = qq(SELECT DISTINCT(dateid), event_month, event_day from $http_in->{Calendar}
                   WHERE dateid >= ?
                   AND dateid <= ?);
      $db->query($query, $cal_data[5], $cal_data[6]);
      my $events = {};
      while (my $event = $db->result("hashref")) { $events->{"$event->{event_month}\/$event->{event_day}"} = ""; }
      # while
      $db->finish;
      
      $cal->calendar_formatted($dateid,
                               $events,
                               @cal_data,
                               $_[0]);
   } # if
   else { croak(my_error("no", "Can't display calendar. Configuration Error.\n")); }
   # else
} # endsub show_calendar

sub show_week_list {
   my ($m, $d, $y) = split("/", $http_in->{DateID});
   my @date = ($y, $m, $d);
   my $cal = CyberCalendar::Calendar->new();
   my $dim = $cal->days_in_month($date[0], $date[1]);
   my $weeks = $dim / 7;
   my $list = '';
   my $submit = '';
   if ($config->{public_event_submit} == 1) {
      $submit = qq(&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<font face="$config->{event_head_font}" size=3><b>
            <a href="$config->{submit_url}?Calendar=$http_in->{Calendar}" style="text-decoration:none"><font color="$config->{cal_head_text_color}">Submit an Event</font></a>
	    </b></font>);
   } # if
   if ($http_in->{View} eq 'Week') {
      my @week = $cal->week_of_year(@date);
      my @monday = $cal->monday_of_week(@week);
      my @nextweek = $cal->add_days(8, @monday);
      @week = $cal->week_of_year(@nextweek);
      my @monday_n = $cal->monday_of_week(@week);
      my @lastweek = $cal->minus_days(6, @monday);
      @week = $cal->week_of_year(@lastweek);
      my @monday_l = $cal->monday_of_week(@week);
   print qq(<div><b><font face ="$config->{event_head_font}" size="3" color="$config->{cal_head_text_color}">
         <a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=Week&DateID=$monday_l[1]/$monday_l[2]/$monday_l[0]"
         style="text-decoration:none"><font color="$config->{cal_head_text_color}">&lt;&lt; Last Week</font></a>&nbsp;&nbsp;&nbsp;
         <a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}" style="text-decoration:none"><font color="$config->{cal_head_text_color}">&\#149;</font></a>
         &nbsp;&nbsp;&nbsp;<a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=Week&DateID=$monday_n[1]/$monday_n[2]/$monday_n[0]"
         style="text-decoration:none"><font color="$config->{cal_head_text_color}">Next Week &gt;&gt;</font></a></font></b></div>);
   } # if
   else {
      $date[2] = 1;
      my $i = 0;
      my $w = 1;
      while ($i <= $weeks) {
         my @week = $cal->week_of_year(@date);
         my @monday = $cal->monday_of_week(@week);
         $list .= qq( <a href="$config->{cal_url}?$config->{site}Calendar=$http_in->{Calendar}&View=Week&DateID=$monday[1]/$monday[2]/$monday[0]"
                  style="text-decoration:none"><font color="$config->{cal_head_text_color}">$w</font></a>&nbsp;);
         @date = $cal->add_days(7, @date);
         $w++;
         $i++;
      } # while
      print qq(<div><b><font face ="$config->{event_head_font}" size="3" color="$config->{cal_head_text_color}">View Week:&nbsp;$list&nbsp;</font></b>$submit</div>);
   } # else
} # endsub show_week_list

##
## Shows the drop-down list of event categories.
##
sub show_categories {
   my $query = qq(SELECT DISTINCT category from $http_in->{Calendar} WHERE dateid >= ? ORDER BY category ASC);
   $db->query($query, $today);
   
   my $c = qq(<!-- START_CATEGORIES -->\n<div><font face ="$config->{event_head_font}" size ="2">
           <form method="post" action="$config->{cal_url}?$config->{site}">\n<div><select name="Category"><option value="" SELECTED>Filter by...</option>);

   while ( my $tmp = $db->result("hashref")) {
      my ($name, $value) = each(%{ $tmp });
      $c .= "<option value=\"$value\">$value</option>";
   } # while
   $db->finish;
   $c .= qq(</select>\n<input type="hidden" name="Calendar" value="$http_in->{Calendar}" />
         <input type="hidden" name="View" value="Category" /></div>\n<div>
         <input type="image" name="$config->{browse_img_alt}" src="$config->{browse_img}" height="$config->{browse_img_height}"
         width="$config->{browse_img_width}"  border=0 valign="top" /></div>\n</form></font></div>\n<!-- END_CATEGORIES -->\n);
   print $c;
} # endsub show_categories

##
## Spits out the search box.
##
sub show_search {
   print qq(<!-- START_SEARCH_BOX -->\n<div><font face="$config->{cal_head_font}" size="2">
<form method="POST" action="$config->{cal_url}?$config->{site}">
<div><input type="text" name="searchtext" size="15" maxlength="255" />
<input type="hidden" name="Calendar" value="$http_in->{Calendar}" />
<input type=hidden name=View value=Search /></div>
<div><input type="image" name="$config->{search_img_alt}" src="$config->{search_img}" height="$config->{search_img_height}"
width="$config->{search_img_width}" border=0 valign="top" /></div>
</form>
</font></div>\n<!-- END_SEARCH_BOX -->
);
} # endsub show_search

##
## Displays the calendar list.
##
sub show_calendar_list {
   my $post_to = "$config->{cal_url}?$config->{site}";
   $post_to = $_[3] if $_[3] ne '';
   my $button = $config->{cal_img};
   $button = $_[4] if $_[4] ne '';
   # Picks a query based on whether the calling subroutine passed
   # access level information.
   my $query = "SELECT calendar, name from calendars WHERE is_visible = 1 ORDER BY name ASC";
   $query = "SELECT calendar, name from calendars ORDER BY name ASC" if $_[1] == 1;
   $query = "SELECT acl.calendar, calendars.name from acl, calendars WHERE acl.uid = $_[0] AND acl.calendar = calendars.calendar ORDER BY calendars.name ASC" if $_[1] > 1;
   $query = "SELECT acl.calendar, calendars.name from acl, calendars
            WHERE acl.uid = $_[0]
            AND acl.full_ctrl = 1
            AND acl.calendar = calendars.calendar
            ORDER BY calendars.name ASC" if $_[1] == 3;
   $db->query($query);
   my $rows = $db->rowcount;
   if ($rows > 1) {
      my $current_cal = '';
      my $cals = '';
      while (my $tmp = $db->result("arrayref")) {
         $current_cal = $tmp->[1] if $tmp->[0] eq $http_in->{Calendar}; 
         $cals .= "<option value=\"$tmp->[0]\">$tmp->[1]</option>";
      } # while
      my $cal = qq(<!-- START_CAL_LIST -->\n<div><font face ="$config->{event_head_font}" size ="2"><form method="post" action="$post_to">
                <div><select name="Calendar"><option value="$http_in->{Calendar}" SELECTED>$current_cal</option>);
      $cal .= qq($cals</select>$_[2]</div><div><input type="image" name="$config->{cal_img_alt}" src="$button" height="$config->{cal_img_height}"
              width="$config->{cal_img_width}" border=0 valign="top" /></div></form></font></div>\n<!-- END_CAL_LIST -->);
      print $cal;
   } # if
   else {
      if ($config->{show_large_calendar} == 1) {
         my $cal_ary = $db->result("arrayref");
         print qq(\n<div>&nbsp;&nbsp;<font face ="$config->{event_head_font}" color="$config->{event_head_text_color}" size ="3"><b>$cal_ary->[1]</b></font></div>);
      }
   } # else
   $db->finish;
} # endsub show_calendar_list

sub http2dateid {
   my ($m, $d, $y) = split("/", $http_in->{DateID});
   return "$y\-$m\-$d";
} # endsub http2dateid

# A simple subroutine to print out errors to the browser
sub my_error {
   if ($_[0] eq "yes") {
      my $h = CyberCalendar::Http->new();
      $h->header(type => 'text/html');
   }
   print <<ERRORMSG;
<html><head><title>CyberCalendar: ERROR</title></head>
<body bgcolor="#FFFFFF"><div align="center">
<table border="0" width="450" align="center"><tr><td bgcolor="#C0C0C0">
<b><font face="$config->{page_title_font}" color="red">ERROR:</font> $_[1]</b><p></p>
</td></tr>
</table>
</div>
</body></html>
ERRORMSG
} # endsub my_error

sub my_exit {
   $db->disconnect;
   # Determine how to properly exit
   if (exists $http_in->{mod_perl}) { Apache::exit(0); }
   # if
   else { CORE::exit(0); }
   # else
} # endsub my_exit

#===============================================================================
# Here Documents
#===============================================================================

sub event_long {
   my $event_head_color = $_[1]->{event_head_color};
   my $event_head_text_color = $_[1]->{event_head_text_color};
   $event_head_color = $_[1]->{featured_head_color} if $_[0]->{featured} == 1;
   $event_head_text_color = $_[1]->{featured_head_text_color} if $_[0]->{featured} == 1;
############################################################
   return <<"EVENTLONG";
\n<!-- BEGIN EVENT -->
<table border="0" align="center">
<tr><td align="center" valign="top">
<table cellspacing="0" cellpadding="0" border="0" align="center">
<tr align="center" valign="middle">
<td align="center" valign="middle">
<table cellspacing="0" cellpadding="0" border="0" width="425">
<tr><td align="left" bgcolor="$event_head_color">
<font color="$event_head_text_color" size="$_[1]->{event_head_font_size}" face="$_[1]->{event_head_font}">
&nbsp;&nbsp;<b>$_[0]->{subject}</b>
</font>
</td></tr>
<tr><td align="left" valign="top" bgcolor="$_[1]->{event_body_bgcolor}">
<table cellpadding="5" border="0" align="left" valign="top" bgcolor="$_[1]->{event_body_bgcolor}">
<tr><td align="left" valign="top" bgcolor="$_[1]->{event_body_bgcolor}" width="425">
<font color="$_[1]->{event_body_text_color_detail}" size="$_[1]->{event_body_font_size}" face="$_[1]->{event_body_font}"><b>
 Date: $_[0]->{datetext}<br />
 Time: $_[0]->{starttime}<br />
 Location: $_[0]->{location}<br />
 Category: $_[0]->{category}<br />
 $_[0]->{contact}
 $_[0]->{url}<br />
</b></font>
<font size="$_[1]->{event_body_font_size}" color="$_[1]->{event_body_text_color_body}" face="$_[1]->{event_body_font}">
<b>$_[0]->{desctext}</b><br /><br />
<font size="-2">$_[0]->{infolink}
</font>
</font></td></tr></table>
</td></tr></table></td></tr></table></td></tr></table>
<!-- END EVENT -->\n
EVENTLONG
############################################################
} # endsub event_long

sub event_short {
   my $event_head_color = $_[1]->{event_head_color};
   my $event_head_text_color = $_[1]->{event_head_text_color};
   $event_head_color = $_[1]->{featured_head_color} if $_[0]->{featured} == 1;
   $event_head_text_color = $_[1]->{featured_head_text_color} if $_[0]->{featured} == 1;
   my $text = '';
   # Display the number of lines defined in
   # $config->{show_lines}
   if ($_[0]->{desctext} =~ /<br\/>/o) {
      my @text = split(/<br \/>/, $_[0]->{desctext});
      if ($#text > $_[1]->{show_lines}) {
         @text = map { qq($_<br />) } splice(@text, 0, $_[1]->{show_lines});
	 $text = @text;
         $text .=  "...";
      } # if
      else { $text = $_[0]->{desctext}; }
   } # if
   else {
      my $textlen = length($_[0]->{desctext});
      my $show = $_[1]->{show_lines} * $_[1]->{line_length};
      if ($textlen > $show) { $text = substr($_[0]->{desctext}, 0, $show) . "..."; }
      else { $text = $_[0]->{desctext}; }
   } # else
############################################################
return <<"EVENTSHORT";
\n<!-- BEGIN EVENT -->
<table cellspacing="4" cellpadding="0" border="0" align="center">
<tr align="center" valign="middle"><td align="center" valign="middle">
<table cellspacing="0" cellpadding="0" border="0" width="425">
<tr><td align="left" bgcolor="$event_head_color">
<font color="$event_head_text_color" size="$_[1]->{event_head_font_size}" face="$_[1]->{event_head_font}">
&nbsp;&nbsp;<b>$_[0]->{subject}</b>
</font></td></tr>
<tr><td align="left" valign="top" bgcolor="$_[1]->{event_body_bgcolor}">
<table cellpadding="5" border="0" align="left" valign="top" bgcolor="$_[1]->{event_body_bgcolor}">
<tr><td align="left" valign="top" bgcolor="$_[1]->{event_body_bgcolor}" width="425">
<font color="$_[1]->{event_body_text_color_detail}" FACE="$_[1]->{event_body_font}">
<font size="$_[1]->{event_body_font_size}"><b>
 Date: $_[0]->{datetext}<br />
 Time: $_[0]->{starttime}
</b><p align="left">
<font color="$_[1]->{event_body_text_color_body}">
<b>$text<br /></font></font>
<font size="-2">$_[0]->{infolink}</font></b>
</font></p></td></tr></table></td></tr>
</table></td></tr></table>
<!-- END EVENT -->\n
EVENTSHORT
############################################################
} # endsub event_short

sub event_options {
############################################################
return <<"EVENTOPTIONS";
\n<!-- BEGIN OPTIONS -->
<table width="400" align="center" border="0" cellspacing="0" cellpadding="0"><tr bgcolor="$_[1]->{cal_trimcolor}"><td align="center">
<table border="0" align="center"><tr bgcolor="$_[1]->{event_head_color}"><td align="left">
<font face="$_[1]->{event_head_font}"><b><font size="+1" color="$_[1]->{event_head_text_color}">&nbsp;Event Options:</font></b></font>
</td></tr><tr bgcolor="$_[1]->{event_body_bgcolor}"><td align="center"> 
<div align="center"> 
<font face="arial,helvetica"><b>E-mail this Event to a Friend</b></font><br />
</div>
<!-- BEGIN MAIL FORM -->
<form method="post" action="$_[1]->{formproc_url}">
<table width="100%" border="0" cellspacing="0" cellpadding="0" align="center"><tr valign="top"><td width="11%">
<font face="$_[1]->{event_body_font}"><b>&nbsp;From:&nbsp;</b></font>
</td><td width="89%" valign="top" align="left">
<font face="$_[1]->{event_body_font}">
<input type="text" name="from_email" size="25" maxlength="255" value="Your e-mail here. " />
</font>
</td></tr><tr bgcolor="$_[1]->{event_body_bgcolor}"><td valign="top" align="left"> 
<font face="$_[1]->{event_body_font}"><b>&nbsp;To:&nbsp;</b></font>
</td><td width="89%" valign="top" align="left">
<font face="$_[1]->{event_body_font}">
<input type="text" name="to_email" size="25" maxlength="255" />
</font>
</td></tr><tr valign="top"><td width="11%" align="left">
<font face="$_[1]->{event_body_font}"><b>&nbsp;Note:&nbsp;</b></font>
</td><td width="89%" align="left">
<font face="$_[1]->{event_body_font}"> 
<textarea name="note" cols="25" rows="3" wrap="PHYSICAL"></textarea>
</font>
</td></tr><tr valign="top"><td colspan="2" align="left">
<font face="$_[1]->{event_body_font}"><b>&nbsp;Send E-mail as HTML?&nbsp;<input type="checkbox" name="html_mail" value="yes" /></b></font>
</td></tr></table>
<br />
<!-- BEGIN NOTE -->
<div align="center">
<table border="0" width="400" align="center"><tr bgcolor="$_[1]->{cal_trimcolor}"><td>
<font face="$_[1]->{event_body_font}" size="-1"><i>&nbsp;<b>NOTE:</b> 
You can send this message to multiple recipients by entering 
more than one e-mail address in the "To:" field separated by commas.<br />
Ex: shawn\@foo.org, mary\@bar.net, kathy\@baz.com </i></font>
</td></tr></table>
</div>
<!-- END NOTE -->
<div align="center">
<input type="hidden" name="Calendar" value="$_[0]->{Calendar}" />
<input type="hidden" name="View" value="Options" />
<input type="hidden" name="FormAction" value="SendMail" />
<input type="hidden" name="DateID" value="$_[0]->{DateID}" />
<input type="hidden" name="Repeatid" value="$_[0]->{Repeatid}" />
<input type="submit" name="submit" value="Send E-Mail" />
</div>
</form>
<!-- END MAIL FORM -->
</td></tr><tr bgcolor="$_[1]->{event_body_bgcolor}"><td align="center">
<font face="$_[1]->{event_body_font}"><b>Receive an Event Reminder via E-mail</b></font><br />
<!-- BEGIN REMINDER FORM-->
<form method="POST" action="$_[1]->{formproc_url}">
<div align="left">
<font face="$_[1]->{event_body_font}"><b>&nbsp;Receive the reminder:&nbsp;</b></font> 
<select name="when">
<option value="0" selected>When?</option>
<option value="0">On the same day as the event.</option>
<option value="1">1 day before the event.</option>
<option value="2">2 days before the event.</option>
<option value="5">5 days before the event.</option>
<option value="7">7 days before the event.</option>
</select><br />
<font face="$_[1]->{event_body_font}"><b>&nbsp;E-mail:&nbsp;</b>
<input type="text" name="to_email" value="Your e-mail here. " size="25" maxlength="255" />
<br />
<b>&nbsp;Receive E-mail as HTML? <input type="checkbox" name="html_mail" value="yes" /></b></font>
</div>
<br />
<!-- BEGIN NOTE --> 
<div align="center">
<table border="0" width="400" align="center"><tr bgcolor="$_[1]->{cal_trimcolor}"><td>
<font face="arial,helvetica" size="-1"><i>&nbsp;<b>NOTE:</b> 
You can send this reminder to multiple recipients by entering 
more than one e-mail address separated by commas.<br />
Ex: shawn\@foo.org, mary\@bar.net, kathy\@baz.com </i></font>
</td></tr></table>
</div>
<!-- END NOTE -->
<div align="center">
<input type="hidden" name="Calendar" value="$_[0]->{Calendar}" />
<input type="hidden" name="Repeatid" value="$_[0]->{Repeatid}" />
<input type="hidden" name="DateID" value="$_[0]->{DateID}" />
<input type="hidden" name="View" value="Options" />
<input type="hidden" name="FormAction" value="Reminder" />
<input type="submit" name="submit" value="Save Reminder" />
</div>
</form>
<!-- END REMINDER FORM -->
</td></tr><tr bgcolor="$_[1]->{event_body_bgcolor}"><td align="center">
<font face="$_[1]->{event_body_font}"><b>Download vCalendar file for this event to import into your personal calendaring or scheduling program:
<!-- BEGIN VCAL LINK -->
<a href="$_[1]->{vcal_url}?Calendar=$_[0]->{Calendar}&DateID=$_[0]->{DateID}&Repeatid=$_[0]->{Repeatid}">Download</a></b></font>
<!-- END VCAL LINK -->
</td></tr></table>
</td></tr></table>
<!-- END OPTIONS -->
EVENTOPTIONS
############################################################
} # endsub event_options

#===============================================================================

sub DESTROY {
   my $self = shift || 0;
   my $input = {};
} # endsub DESTROY
1;
