package CyberCalendar::Calendar;
###################################################################
# CyberCalendar v1.8.2
#
# Calendar Functions Module
# Copyright 1999, 2000, 2001 Shawn Ewald <shawn@cyberweavers.com>
#
###################################################################
# License:                                                        #
# ----------------------------------------------------------------#
# This program is free software; you can redistribute it and/or   #
# modify it under the terms of the GNU General Public License     #
# as published by the Free Software Foundation; either version 2  #
# of the License, or (at your option) any later version.          #
#                                                                 #
# This program is distributed in the hope that it will be useful, #
# but WITHOUT ANY WARRANTY; without even the implied warranty of  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
###################################################################
# For the full text of the GNU General Public License, go to:     #
# http://www.gnu.org/copyleft/gpl.html                            #
###################################################################
# IMPORT MODULES
use vars qw($config $todaysdate);
use Date::Calc qw(Today Now Calendar Day_of_Week Week_of_Year Monday_of_Week
                  Days_in_Month Delta_Days Add_Delta_Days Date_to_Text_Long
                  Decode_Month Month_to_Text);
use strict;
###################################################################
# Callable Methods

sub new {
   my $self = shift || 0;
   $config = $_[0];
   $todaysdate = [Today()];
   my $arrayref = [];
   bless $arrayref, $self;
} # endsub new

sub timenow {
   my $self = shift || 0;
   return sprintf("%02d:%02d:%02d", Now());
} # endsub timenow

sub datenow {
   my $self = shift || 0;
   return sprintf("%d-%d-%d", Today());
} # endsub datenow

sub datestring {
   my $self = shift || 0;
   return Date_to_Text_Long(@_);
} # endsub datestring

sub hr24_2_hr12 {
   my $self = shift || 0;
   my $am_pm = '';
   my $the_time = '';
   my ($h, $m, $s) = split(":", $_[0]);
   if ($h == 0) { $the_time = "TBA"; }
   elsif ($h < 12 or $h == 24) {
      $am_pm = "AM";
      $h = $h - 12 if $h == 24;
      $the_time = sprintf("%d:%02d $am_pm", ($h, $m));
   } # elsif
   else {
      $am_pm = "PM";
      $h = $h - 12 if $h != 12;
      $the_time = sprintf("%d:%02d $am_pm", ($h, $m));
   } # else
   return $the_time;
}

sub week_of_year {
   my $self = shift || 0;
   return Week_of_Year(@_);
}

sub monday_of_week {
   my $self = shift || 0;
   return Monday_of_Week(@_);
}

sub vcal_date {
   my $self = shift || 0;
   my ($y, $mo, $d) = split("-", $_[0]);
   my ($h, $min, $s) = split(":", $_[1]); 
   return sprintf("%04d%02d%02dT%02d%02d%02d", ($y, $mo, $d, $h, $min, $s));
} # endsub process_event

sub add_days {
   my $self = shift || 0;
   my $add_by = shift(@_);
   return Add_Delta_Days(@_, +$add_by);
} # endsub add_days

sub minus_days {
   my $self = shift || 0;
   my $minus_by = shift;
   return Add_Delta_Days(@_, -$minus_by);
} # endsub minus_days

sub delta_days {
   my $self = shift || 0;
   return Delta_Days(@_);
}

sub days_in_month {
   my $self = shift || 0;
   return Days_in_Month($_[0], $_[1]);
}

sub calendar {
   my $self = shift || 0;
   return [split(/\s+/, Calendar($_->[0], $_->[1]))];
} # endsub calendar

sub prepare_calendar_formatted {
   my $self = shift || 0;
   my $a_month = \@_;
   $a_month->[2] = 1;
###############################
# Create Month Arrays
   my @months = ();
   my @calendars = ();
   $config->{show_calendars} = 1 if $config->{show_large_calendar} == 1;
   my $show_calendars = $config->{show_calendars} - 1;

   @months = map { make_months($_,$a_month) } (0..$show_calendars);
   @calendars = map { calendar($_) } @months;

###############################

   my $i = 0;
   my $days_add = 0;
   my @dim = ();
   my @dow = ();
   my @ldow = ();

LOOP:
   while ($i != $config->{show_calendars}) {
      my $dim = Days_in_Month($months[$i][0], $months[$i][1]);
      push(@dim, $dim);

      $days_add = $days_add+$dim;

      my $dow = Day_of_Week($months[$i][0], $months[$i][1], 1);
      push(@dow, $dow);

      my $ldow = Day_of_Week($months[$i][0], $months[$i][1], $dim);
      push(@ldow, $ldow);

      $i++;
   } # while

   my $sdate = "$months[0][0]\-$months[0][1]\-1";
   my $edate = "$months[$show_calendars][0]\-$months[$show_calendars][1]\-$dim[$show_calendars]";


   my @prm = @{ $months[0] };
   $prm[1] = $prm[1] - $config->{show_calendars};
   if ($prm[1] == 0) { $prm[1] = 12; $prm[0] = $prm[0]-1; }
   if ($prm[1] == -1) { $prm[1] = 11; $prm[0] = $prm[0]-1; }
   if ($prm[1] == -2) { $prm[1] = 10; $prm[0] = $prm[0]-1; }

   my @nxm = Add_Delta_Days(@{ $months[0] }, +$days_add);

   $prm[2] = 1;
   $nxm[2] = 1;

   return (\@months, \@calendars, \@dim, \@dow, \@ldow, $sdate, $edate, \@prm, \@nxm);
} # endsub prepare_calendar_formatted

sub show_large_calendar_formatted {
   my $self = shift || 0;

   my $dateid = shift;
   my $events = shift;
   my $months = shift;
   my $cal = shift;
   my $dim = shift;
   my $dow = shift;
   my $ldow = shift;
   my $sdate = shift;
   my $edate = shift;
   my $prm = shift;
   my $nxm = shift;
   my $dimension = shift;
   my $prev_month = Month_to_Text($prm->[1]);
   my $next_month = Month_to_Text($nxm->[1]);
   shift(@{ $cal->[0] });
   my $head = [splice(@{ $cal->[0] }, 0, 9)];
   my $this_month = Decode_Month($head->[0]);
   my $this_year = $head->[1];

############################################################
   print <<"LGCALTOP";
<table width="$config->{large_calendar_width}" height="25" align="center" border="0" bgcolor="$config->{cal_bg_color}" cellpadding="0" cellspacing="0">
<tr bgcolor="$config->{cal_bg_color}"> 
<td align=left valign="center" height="25" width="$dimension->{month_cell}">&nbsp;<a href="$config->{cal_url}?Calendar=$config->{calendar}&DateID=$prm->[1]\/$prm->[2]\/$prm->[0]"
style="text-decoration:none"><font face="$config->{cal_head_font}"><b><font size="2">&lt;&lt; $prev_month</font></b></font></a></td>
<td align="center" width="$dimension->{mo_yr_cell}" height="25"><font size="7"><font face="$config->{cal_head_font}" size="+3"><b>
$head->[0] $head->[1]</b></font></font></td>
<td align="right" valign="center" height="25" width="$dimension->{month_cell}"> <a href="$config->{cal_url}?Calendar=$config->{calendar}&DateID=$nxm->[1]\/$nxm->[2]\/$nxm->[0]"
style="text-decoration:none">
<font face="$config->{cal_head_font}"><b><font size="2">$next_month &gt;&gt;</font></b></font></a>&nbsp;</td>
</tr></table>

<table width="$config->{large_calendar_width}" border="0" cellpadding="0" cellspacing="1" align="center">
<tr width="100%" valign="top"> 
<td align="left" width="$dimension->{cell_width}" height="15" bgcolor="$config->{cal_bg_color}"> 
<div align="center"><b><font face="$config->{cal_head_font}" size="2">
$head->[8]day
</font></b></div></td>
<td align="left" width="$dimension->{cell_width}" height="15" bgcolor="$config->{cal_bg_color}"> 
<div align="center"><b><font face="$config->{cal_head_font}" size="2">
$head->[2]day
</font></b></div></td>
<td align="left" width="$dimension->{cell_width}" height="15" bgcolor="$config->{cal_bg_color}">
<div align="center"><b><font face="$config->{cal_head_font}" size="2">
$head->[3]sday
</font></b></div></td>
<td align="left" width="$dimension->{cell_width}" height="15" bgcolor="$config->{cal_bg_color}">
<div align="center"><b><font face="$config->{cal_head_font}" size="2">
$head->[4]nesday
</font></b></div></td>
<td align="left" width="$dimension->{cell_width}" height="15" bgcolor="$config->{cal_bg_color}">
<div align="center"><b><font face="$config->{cal_head_font}" size="2">
$head->[5]rsday
</font></b></div></td>
<td align="left" width="$dimension->{cell_width}" height="15" bgcolor="$config->{cal_bg_color}">
<div align="center"><b><font face="$config->{cal_head_font}" size="2">
$head->[6]day
</font></b></div></td>
<td align="left" width="$dimension->{cell_width}" height="15" bgcolor="$config->{cal_bg_color}">
<div align="center"><b><font face="$config->{cal_head_font}" size="2">
$head->[7]urday
</font></b></div></td></tr>
LGCALTOP

   my $date_table_start = qq(<table width="18" border="0" cellpadding="0" cellspacing="0"><tr bgcolor="$config->{cal_trimcolor}"><td><b><font face="$config->{cal_font}" color="$config->{cal_text_color}" size="2">);
   my $date_table_end = "</font></b></td></tr></table>";
############################################################
   my ($sblank, $eblank) = get_blanks(0, $dow, $ldow);
   my @days = map { match_events_large_calendar($_, $events, $this_month, $this_year, $date_table_start, $date_table_end, $dimension) } @{ $cal->[0] };
   my $sblanks = [];
   if ($sblank > 0) {
      $sblanks =  [blank_maker([0..$sblank],
                               'left',
                               'top',
                               $dimension->{cell_width},
                               $dimension->{cell_height},
                               ' ',
                               '&nbsp;&nbsp;&nbsp;')];
      shift(@{ $sblanks });
      unshift(@days, @{ $sblanks });
   } # if
   my $eblanks = [];
   if ($eblank > 0) {
      $eblanks =  [blank_maker([0..$eblank],
                               'left',
                               'top',
                               $dimension->{cell_width},
                               $dimension->{cell_height},
                               ' ',
                               '&nbsp;&nbsp;&nbsp;')];
      shift(@{ $eblanks });
      push(@days, @{ $eblanks });
   } # if
   print_weeks(@days);
   print "\n</table>\n";
} # endsub show_large_calendar_formatted

sub calendar_formatted {
   my $self = shift || 0;

   my $dateid = shift;
   my $events = shift;
   my $months = shift;
   my $calendars = shift;
   my $dim = shift;
   my $dow = shift;
   my $ldow = shift;
   my $sdate = shift;
   my $edate = shift;
   my $prm = shift;
   my $nxm = shift;
   my $session = shift;

   my $pmonth_abrev = substr(Month_to_Text($prm->[1]), 0, 3);
   my $nmonth_abrev = substr(Month_to_Text($nxm->[1]), 0, 3);
   $session = "&session=$session" if $session ne '';
   my $cal_url = $CyberCalendar::Application::config->{cal_url};
   $cal_url = $CyberCalendar::Application::config->{admin_url} if $session ne '';
   my $help_url = $config->{help_index};
   $help_url = "help/help_index.html" if $session ne '';;
   my $submit_link = qq(<br /><a href="$config->{submit_url}?Calendar=$CyberCalendar::Application::http_in->{Calendar}"><font color="$config->{cal_head_text_color}">&gt;&gt; Submit an Event &lt;&lt;</font></a>)
      if $config->{public_event_submit} == 1;
   $submit_link = '' if $session ne '';
#######################################
# Months
#######################################

print <<"CALTOP";
<table border="0" width="126" cellpadding="0" cellspacing="1">
<tr bgcolor="$config->{cal_trimcolor}"> 
<td align="center">
<table width="126" border="0" align="center" cellpadding="0" cellspacing="1">
<tr><td>
<table width="100%" border="0" cellpadding="0" cellspacing="0">
<tr colspan="7" valign="top" bgcolor="$config->{cal_head_color}"> 
<td align="left" valign="top">
<font face="$config->{cal_head_font}" size="$config->{cal_head_font_size}">
<b><a href="$cal_url?Calendar=$config->{calendar}&View=Day&DateID=$prm->[1]\/$prm->[2]\/$prm->[0]$session"><font color="$config->{cal_head_text_color}">&lt;$pmonth_abrev</font></a>
</font></td>
<td align="center" valign="top">
<font face="$config->{cal_head_font}" size="$config->{cal_head_font_size}">
<b><a href="$cal_url?Calendar=$config->{calendar}&View=Day&DateID=$todaysdate->[1]/$todaysdate->[2]/$todaysdate->[0]$session"><font color="$config->{cal_head_text_color}">Today</font></a>
</b></font></td>
<td align="right" valign="top">
<font face="$config->{cal_head_font}" size="$config->{cal_head_font_size}">
<b><a href="$cal_url?Calendar=$config->{calendar}&View=Day&DateID=$nxm->[1]\/$nxm->[2]\/$nxm->[0]$session"><font color="$config->{cal_head_text_color}">$nmonth_abrev&gt;</font></a></b></font></td>
</tr></table>
CALTOP
############################################################
   my $a = 0;
LOOP:
   foreach my $cal (@{ $calendars }) {
      shift(@{ $cal });
      
      my $head = [splice(@{ $cal }, 0, 9)];
      my $this_month = Decode_Month($head->[0]);
      my $this_year = $head->[1];
############################################################
print <<"CALHEAD";
<tr bgcolor="$config->{cal_bg_color}"><td>
<table width="100%" cellspacing="0" cellpadding="1" border="0">
<tr width="100%" bgcolor="$config->{cal_bg_color}"> 
<td colspan="7" align="center">
<font color="$config->{cal_text_color}" size="$config->{cal_month_year_fontsize}" face="$config->{cal_font}">
<b>$head->[0] $head->[1]</b></font>
</td></tr>
<tr width="100%" bgcolor="$config->{cal_bg_color}"> 
<td align="center" width="18" height="14" valign="bottom">
<font face = "$config->{cal_font}" color="$config->{cal_text_color}" size="$config->{cal_days_font_size}">
$head->[8]</font></td>
<td align="center" width="18" height="14" VALIGN="BOTTOM">
<font face = "$config->{cal_font}" color="$config->{cal_text_color}" size="$config->{cal_days_font_size}">
$head->[2]</font></td>
<td align="center" width="18" height="14" valign="bottom">
<font face = "$config->{cal_font}" color="$config->{cal_text_color}" size="$config->{cal_days_font_size}">
$head->[3]</font></td>
<td align="center" width="18" height="14" valign="bottom">
<font face = "$config->{cal_font}" color="$config->{cal_text_color}" size="$config->{cal_days_font_size}">
$head->[4]</font></td>
<td align="center" width="18" height="14" valign="bottom">
<font face = "$config->{cal_font}" color="$config->{cal_text_color}" size="$config->{cal_days_font_size}">
$head->[5]</font></td>
<td align="center" width="18" height="14" valign="bottom">
<font face = "$config->{cal_font}" color="$config->{cal_text_color}" size="$config->{cal_days_font_size}">
$head->[6]</font></td>
<td align="center" width="18" height="14" valign="bottom">
<font face = "$config->{cal_font}" color="$config->{cal_text_color}" size="$config->{cal_days_font_size}">
$head->[7]</font></td></tr>
CALHEAD
############################################################
      my ($sblank, $eblank) = get_blanks($a, $dow, $ldow);
      my @days = map { match_events_small_calendar($_, $events, $this_month, $this_year, $cal_url, $session) } @{ $cal };
      my $sblanks = ();
      if ($sblank > 0) {
         $sblanks =  [blank_maker([0..$sblank],
                                  'right',
                                  'bottom',
                                  '18',
                                  '14',
                                  $config->{cal_dates_font_size},
                                  '&nbsp;&nbsp;&nbsp;')];
         shift(@{ $sblanks });
         unshift(@days, @{ $sblanks });
      } # if
      my $eblanks = ();
      if ($eblank > 0) {
         $eblanks =  [blank_maker([0..$eblank],
                                  'right',
                                  'bottom',
                                  '18',
                                  '14',
                                  $config->{cal_dates_font_size},
                                  '&nbsp;&nbsp;&nbsp;')];
         shift(@{ $eblanks });
         push(@days, @{ $eblanks });
      } # if
      print_weeks(@days);
      print qq(</table></td></tr>);
      $a++;
   } # foreach
############################################################

print <<"CALEND";
<tr valign="top" bgcolor="$config->{cal_head_color}">
<td align="center" valign="top">
<font face="$config->{cal_head_font}" size="$config->{cal_head_font_size}"><b>
<a href="#" onClick="openBrWindow('$help_url','CalendarHelp','menubar=yes,scrollbars=yes,width=450,height=450')">
<font color="$config->{cal_head_text_color}">&gt;&gt; Calendar Help &lt;&lt;</font></a>$submit_link
</b></font>
</td></tr>
</table>
</td></tr></table>\n\n
CALEND

} # endsub calendar_formatted

###################################################################
# Internal Subroutines

sub make_months {
   my $add_by = "";
   if ($_[0] == 0) { $add_by = $_[0]; }
   elsif ($_[0] == 1) { $add_by = Days_in_Month($_[1]->[0], $_[1]->[1]); }
   elsif ($_[0] == 2) {
      $add_by = Days_in_Month($_[1]->[0], $_[1]->[1]);
      my $temp_days = [Add_Delta_Days(@{ $_[1] }, +$add_by)];
      $add_by = $add_by + Days_in_Month($temp_days->[0], $temp_days->[1]);
   } # elsif
   return [Add_Delta_Days(@{ $_[1] }, +$add_by)];
} # endsub make_months

sub match_events_large_calendar {
   my $bg_color = $config->{cal_bg_color};
   my $date_cmp = "$_[2]\/$_";
   $bg_color = $config->{cal_trimcolor} if $date_cmp eq "$todaysdate->[1]/$todaysdate->[2]";
   if (exists $_[1]->{"$date_cmp"}) {
      my $date_link = "$config->{cal_url}?Calendar=$config->{calendar}&View=Day&DateID=$date_cmp\/$_[3]";
      $_ = qq(<a href="$date_link">$_</a>);
      $bg_color = $config->{featured_head_color};
   } # if 
   $_ = qq(<td align="left" width="$_[6]->{cell_width}" height="$_[6]->{cell_height}" bgcolor="$bg_color" valign="top"><font face="$config->{cal_font}"
        color="$config->{cal_text_color}">$_[4]$_$_[5]<font size="$config->{cal_dates_font_size}">$_[1]->{"$date_cmp"}</font></font></td>);
} # endsub match_events_large_calendar


sub match_events_small_calendar {
   my $text_color = $config->{cal_text_color};
   my $date_cmp = "$_[2]\/$_";
   $text_color = $config->{featured_link_color} if $date_cmp eq "$todaysdate->[1]/$todaysdate->[2]";
   my $i = '&nbsp;' if $_ < 10;
   if (exists $_[1]->{"$date_cmp"}) {
      my $date_link = "$_[4]?Calendar=$config->{calendar}&View=Day&DateID=$date_cmp\/$_[3]$_[5]";
      $_ = qq(<a href="$date_link" style="color: $text_color">$_</a>);

   } # if
   $_ = qq(<td align="right" width="18" height="14" bgcolor="$config->{cal_bg_color}" valign="bottom"><font face="$config->{cal_font}"
        color="$text_color" size="$config->{cal_dates_font_size}">&nbsp;$_$i</font></td>);
} # endsub match_events_small_calendar

sub print_weeks {
   #my @days = @_;
   my $weeks = $#_/7;
   my $i = 0;
   my $week = [];

LOOP:
   while ($i <= $weeks) {
      $week = [splice(@_, 0 , 7)];
      print qq(<tr width="100%" bgcolor="$config->{cal_bg_color}" valign="top">\n\n@{ $week }\n\n</tr>);
      $i++;
   } # while
} # endsub print_weeks

sub get_blanks {
   my $sblank = '';
   if ($_[1]->[$_[0]] == 7) { $sblank = 0; }
   else { $sblank = $_[1]->[$_[0]]; }

   my $eblank = '';
   if ($_[2]->[$_[0]] == 7) { $eblank = 6; }
   elsif ($_[2]->[$_[0]] == 6) { $eblank = 0; }
   else { $eblank = 6-$_[2]->[$_[0]]; }
   return ($sblank, $eblank);
} # endsub  get_blanks

sub blank_maker {
   return map {
                qq(<td align="$_[1]" width="$_[3]" height="$_[4]" bgcolor="$config->{cal_bg_color}" valign="$_[2]">
                <font face="$config->{cal_font}" color="$config->{cal_text_color}" size="$_[5]">$_[6]</font></td>\n)
              } @{ $_[0] };
} # endsub blank_maker

sub DESTROY {
   my $self = shift || 0;
   my $input = [];
} # endsub DESTROY

1;
