package CyberCalendar::PDA;
###################################################################
# CyberCalendar v1.8.2
#
# PDA Calendar Module
# Copyright 1999, 2000, 2001 Shawn Ewald <shawn@cyberweavers.com>
#
###################################################################
# License:                                                        #
# ----------------------------------------------------------------#
# This program is free software; you can redistribute it and/or   #
# modify it under the terms of the GNU General Public License     #
# as published by the Free Software Foundation; either version 2  #
# of the License, or (at your option) any later version.          #
#                                                                 #
# This program is distributed in the hope that it will be useful, #
# but WITHOUT ANY WARRANTY; without even the implied warranty of  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
###################################################################
# For the full text of the GNU General Public License, go to:     #
# http://www.gnu.org/copyleft/gpl.html                            #
###################################################################
use vars qw($config $http_in $db $app $fdate $ldate);
use CyberCalendar::Application;
use strict;

sub new {
   my $self = shift || 0;
   my $hashref = {};

   $app = CyberCalendar::Application->new();
   $app->init('NULL');

   # Get application variables
   $http_in = $CyberCalendar::Application::http_in;
   $config = $CyberCalendar::Application::config;
   $db = $CyberCalendar::Application::db;

   my $http = CyberCalendar::Http->new();
   if ($http_in->{http_accept}  =~ /(vnd\.wap\.wml|x-wap)/o) {
      $http->header(type => 'text/vnd.wap.wml');
      $config->{content} = 'wml';
      $config->{br} = '<br/>';
   } # if
   else {
      $http->header(type => 'text/html');
      $config->{content} = 'html';
      $config->{br} = '<br>';
   } # else

   my ($m, $d, $y) = split("/", $http_in->{DateID});
   $http_in->{dateid} = "$y-$m-$d";
   $fdate = "$y-$m-1";
   my $cal = CyberCalendar::Calendar->new();
   my $dim = $cal->days_in_month($y, $m);
   $ldate = "$y-$m-$dim";

   bless $hashref, $self;
} # endsub new

sub show_page {
   for ($http_in->{View}) {
      /Day/o && do { day_view(); last; };
      /Event/o && do { event_view(); last; };
      /Search/o && do { search_view(); last; };
      /Category/o && do { category_view(); last; };
      main_view(); last;
   } # for
} # endsub show_page

sub main_view {
   my $page = '';
   if ($config->{content} eq 'html') {
      $page .= qq(<center><table border="0" width="100%" cellpadding="0" cellspacing="0" align="center"><tr><td align="center" valign="top">
                 <font face="Arial, Helvetica">);
      $page .= nav_links();
      $page .= qq(</font></td></tr><tr><td align="center" valign="top"><form method="post" action="$config->{pda_url}">
                 <font face="Arial, Helvetica">);
      $page .= calendar_list();
      $page .= qq( </font></form>
                 </td></tr><tr><td align="center" valign="top"><form method="post" action="$config->{pda_url}">
                 <input type="hidden" name="Calendar" value="$http_in->{Calendar}">
                 <input type="hidden" name="View" value="Day"><select name="DateID">);
      $page .= dates_list();
      $page .= qq(</select> <input type="submit" name="submit" value="View"></form>
                 </td></tr><tr><td align="center" valign="top"><form method="post" action="$config->{pda_url}">
                 <input type="hidden" name="Calendar" value="$http_in->{Calendar}">
                 <input type="hidden" name="View" value="Category"><select name="Category">);
      $page .= category_list();
      $page .= qq(</select> <input type="submit" name="submit" value="Browse"></form>
                 </td></tr><tr><td align="center" valign="top">);
      $page .= search_box();
      $page .= "</font></td></tr></table></center>";
      print show_palm($page);
   } # if
   else {
      #my $cal_name = wap_escape($config->{calendar_name});
      $page .= qq(\n<card id="mainpage" title="Calendar: $config->{calendar_name}">\n<p align="center">);
      $page .= nav_links();
      $page .= calendar_list();
      $page .= qq(<br/>\n<select>\n);
      $page .= dates_list();
      $page .= "</select>\n<br/>\n<select>\n";
      $page .= category_list();
      $page .= "</select>\n<br/>\n";
      $page .= search_box();
      $page .= "\n<br/>\n</p>\n</card>\n";
      print show_wap($page);
   } # else
} # endsub main_view

sub day_view {
   my @events = ();
   my $query = qq(SELECT starttime, subject, repeatid from $http_in->{Calendar}
                  WHERE dateid = ?
                  ORDER BY starttime ASC);
   $db->query($query,
              CyberCalendar::Application::http2dateid());
   my $cal = CyberCalendar::Calendar->new();
   while (my $tmp = $db->result("hashref")) {
      my $time = $cal->hr24_2_hr12($tmp->{starttime});
      push(@events, qq(<a href="$config->{pda_url}?Calendar=$http_in->{Calendar}&amp;View=Event&amp;DateID=$http_in->{DateID}&amp;Repeatid=$tmp->{repeatid}">$time: $tmp->{subject}</a>\n$config->{br}\n));
   }
   $db->finish;
   my $page = '';
   if ($config->{content} eq 'html') {
      $page = qq(\n<p align="left">\n<strong>Events for: $http_in->{DateID}</strong><br><br>@events\n<br><b><a href="$config->{pda_url}?Calendar=$http_in->{Calendar}">&lt;&lt; Back</a></b></p>\n);
      print show_palm($page);
   } # if
   else {
      #my $displayed_cal_name = wap_escape($config->{calendar_name});
      $page = qq(<card id="day_view" title="Calendar: $config->{calendar_name} Date: $http_in->{DateID}">\n<p align="left">\n<strong>Events for: $http_in->{DateID}</strong><br/><br/>@events\n</p>\n</card>\n);
      print show_wap($page);
   } # else
} # endsub day_view

sub event_view {
   my $query = qq(SELECT * from $http_in->{Calendar}
                  WHERE dateid = ?
                  AND repeatid = ?);
   $db->query($query,
               CyberCalendar::Application::http2dateid(),
               $http_in->{Repeatid});
   my $event = $db->result("hashref");
   $db->finish;
   my $cal = CyberCalendar::Calendar->new();
#######################
   $event->{datetext} = $cal->datestring($event->{event_year},
                                         $event->{event_month},
                                         $event->{event_day});
   if ($event->{enddate} != 0) {
      my ($y, $m , $d) = split("-", $event->{enddate});
      my $enddate_datetext = $cal->datestring($y, $m, $d);
      $event->{datetext} = "$event->{datetext} - $enddate_datetext";
   } # if
   $event->{starttime} = $cal->hr24_2_hr12($event->{starttime});
   if ($event->{endtime} != 0) {
      $event->{endtime} = $cal->hr24_2_hr12($event->{endtime});
      $event->{starttime} = "$event->{starttime} - $event->{endtime}";
   } # if
   $event->{url} = qq(<a href="$event->{url}">$event->{url}</a>) if $config->{content} eq 'html';
   $event->{subject} = wap_escape($event->{subject});
   $event->{desctext} = wap_escape($event->{desctext});
   my $vcal = qq(\n<a href="$config->{vcal_url}?Calendar=$http_in->{Calendar}&amp;DateID=$event->{event_month}/$event->{event_day}/$event->{event_year}&Repeatid=$event->{repeatid}">Download vCalendar</a>\n);
#######################
   my $page = <<"EVENT";
<p align="left">
   <strong>$event->{subject}</strong>$config->{br}$config->{br}
   <strong>Date: </strong>$event->{datetext}$config->{br}
   <strong>Time: </strong>$event->{starttime}$config->{br}
   <strong>Location: </strong>$event->{location}$config->{br}
   <strong>Category: </strong>$event->{category}$config->{br}
   <strong>Website: </strong>$event->{url}$config->{br}
   <strong>Contact: </strong>$event->{email}$config->{br}$config->{br}
$event->{desctext}
</p>
EVENT
   if ($config->{content} eq 'html') {
      $page .= qq($vcal<br><br><b><a href="$config->{pda_url}?Calendar=$http_in->{Calendar}">&lt;&lt; Back</a></b>);
      print show_palm($page);
   } # if
   else {
      #my $displayed_cal_name = wap_escape($config->{calendar_name});
      $page = qq(\n<card id="event_view" title="Calendar: $config->{calendar_name} -- View Event">\n$page\n</card>\n);
      print show_wap($page);
   } # else
} # endsub event_view

sub search_view {
   my @events = ();
   my $query = qq(SELECT * from $http_in->{Calendar}
                  WHERE subject LIKE ?
                  OR desctext LIKE ?
                  ORDER BY dateid DESC);
   $db->query($query,
              "%$http_in->{searchtext}%",
              "%$http_in->{searchtext}%");
   my $rows = $db->rowcount;
   if ($rows == 0 or $http_in->{searchtext} eq '') { push(@events, qq(\n<strong>No events found.</strong>\n$config->{br}\n)); }
   # if
   else {
      my $cal = CyberCalendar::Calendar->new();
      while (my $tmp = $db->result("hashref")) {
         my ($y, $m, $d) = split("-", $tmp->{dateid});
         my $date = "$m/$d/$y";
         my $time = $cal->hr24_2_hr12($tmp->{starttime}); 
         push(@events, qq(<a href="$config->{pda_url}?Calendar=$http_in->{Calendar}&amp;View=Event&amp;DateID=$date&amp;Repeatid=$tmp->{repeatid}">$date $time: $tmp->{subject}</a>$config->{br}\n));
      }
   } # else
   $db->finish;
   #my $displayed_cal_name = wap_escape($config->{calendar_name});
   my $page = '';
   if ($config->{content} eq 'html') {
      $page .= qq(\n<p align="left">\n<strong>Results for query: $http_in->{searchtext}</strong><br><br>@events\n<br><b><a href="$config->{pda_url}?Calendar=$http_in->{Calendar}">&lt;&lt; Back</a></b></p>\n);
      print show_palm($page);
   } # if
   else {
      $page = qq(<card id="search_view" title="Calendar: $config->{calendar_name} -- Search View">\n<p align="left">\n<strong>Results for query: $http_in->{searchtext}</strong><br/><br/>@events\n</p>\n</card>\n);
      print show_wap($page);
   } # else
} # endsub search_view

sub category_view {
   my @events = ();
   my $query = qq(SELECT * from $http_in->{Calendar}
                  WHERE dateid >= ?
                  AND category = ?
                  ORDER BY dateid ASC);
   $db->query($query,
              $fdate,
              $http_in->{Category});
   my $rows = $db->rowcount;
   if ($rows == 0) { push(@events, qq(\n<strong>No events found in this category.</strong>\n<br/>\n)); }
   # if
   else {
      my $cal = CyberCalendar::Calendar->new();
      while (my $tmp = $db->result("hashref")) {
         my ($y, $m, $d) = split("-", $tmp->{dateid});
         my $date = "$m/$d/$y";
         my $time = $cal->hr24_2_hr12($tmp->{starttime}); 
         push(@events, qq(<a href="$config->{pda_url}?Calendar=$http_in->{Calendar}&amp;View=Event&amp;DateID=$date&amp;Repeatid=$tmp->{repeatid}">$date $time: $tmp->{subject}</a>$config->{br}\n));
      }
   } # else
   $db->finish;
   my $page = '';
   if ($config->{content} eq 'html') {
      $page = qq(\n<p align="left">\n<strong>Category: $http_in->{Category}</strong><br><br>@events\n<br><b><a href="$config->{pda_url}?Calendar=$http_in->{Calendar}">&lt;&lt; Back</a></b></p>\n);
      print show_palm($page);
   } # if
   else {
      #my $displayed_cal_name = wap_escape($config->{calendar_name});
      $page = qq(<card id="category_view" title="Calendar: $config->{calendar_name} -- Category View">\n<p align="left">\n<strong>Category: $http_in->{Category}</strong><br/><br/>@events\n</p>\n</card>\n);
      print show_wap($page);
   } # else
} # endsub category_view

sub show_wap {
   return <<"WAPDOC";
<?xml version="1.0"?>
<!DOCTYPE wml PUBLIC "-//WAPFORUM/DTD wml 1.1//EN" "http://www.wapforum.org/DTD/wml_1.1.xml">
<wml>
<head><meta http-equiv="Cache-Control" content="max-age=0"/></head>
<template><do type="prev" label="&lt;&lt; Back"><prev/></do></template>
$_[0]
</wml>
WAPDOC
} # endsub show_wap

sub show_palm {
   return <<"PALMDOC";
<html>
<head><title>Calendar: $config->{calendar_name}</title>
<meta http-equiv="Cache-Control" content="max-age=0">
<meta name="HandheldFriendly" content="True"></head>
<body bgcolor="$config->{body_bg_color}">
<font face="Arial, Helvetica" size="2">
$_[0]
</font>
</body>
</html>
PALMDOC
} # endsub show_palm

sub nav_links {
   my ($m, $d, $y) = split("/", $http_in->{DateID});
   my $month = Date::Calc::Month_to_Text($m);
   my $mo_yr = "$month $y";
   my $cal = CyberCalendar::Calendar->new();
   my $dim = $cal->days_in_month($y, $m);
   my @prev = $cal->minus_days($dim, ($y, $m, $dim));
   my @next = $cal->add_days($dim, ($y, $m, 1));
   my $prev_mo = "$prev[1]/$prev[2]/$prev[0]";
   my $next_mo = "$next[1]/$next[2]/$next[0]";
   return qq(<strong><a href="$config->{pda_url}?Calendar=$http_in->{Calendar}&amp;DateID=$prev_mo">&lt;&lt;</a> $mo_yr <a href="$config->{pda_url}?Calendar=$http_in->{Calendar}&amp;DateID=$next_mo">&gt;&gt;</a></strong>$config->{br}$config->{br}\n); 
} # endsub nav_links

sub calendar_list {
   my @calendars = ();
   my $value = "value=\"";
   $value = "onpick=\"$config->{pda_url}?Calendar=" if $config->{content} eq 'wml';
   #my $displayed_cal_name = wap_escape($config->{calendar_name});
   push(@calendars, "<option $value$http_in->{Calendar}\">$config->{calendar_name}</option>\n");
   my $query = "SELECT calendar, name from calendars where calendar != ? ORDER BY name ASC";
   $db->query($query, $http_in->{Calendar});
   my $rows = $db->rowcount;
   if ($rows == 0) { $db->finish; return qq(<strong><u>Calendar: $config->{calendar_name}</u></strong>$config->{br}); }
   # if
   else {
      my $name = " name=\"Calendar\"" if $config->{content} eq 'html';
      while (my $tmp = $db->result("hashref")) {
         #$displayed_cal_name = wap_escape($tmp->{name});
         push(@calendars, "<option $value$tmp->{calendar}\">$tmp->{name}</option>\n");
      } # while
      $db->finish;
      return qq(\n<select$name>\n@calendars</select> <input type="submit" name="submit" value="Select">);
   } # else
} # endsub calendar_list

sub dates_list {
   my @dates = ();
   my $value = "onpick=\"$config->{pda_url}?Calendar=$http_in->{Calendar}&amp;View=Day&amp;DateID=";
   $value = "value=\"" if $config->{content} eq 'html';
   push(@dates, "<option $value\">Select a date...</option>\n");
   # get dates on which events are occurring
   my $query = qq(SELECT DISTINCT dateid from $http_in->{Calendar}
                  WHERE dateid >= ? AND dateid <= ?
                  ORDER BY dateid ASC);
   $db->query($query, $fdate, $ldate);
   my $cal = CyberCalendar::Calendar->new();
   while (my $tmp = $db->result("hashref")) {
      my ($y, $m, $d) = split("-", $tmp->{dateid});
      my $dateid = "$m/$d/$y";
      my $datestring = $cal->datestring($y, $m, $d);
      push(@dates, "<option $value$dateid\">$datestring</option>\n");
   } # while
   $db->finish;
   return qq(@dates);
} # endsub dates_list

sub category_list {
   my @categories = ();
   my $value = "onpick=\"$config->{pda_url}?Calendar=$http_in->{Calendar}&amp;View=Category&amp;Category=";
   $value = "value=\"" if $config->{content} eq 'html';
   push(@categories, "<option $value\">Browse by category...</option>\n");
   # get list of categories
   my $query = qq(SELECT DISTINCT category from $http_in->{Calendar} WHERE dateid >= ? ORDER BY category ASC);
   $db->query($query, $fdate);
   my $url = CyberCalendar::Http->new();
   while (my $tmp = $db->result("hashref")) {
      my $cat = $tmp->{category};
      #my $wcat = $url->webify($tmp->{category});
      push(@categories, "<option $value$tmp->{category}\">$cat</option>\n");
   }
   $db->finish;
   return qq(@categories);
} # endsub category_list

sub search_box {
   my $search = '';
   if ($config->{content} eq 'html') {
      $search = qq(\n<form method="post" action="$config->{pda_url}"><input type="hidden" name="Calendar" value="$http_in->{Calendar}">
                  <input type="hidden" name="View" value="Search"><input name="searchtext" type="text" size="13" maxlength="25">
                  <input type="submit" name="submit" value="Search"></form>\n);
   } # if
   else {
      $search = qq(\n<input name="searchtext" type="text" format="*M" size="13" maxlength="25" emptyok="false"/>
                  <strong><a href="$config->{pda_url}?Calendar=$http_in->{Calendar}&amp;View=Search&amp;searchtext=\$(searchtext)">Search</a></strong>\n);
   } # else
   return $search;
} # endsub search_box

##
## Escapes certain problamatic characters
##
sub wap_escape {
   $_[0] =~ s/<br>/\n/g;
   $_[0] =~ s/&/&amp;/g;
   $_[0] =~ s/</&lt;/g;
   $_[0] =~ s/>/&gt;/g;
   return $_[0];
} # endsub wap_escape

sub wap_exit {
 CyberCalendar::Application::my_exit();
} # endsub wap_exit

sub DESTROY {
    my $self = shift;
    my $hashref = {};
} # endsub DESTROY
1;
