package CyberCalendar::Setup;
###################################################################
# CyberCalendar v1.8.2
#
# Setup and Configuration Module
# Copyright 1999, 2000, 2001 Shawn Ewald <shawn@cyberweavers.com>
#
###################################################################
# License:                                                        #
# ----------------------------------------------------------------#
# This program is free software; you can redistribute it and/or   #
# modify it under the terms of the GNU General Public License     #
# as published by the Free Software Foundation; either version 2  #
# of the License, or (at your option) any later version.          #
#                                                                 #
# This program is distributed in the hope that it will be useful, #
# but WITHOUT ANY WARRANTY; without even the implied warranty of  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
###################################################################
# For the full text of the GNU General Public License, go to:     #
# http://www.gnu.org/copyleft/gpl.html                            #
###################################################################
# IMPORT MODULES
use vars qw($config $http_in $db $user $app);
use CyberCalendar::Application;
use CyberCalendar::Auth;
use strict;


sub new {
   my $self = shift;
   my $hashref = {};
   bless $hashref, $self;
} # endsub new

sub init {

   $app = CyberCalendar::Application->new();
   $app->init();

   $http_in = $CyberCalendar::Application::http_in;
   $config = $CyberCalendar::Application::config;

   # Open database connection
   $db = $CyberCalendar::Application::db;

   if ($config->{session_type} != 0) {
      my $auth = CyberCalendar::Auth->new('');
      $user = $auth->authenticate($config, $http_in, $db);
      $user->{session} = $http_in->{session};
      if ($user->{accesslevel} != 1
         and $user->{full_ctrl} != 1) { CyberCalendar::Auth::login_error("Permission denied."); }
   } # if
   if ($user->{accesslevel} == 1) { $user->{cal_list} = 1; }
   else { $user->{cal_list} = 3; }
} # endsub init

sub show_page {
SWITCH:
   for ($http_in->{Setup}) {
      /Config/o && do { config_calendar();  last; };
      /NewCal/o && do { new_calendar(); last; };
      /DeleteCalendar/o && do { delete_calendar(); last; };
      /ChangePassword/o && do { config_password(); last; };
      /NewUser/o && do { new_user(); last; };
      /EditUser/o && do { edit_user(); last; };
      /SaveACL/o && do { save_acl(); last; };
      /DeleteUser/o && do { delete_user(); last; };
      option_form(); last;
   } # for
   my_exit();
} # endsub show_page

sub new_user {
   check_perms();
   if (exists $http_in->{SaveUser}) { save_user_info($http_in); }
   else { print user_form(); }
} # endsub new_user

sub edit_user {
   check_perms();
   if (exists $http_in->{SaveUser}) { save_user_info($http_in); }
   else { print user_form(get_user_info($http_in->{uid})); }
} # endsub edit_user

sub save_acl {
   check_perms();
   my $query = '';
   if (exists $http_in->{add_access}
      and $http_in->{add_access} ne '') {
      if (exists $http_in->{make_owner}) {
         $query = "UPDATE calendars set uid = ? where calendar = ?";
         $db->query($query, $http_in->{uid}, $http_in->{add_access});
         $db->finish;
         $query = "UPDATE config set uid = ? where calendar = ?";
         $db->query($query, $http_in->{uid}, $http_in->{add_access});
         $db->finish;
         $query = "DELETE from acl where uid = ? and calendar = ?";
         $db->query($query, $http_in->{uid}, $http_in->{add_access});
         $db->finish;
         $query = "INSERT INTO acl (uid, calendar, full_ctrl) VALUES(?, ?, ?)";
         $db->query($query, $http_in->{uid}, $http_in->{add_access}, 1);
         $db->finish;
      } # if
      else {
         $query = "UPDATE calendars set uid = ? where uid = ? and calendar = ?";
         $db->query($query, 0, $http_in->{uid}, $http_in->{add_access});
         $db->finish;
         $query = "UPDATE config set uid = ? where uid = ? and calendar = ?";
         $db->query($query, 0, $http_in->{uid}, $http_in->{add_access});
         $db->finish;
         $query = "DELETE from acl where uid = ? and calendar = ?";
         $db->query($query, $http_in->{uid}, $http_in->{add_access});
         $db->finish;
         $query = "INSERT INTO acl (uid, calendar) VALUES(?, ?)";
         $db->query($query, $http_in->{uid}, $http_in->{add_access});
         $db->finish;
      } # else
      print user_form(get_user_info($http_in->{uid}), 'Access information updated successfully.');
   } # if
   elsif (exists $http_in->{remove_access}
         and $http_in->{remove_access} ne '') {
      if (exists $http_in->{remove_owner}) {
         $query = "UPDATE calendars set uid = ? where uid = ? and calendar = ?";
         $db->query($query, 0, $http_in->{uid}, $http_in->{remove_access});
         $db->finish;
         $query = "UPDATE config set uid = ? where uid = ? and calendar = ?";
         $db->query($query, 0, $http_in->{uid}, $http_in->{remove_access});
         $db->finish;
         $query = "DELETE from acl where uid = ? and calendar = ?";
         $db->query($query, $http_in->{uid}, $http_in->{remove_access});
         $db->finish;
         $query = "INSERT INTO acl (uid, calendar) VALUES(?, ?)";
         $db->query($query, $http_in->{uid}, $http_in->{remove_access});
         $db->finish;
      } # if
      else {
         $query = "DELETE from acl where uid = ? and calendar = ?";
         $db->query($query, $http_in->{uid}, $http_in->{remove_access});
         $db->finish;
         $query = "UPDATE calendars set uid = ? WHERE uid = ? and calendar = ?";
         $db->query($query, 0, $http_in->{uid}, $http_in->{remove_access});
         $db->finish;
         $query = "UPDATE conifg set uid = ? WHERE uid = ? and calendar = ?";
         $db->query($query, 0, $http_in->{uid}, $http_in->{remove_access});
         $db->finish;
      } # else
      print user_form(get_user_info($http_in->{uid}), 'Access information updated successfully.');
   } # elsif
   else { 
      my_error('no', 'You must select a calendar.');
      my_exit();
   } # else
} # endsub save_acl

sub delete_user {
   check_perms();
   my $u = get_user_info($http_in->{uid});
   my $query = "DELETE from users WHERE uid = ?";
   $db->query($query, $u->{uid});
   $db->finish;
   $query = "DELETE from acl WHERE uid = ?";
   $db->query($query, $u->{uid});
   $db->finish;
   $query = "UPDATE calendars set uid = ? WHERE uid = ?";
   $db->query($query, 0, $u->{uid});
   $db->finish;
   $query = "UPDATE config set uid = ? WHERE uid = ?";
   $db->query($query, 0, $u->{uid});
   $db->finish;

   print <<"DELUSERMSG";
<html><head><title>CyberCalendar: Delete User</title></head>
<body bgcolor="#FFFFFF"><div align="center">
<table border="0" width="450" align="center"><tr><td bgcolor="#C0C0C0" align="center">
<b>User "$u->{username}" Deleted Successfully!<br />
<a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">Return to Calendar Setup.</a></b>
</td></tr>
</table>
</div></body>
</html>
DELUSERMSG
} # endsub delete_user

sub save_user_info {
   check_perms();
   my $query = '';
   my $msg = '';
   if ($http_in->{Setup} eq 'NewUser') {
      $query = "SELECT username from users WHERE username = ?";
      $db->query($query, $_[0]->{username});
      my $count = $db->rowcount;
      if ($count != 0) { my_error("no", "User Already Exists! Please choose another username.\n"); my_exit(); }
      $_[0]->{password} = "nopassword" if $config->{session_type} == 1;
      $msg = qq(User "$_[0]->{username}" Created Successfully!);
      $query = "INSERT INTO users (username, password, accesslevel, fullname, email)
                   VALUES(?, password(?), ?, ?, ?)";
      $db->query($query, $_[0]->{username}, $_[0]->{password}, $_[0]->{accesslevel}, $_[0]->{fullname}, $_[0]->{email});
   print qq(
<html><head><title>CyberCalendar: Add User</title></head>
<body bgcolor="#FFFFFF"><div align="center">
<table border="0" width="450" align="center"><tr><td bgcolor="#C0C0C0" align="center">
<b>$msg<br />
<a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">Return to Calendar Setup.</a></b>
</td></tr>
</table>
</div></body>
</html>
);
   } # if
   else {
      $msg = qq(User "$_[0]->{username}" Updated Successfully!);
      if (exists  $_[0]->{password}
	 and $_[0]->{password} ne '') {
         $query = "UPDATE users SET username = ?, password = password(?), accesslevel = ?, fullname = ?, email = ? WHERE uid = ?";
         $db->query($query, $_[0]->{username}, $_[0]->{password}, $_[0]->{accesslevel}, $_[0]->{fullname}, $_[0]->{email}, $_[0]->{uid});
      } # if
      else {
         $query = "UPDATE users SET username = ?, accesslevel = ?, fullname = ?, email = ? WHERE uid = ?";
         $db->query($query, $_[0]->{username}, $_[0]->{accesslevel}, $_[0]->{fullname}, $_[0]->{email}, $_[0]->{uid});
      } # else
      print user_form(get_user_info($http_in->{uid}), $msg);
   } # else
   $db->finish;
} # endsub save_user_info

sub config_password {
   if (!exists $http_in->{pwd}) { print password_form(); }
   else { change_password(); }
} # endsub config_password

sub change_password {
   if ($http_in->{password} ne $http_in->{password2}) { print "<b>Passwords do not match."; exit(0); }
   if ($http_in->{password} eq '' or $http_in->{password2} eq '') { print "<b>You cannot have a blank password!"; exit(0); }
   my $query = qq(UPDATE users set password = password(?) where sessionid = ?);
   $db->query($query, $http_in->{password2}, $user->{session});
   $db->finish;
   print <<"CHGPWDMSG";
<html><head><title>CyberCalendar: ERROR</title></head>
<body bgcolor="#FFFFFF"><div align="center">
<table border="0" width="450" align="center"><tr><td bgcolor="#C0C0C0" align="center">
<b>Password Changed.<br /><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">Return to calendar Setup.</a>
</td></tr>
</table>
</div></body>
</html>
CHGPWDMSG
} # endsub change password

sub get_cal_config {
   my $query = "SELECT * from config WHERE calendar = ?";
   $db->query($query, $http_in->{Calendar});
   my $href = $db->result("hashref");
   $db->finish;
   return $href;
} # endsub get_cal_config

sub get_user_info {
   if ($_[0] == 0 || $_[0] == '') { my_error("no", "You must select a user!"); my_exit(); }
   my $query = "SELECT * from users WHERE uid = ?";
   $db->query($query, $_[0]);
   my $href = $db->result("hashref");
   $db->finish;
   return $href;
} # endsub get_user_info

sub get_cal_info {
   my $query = qq(SELECT * from calendars
                  WHERE calendar = ?);
   $db->query($query, $http_in->{Calendar});
   my $href = $db->result("hashref");
   $db->finish;
   return $href;
} # endsub get_cal_info

sub config_calendar {
   if (exists $http_in->{SaveConfig}) {
      $http_in->{timezone} = $http_in->{other_tz} if $http_in->{other_tz} ne '';
      if (exists $http_in->{apply_all}
         and $http_in->{apply_all} eq "apply_all"){
         $db->query("SELECT calendar from calendars");
         my $calendars = {};
         while (my $temp = $db->result("hashref")) {
            my ($name, $value) = each(%{ $temp });
            $calendars->{$value} = $value;
         } # while
         foreach (keys %{ $calendars }) {
            update_calendar_config($_, $http_in);
         } # foreach
         $db->finish;
      } # if
      else {
         update_calendar_config($http_in->{Calendar}, $http_in);
      } # else
   print <<"CHGCFGMSG";
<html><head><title>CyberCalendar: Configure Calendar</title></head>
<body bgcolor="#FFFFFF"><div align="center">
<table border="0" width="450" align="center"><tr><td bgcolor="#C0C0C0" align="center">
<b> Calendar "$http_in->{Calendar}" configuration changed.<br />
<a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&Setup=Config&session=$user->{session}">Reconfigure calendar.</a>&nbsp;|&nbsp;
<a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">Return to calendar Setup.</a>
</td></tr>
</table>
</div></body>
</html>
CHGCFGMSG
   }
   else { print config_form(get_cal_config(), get_cal_info()); }
} # endsub config_calendar

sub update_calendar_config {
   my $query = '';
   $_[1]->{public_direct_submit} = '0';
   if ($_[1]->{public_event_submit} == 1) { $_[1]->{public_event_submit} = '1'; $_[1]->{public_direct_submit} = '0'; }
   if ($_[1]->{public_event_submit} == 2) { $_[1]->{public_event_submit} = '1'; $_[1]->{public_direct_submit} = '1'; }
   if (!exists $_[1]->{apply_all}) {
      if ($user->{accesslevel} == 1) {
         if ($_[1]->{is_default} == 1) {
            $query = "UPDATE config set is_default = ?";
            $db->query($query, '0');
            $db->finish;
         } # if
         if (!exists $_[1]->{is_default}
	     and $_[0] ne $config->{default_calendar}) { $_[1]->{is_default} = '0'; }
         else { $_[1]->{is_default} = '1'; }
         $query = "UPDATE calendars set uid = ?, notes = ? WHERE calendar = ?";
         $db->query($query, $_[1]->{uid}, $_[1]->{notes}, $_[0]);
         $db->finish;
         $query = "UPDATE config set uid = ?, is_default = ? WHERE calendar = ?";
         $db->query($query, $_[1]->{uid}, $_[1]->{is_default}, $_[0]);
         $db->finish;
      } # if
     if (!exists $_[1]->{is_visible}) { $_[1]->{is_visible} = '0'; }
      $query = qq(UPDATE calendars SET
                  name = ?,
                  is_visible = ?,
                  description = ?
                  WHERE calendar = ?);
      $db->query($query,
                 $_[1]->{name},
                 $_[1]->{is_visible},
                 $_[1]->{description},
                 $_[0]);
      $db->finish;
   } # if
   $query = qq(UPDATE config SET
               timezone = ?,
               show_large_calendar = ?,
               large_calendar_width = ?,
               show_calendars = ?,
               show_days = ?,
               show_lines = ?,
               site_homepage = ?,
               calendar_homepage = ?,
               template = ?,
               body_bg_color = ?,
               page_title_font = ?,
               page_title_font_size = ?,
               page_title_var_color = ?,
               cal_head_color = ?,
               cal_head_text_color = ?,
               cal_head_font = ?,
               cal_head_font_size = ?,
               cal_trimcolor = ?,
               cal_bg_color = ?,
               cal_text_color = ?,
               cal_font = ?,
               cal_month_year_fontsize = ?,
               cal_days_font_size = ?,
               cal_dates_font_size = ?,
               featured_head_color = ?,
               featured_head_text_color = ?,
               featured_link_color = ?,
               event_head_color = ?,
               event_head_text_color = ?,
               event_head_font = ?,
               event_head_font_size = ?,
               event_body_bgcolor = ?,
               event_body_text_color_detail = ?,
               event_body_text_color_body = ?,
               event_body_font = ?,
               event_body_font_size = ?,
               cal_img = ?,
               cal_img_alt = ?,
               cal_img_width = ?,
               cal_img_height = ?,
               browse_img = ?,
               browse_img_alt = ?,
               browse_img_width = ?,
               browse_img_height = ?,
               search_img = ?,
               search_img_alt = ?,
               search_img_width = ?,
               search_img_height = ?,
               help_img = ?,
               help_img_alt = ?,
               help_img_width = ?,
               help_img_height = ?,
               from_address = ?,
               mail_message_title = ?,
               html_mail_bgcolor = ?,
               html_mail_body_font = ?,
               html_mail_body_fontsize = ?,
               html_mail_body_textcolor = ?,
               public_event_submit = ?,
               public_direct_submit = ?
               WHERE calendar = ?);
   $db->query($query,
              $_[1]->{timezone},
              $_[1]->{show_large_calendar},
              $_[1]->{large_calendar_width},
              $_[1]->{show_calendars},
              $_[1]->{show_days},
              $_[1]->{show_lines},
              $_[1]->{site_homepage},
              $_[1]->{calendar_homepage},
              $_[1]->{template},
              $_[1]->{body_bg_color},
              $_[1]->{page_title_font},
              $_[1]->{page_title_font_size},
              $_[1]->{page_title_var_color},
              $_[1]->{cal_head_color},
              $_[1]->{cal_head_text_color},
              $_[1]->{cal_head_font},
              $_[1]->{cal_head_font_size},
              $_[1]->{cal_trimcolor},
              $_[1]->{cal_bg_color},
              $_[1]->{cal_text_color},
              $_[1]->{cal_font},
              $_[1]->{cal_month_year_fontsize},
              $_[1]->{cal_days_font_size},
              $_[1]->{cal_dates_font_size},
              $_[1]->{featured_head_color},
              $_[1]->{featured_head_text_color},
              $_[1]->{featured_link_color},
              $_[1]->{event_head_color},
              $_[1]->{event_head_text_color},
              $_[1]->{event_head_font},
              $_[1]->{event_head_font_size},
              $_[1]->{event_body_bgcolor},
              $_[1]->{event_body_text_color_detail},
              $_[1]->{event_body_text_color_body},
              $_[1]->{event_body_font},
              $_[1]->{event_body_font_size},
              $_[1]->{cal_img},
              $_[1]->{cal_img_alt},
              $_[1]->{cal_img_width},
              $_[1]->{cal_img_height},
              $_[1]->{browse_img},
              $_[1]->{browse_img_alt},
              $_[1]->{browse_img_width},
              $_[1]->{browse_img_height},
              $_[1]->{search_img},
              $_[1]->{search_img_alt},
              $_[1]->{search_img_width},
              $_[1]->{search_img_height},
              $_[1]->{help_img},
              $_[1]->{help_img_alt},
              $_[1]->{help_img_width},
              $_[1]->{help_img_height},
              $_[1]->{from_address},
              $_[1]->{mail_message_title},
              $_[1]->{html_mail_bgcolor},
              $_[1]->{html_mail_body_font},
              $_[1]->{html_mail_body_fontsize},
              $_[1]->{html_mail_body_textcolor},
              $_[1]->{public_event_submit},
              $_[1]->{public_direct_submit},
              $_[0]);
   $db->finish;
} # endsub update_calendar_config

sub new_calendar {
   check_perms();
   if (exists $http_in->{SaveCalendar}) { add_calendar($http_in); }
   else { print calendar_form(); }
} # endsub new_calendar

sub delete_calendar {
   check_perms();
   my $query = "DROP TABLE $http_in->{Calendar}";
   $db->query($query);
   $db->finish;
   $query = "DELETE from calendars WHERE calendar = ?";
   $db->query($query, $http_in->{Calendar});
   $db->finish;
   $query = "DELETE from config WHERE calendar = ?";
   $db->query($query, $http_in->{Calendar});
   $db->finish;
   $query = "DELETE from acl WHERE calendar = ?";
   $db->query($query, $http_in->{Calendar});
   $db->finish;
   print <<"DELCALMSG";
<html><head><title>CyberCalendar: ERROR</title></head>
<body bgcolor="#FFFFFF"><div align="center">
<table border="0" width="450" align="center"><tr><td bgcolor="#C0C0C0" align="center">
<b>Calendar $http_in->{Calendar} Deleted Successfully! <a href="$config->{setup_url}?Calendar=$config->{default_calendar}&session=$user->{session}">Return to Root Calendar.</a>
</td></tr>
</table>
</div></body>
</html>
DELCALMSG
} # endsub delete_calendar

sub add_calendar {
   check_perms();
   my $query = '';
   if ($_[0]->{calendar} ne ''
      and $_[0]->{name} ne '') {
      my @tables = $db->table_list;
      $db->finish;
      foreach (@tables) {
         if ($_[0]->{calendar} eq $_) { my_error("no", "Calendar Already Exists! Please choose another name.\n"); my_exit(); }
      } # foreach
      if (!exists $_[0]->{is_visible}) { $_[0]->{is_visible} = '0'; }
      $_[0]->{public_direct_submit} = '0';
      if ($_[0]->{public_event_submit} == 1) { $_[0]->{public_event_submit} = '1'; $_[0]->{public_direct_submit} = '0'; }
      if ($_[0]->{public_event_submit} == 2) { $_[0]->{public_event_submit} = '1'; $_[0]->{public_direct_submit} = '1'; }
      if (!exists $_[0]->{show_large_calendar}) { $_[0]->{show_large_calendar} = '0'; }
      if ($_[0]->{is_default} == 1) {
         $query = "update config set is_default = ?";
         $db->query($query, '0');
         $db->finish;
      } # if
      else { $_[0]->{is_default} = 0; }
      $query = qq(INSERT into calendars (uid, calendar, name, is_visible, description, notes)
                  values(?, ?, ?, ?, ?, ?));
      $db->query($query, $_[0]->{uid}, $_[0]->{calendar}, $_[0]->{name}, $_[0]->{is_visible}, $_[0]->{description}, $_[0]->{notes});
      $db->finish;
      $query = qq(INSERT into config (uid, calendar, is_default, timezone, show_large_calendar, site_homepage, calendar_homepage, template, public_event_submit, public_direct_submit)
                  values(?, ?, ?, ?, ?, ?, ?, ?, ?, ?));
      $db->query($query, $_[0]->{uid}, $_[0]->{calendar}, $_[0]->{is_default}, $_[0]->{timezone}, $_[0]->{show_large_calendar}, $_[0]->{site_homepage},
                $_[0]->{calendar_homepage}, $_[0]->{template}, $_[0]->{public_event_submit}, $_[0]->{public_direct_submit});
      $db->finish;
      $query = qq(INSERT into acl (uid, calendar, full_ctrl)
                  VALUES(?, ?, ?));
      $db->query($query, $_[0]->{uid}, $_[0]->{calendar}, 1);
      $db->finish;
      $query = qq(CREATE TABLE $_[0]->{calendar} (
               eventid int(11) NOT NULL auto_increment,
               featured tinyint(1) DEFAULT '0' NOT NULL,
               repeatid varchar(25) DEFAULT '' NOT NULL,
               dateid date DEFAULT '0000-00-00' NOT NULL,
               enddate date DEFAULT '0000-00-00' NOT NULL,
               event_day int(2) DEFAULT '0' NOT NULL,
               event_month int(2) DEFAULT '0' NOT NULL,
               event_year year(4) DEFAULT '0000' NOT NULL,
               subject varchar(255) DEFAULT '' NOT NULL,
               desctext text,
               url varchar(255),
               email varchar(255),
               location varchar(255),
               category varchar(255),
               othertime char(3),
               starttime time,
               endtime time,
               image varchar(255),
               PRIMARY KEY (eventid),
               KEY repeatid (repeatid),
               KEY dateid (dateid)));
      $db->query($query);
      $db->finish;
      print <<"ADDCALMSG";
<html><head><title>CyberCalendar: ERROR</title></head>
<body bgcolor="#FFFFFF"><div align="center">
<table border="0" width="450" align="center"><tr><td bgcolor="#C0C0C0" align="center">
<b>Calendar created.<br /><a href="$config->{setup_url}?Calendar=$_[0]->{calendar}&Setup=Config&session=$user->{session}">Configure New Calendar.</a> |
<a href="$config->{setup_url}?Calendar=$_[0]->{Calendar}&session=$user->{session}">Return to Previous Calendar.</a>
</td></tr>
</table>
</div></body>
</html>
ADDCALMSG
   } # if
   else { my_error("no", "Operation Failed -- $!\n"); my_exit();}
}


#-----------------------------------------------------------------------#
# Form Subroutines
#-----------------------------------------------------------------------#

sub option_form {
   my $admin_options = '';
   if ($user->{accesslevel} == 1) {
      my $query = "SELECT uid, username, fullname from users ORDER BY username";
      $db->query($query);
      my $edit_user = '';
      my @users = ();
      while (my $users = $db->result("hashref")) {
         push(@users, qq(<option value="$users->{uid}">$users->{username} ($users->{fullname})</option>\n));
      } # while
      $db->finish;
      $edit_user = qq(<form method="post" action="$config->{setup_url}"><font face="Arial, Helvetica, sans-serif"> 
      <select name="uid"><option value="">Edit a User Account</option>\n@users
      </select><input type="submit" name="submit" value="Edit"></font><input type="hidden" name="Setup" value="EditUser">
      <input type="hidden" name="Calendar" value="$http_in->{Calendar}">
      <input type="hidden" name="session" value="$user->{session}"></form>\n);
      $edit_user = '' if $config->{session_type} == 0;
      my $new_user = qq(<li><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&Setup=NewUser&session=$user->{session}">Create a New User Account.</a><p></li>);
      $new_user = '' if $config->{session_type} == 0;
      
      $admin_options = qq(<p><table cellspacing=0 cellpadding=0 border=0 width=300 align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;<b>ADMINISTRATOR OPTIONS:</b>
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0 width=300>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2"><font face="Arial, Helvetica"><br />
            <font size=2><b>
            <ul>
            <li><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&Setup=NewCal&session=$user->{session}">Create a New Calendar.</a><p></li>
            $new_user
            </ul>
            <div align="center">$edit_user</div>
            </b></font></font>
            </td>
          </tr>
        </table>
      </td>
    </tr>
  </table>
</td>
</tr>
</table>);
   }
   my $password_item = qq(<li><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&Setup=ChangePassword&session=$user->{session}">Change Your Password</a><p></li>);
   if ($config->{session_type} == 0 || $config->{session_type} == 1) { $password_item = ''; }
   print <<"OPTIONS";
<html><head><title>Calendar Configuration</title></head>
<body bgcolor="#FFFFFF">
<div align="center">
  <table cellspacing=0 cellpadding=0 border=0 width=200 align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;<b>CONFIGURE CALENDAR: $http_in->{Calendar}</b>
        </font></td>
    </tr>
    <tr bgcolor="#FEFEE2"> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0 width=300>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2"> 
            <font face="Arial, Helvetica"><div align="center"><b>What do you want to do?</b></div><br />
            <font size=2><b>
            <ul>
            <li><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&Setup=Config&session=$user->{session}">Configure Current Calendar.</a><p></li>
            $password_item
            <li><a href="$config->{admin_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">Return to Calendar Admin Page</a><p></li>
            <li><a href="$config->{calendar_homepage}$config->{cal_url}?Calendar=$http_in->{Calendar}">Calendar Home</a><p></li>
            </ul>
            </b></font></font>
            </td>
          </tr>
        </table>
        <table cellspacing=0 cellpadding=4 border=0 width=100 align="center">
        <tr bgcolor="#FEFEE2"><td align="left" bgcolor="#FEFEE2"><font face="Arial, Helvetica">
OPTIONS
   CyberCalendar::Application::show_calendar_list($user->{uid},
                                                  $user->{cal_list},
                                                  qq(<input type="hidden" name="session" value="$user->{session}">),
                                                  $config->{setup_url},
                                                  $config->{select_img});
   print qq(        </font></tr></td>
        </table>
      </td>
    </tr>
  </table>
</td>
</tr>
</table>
$admin_options
</div>
</body>
</html>
);
} # endsub option_form

sub acl_form {
   my $query = '';
   my $calrows = 0;
   my $result = {};
   my @calendar_list = ();
   my @access_list = ();
   my @calendars = ();

   $query = "SELECT distinct calendar, name from calendars
            ORDER BY name ASC";
   $db->query($query);
   $calrows = $db->rowcount;
   if ($calrows != 0) {
      while ($result = $db->result("hashref")) {
         push(@calendar_list, qq(<option value="$result->{calendar}"> $result->{name} ($result->{calendar})</option>));
      } # foreach
   } # if
   $db->finish;

   $query = "SELECT distinct calendars.name, acl.* FROM calendars, acl
            WHERE acl.uid = ?
            AND calendars.calendar = acl.calendar
            ORDER BY calendars.name ASC";
   $db->query($query, $_[0]->{uid});
   $calrows = $db->rowcount;
   if ($calrows != 0) {
      while ($result = $db->result("hashref")) {
         my $owner = '';
         $owner = 'Owner:' if $result->{full_ctrl} == 1;
         push(@access_list, qq(<option value="$result->{calendar}">$owner $result->{name} ($result->{calendar})</option>));
      } # while
   } # if
   $db->finish;

   my $aclform = <<"ACLFORM";
<br />
<table cellpadding="0" cellspacing="0" border="0" align="center" valign="top" width="450">
  <tr align="left" bgcolor="black">
    <td width="450"  align="left">
    <font face = "Verdana, Arial, Helvetica" color="white" size="1"><b>&nbsp;&nbsp;GRANT ACCESS TO CALENDARS</b></font>
    </td>
  </tr>
  <tr align="left" valign="top"  bgcolor="#FEFEE2">
    <td width="450" align="center" valign="top">
    <form action="$config->{setup_url}" method="post">
    <font face="Arial, Helvetica, sans-serif" size="2"><b>
    <input type="hidden" name="session" value="$http_in->{session}" />
    <input type="hidden" name="uid" value="$_[0]->{uid}" />
    <input type="hidden" name="Setup" value="SaveACL" />
    <select name="add_access" size="1">
    <option value="" selected>Select Calendar...</option>
    @calendar_list
    </select><br />
    Make Owner:&nbsp;<input type="checkbox" name="make_owner" value="make_owner" />
    <br /><input name="submit" value="Grant Access" type="submit" /><br />
    </b></font>
    </form>
    </td></tr>
    <tr align="left" valign="top"bgcolor="black">
      <td width="450" align="left" valign="top">
      <font face = "Verdana, Arial, Helvetica" color="white" size="1"><b>&nbsp;&nbsp;REMOVE ACCESS TO CALENDARS</b></font>
      </td>
    </tr>
    <tr bgcolor="#FEFEE2"><td width="450" align="center" valign="top">
    <form action="$config->{setup_url}" method="post">
    <font face="Arial, Helvetica sans-serif" size="2"><b>
    <input type="hidden" name="session" value="$http_in->{session}" />
    <input type="hidden" name="uid" value="$_[0]->{uid}" />
    <input type="hidden" name="Setup" value="SaveACL" />
    <select name="remove_access" size="1">
    <option value="" selected>Select Calendar...</option>
    @access_list
    </select><br />
    Only Remove Ownership:&nbsp;<input type="checkbox" name="remove_owner" value="make_owner" />
    <br /><input name="submit" value="Remove Access" type="submit" /><br />
    </b></font>
    </form>
    </td>
  </tr>
</table>
<br />
ACLFORM
   return $aclform;
} # endsub acl_form

sub user_form {
   check_perms();
   my $delete_user = '';
   my $title = 'NEW USER';
   my $password = qq(<tr><td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Password: </b><font size="2">(25 chars max)</font><b>:</b></font></td>
      <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="password" name="password" size="25" maxlength="25">
      </font></td></tr>);
   if ($config->{session_type} == 0 || $config->{session_type} == 1) { $password = ''; }
   my $user_stats = '';
   my $selected = qq(<option value="1" SELECTED>Select User Access Level...</option>);
   my $setup = qq(<input type="hidden" name="Setup" value="NewUser">);
   if (exists $_[0]->{uid}) {
      $delete_user = qq(<form method="post" action="setup.pl" onSubmit="return confirm('Are you sure you want to delete this user?')"><font face="Arial, Helvetica, sans-serif"><b>
      <input type="hidden" name="Setup" value="DeleteUser">
      <input type="hidden" name="uid" value="$_[0]->{uid}">
      <input type="hidden" name="Calendar" value="$http_in->{Calendar}">
      <input type="hidden" name="session" value="$user->{session}">
      <input type="submit" name="submit" value="Delete User: $_[0]->{username}">
      </b></font></form>);
      $delete_user = '' if $_[0]->{uid} == $user->{uid};
      $title = 'EDIT USER';
      $password =  qq(<tr><td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Change Password: </b><font size="2">(25 chars max)</font><b>:</b></font></td>
      <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="password" name="password" size="25" maxlength="25">
      </font></td></tr>);
      $password = '' if $_[0]->{uid} == $user->{uid};
      $user_stats = qq(<tr><td colspan=2>&nbsp;</td></tr>
      <tr><td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Last login date/time:</b></font></td>
      <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      $_[0]->{lastlogin}</font></td></tr><tr><td colspan=2>&nbsp;</td></tr>
      <tr><td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Last login from host:</b></font></td>
      <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      $_[0]->{lasthost}</font></td></tr><tr><td colspan=2>&nbsp;</td></tr>);
      $selected = qq(<option value="$_[0]->{accesslevel}" SELECTED>$_[0]->{accesslevel}</option>);
      $setup = qq(<input type="hidden" name="Setup" value="EditUser">);
   }
   my $userform = <<"USERFORM";
<html><head><title>User Setup</title></head>
<body bgcolor="#FFFFFF">
<div align=center>
$delete_user
<font face="Arial, Helvetica, sans-serif"><b>$_[1]</b></font>
<form method="post" action="$config->{setup_url}">
  <table cellspacing=0 cellpadding=0 border=0  align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;<b>$title</b><br />
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2">
<table width="450" border="0" cellspacing="0" cellpadding="0">
  <tr> 
    <td colspan="2"> 
      <div align="center"></div>
    </td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Username: 
      </b><font size="2">(25 chars max, no spaces)</font><b>:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="username" size="25" maxlength="25" value="$_[0]->{username}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
$password
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Access Level:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <select name="accesslevel">
        $selected
        <option value="1">1 Administrator</option>
        <option value="2">2 Editor</option>
      </select>
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Full Name:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="fullname" size="25" value="$_[0]->{fullname}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>E-Mail:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="email" size="25" value="$_[0]->{email}">
      </font></td>
  </tr>
$user_stats
<tr><td colspan=2>&nbsp;<input type="hidden" name="Calendar" value="$http_in->{Calendar}">
$setup
<input type="hidden" name="uid" value="$_[0]->{uid}">
<input type="hidden" name="SaveUser" value="SaveUser">
<input type="hidden" name="session" value="$user->{session}"></td></tr>
</table>
            </td>
          </tr>
        </table>
      </td>
    </tr>
    <tr><td colspan=2 align=center bgcolor="#000000"><input type="image" src="images/save.png" border="0" name="Save" width="126" height="15"></td></tr>
  </table>
</form>
<b><font face ="Verdana, Arial, Helvetica"><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">&lt;&lt; Back</a></font></b></div>
USERFORM

   if (exists $_[0]->{uid}) {
      my $user = get_user_info($_[0]->{uid});
      $userform .= acl_form($_[0]) if $_[0]->{accesslevel} != 1;
   } # if
   $userform .= qq(</body></html>);
   return $userform;
} # endsub user_form

sub password_form {
   return <<"PWD";
<html><head><title>Change Password</title></head>
<body bgcolor="#FFFFFF">
<form method="post" action="$config->{setup_url}">
  <div align="center"><font face="Verdana, Arial, Helvetica, sans-serif"><b><font color="red">$_[0]</font><br />
Change Password</b></font><br />
  <table cellspacing=0 cellpadding=0 border=0 width=200 align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;<b>NEW PASSWORD:</b><br />
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0 width=200>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2">&nbsp;&nbsp; 
              <input type=password maxlength=25 size=25 name="password">
            </td>
          </tr>
        </table>
      </td>
    </tr>
  </table>
  <table cellspacing=0 cellpadding=0 border=0 width=200 align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;&nbsp;<b>CONFIRM PASSWORD:</b><br />
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0 width=200>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2">&nbsp;&nbsp; 
              <input type=password maxlength=25 size=25 name="password2">
            </td>
          </tr>
        </table>
      </td>
    </tr>
       <tr><td align="center" bgcolor="#FEFEE2">&nbsp;
    <input type="hidden" name="pwd" value="pwd">
    <input type="hidden" name="session" value="$user->{session}">
    <input type="hidden" name="Setup" value="ChangePassword">
    <input type="hidden" name="Calendar" value="$http_in->{Calendar}"></td></tr>
    <tr><td align="center" bgcolor="#000000"><input type="image" src="images/save.png" border="0" name="Save" width="126" height="15"></td></tr>
  </table>
</form>
<b><font face ="Verdana, Arial, Helvetica"><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">&lt;&lt; Back</a></font></b>
</div>
</body>
</html>
PWD
} # endsub password_form

sub calendar_form {
   check_perms();
   my $public = "CHECKED" if $_[0]->{isviewable} == 1;
   my $query = "SELECT uid, username, fullname from users ORDER BY username";
   $db->query($query);
   my @users = ();
   while (my $users = $db->result("hashref")) {
      push(@users, qq(<option value="$users->{uid}">$users->{username} ($users->{fullname})</option>\n));
   } # while
   $db->finish;
   my $owner_info = qq(<tr><td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Owner:</b></font></td>
   <td valign="top"><font face="Arial, Helvetica, sans-serif"> 
   <select name="uid"><option value="">Select owner...</option>@users
   </select></font></td></tr>\n);
   my $calform = <<"CALFORM";
<html><head><title>Calendar Setup</title></head>
<body bgcolor="#FFFFFF">
<div align=center>
<form method="post" action="$config->{setup_url}">
  <table cellspacing=0 cellpadding=0 border=0  align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;<b>NEW CALENDAR</b><br />
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2">
<table width="450" border="0" cellspacing="0" cellpadding="0">
  <tr> 
    <td colspan="2"> 
      <div align="center"></div>
    </td>
  </tr>
$owner_info

<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>This is the default
    calendar:</b></font></td>
    <td valign="top"> 
      <input type="checkbox" name="is_default" value="1">
  </td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>This calendar is visible
    in the calendar list:</b></font></td>
    <td valign="top"> 
      <input type="checkbox" name="is_visible" value="1" CHECKED>
  </td>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Allow public submission of events:</b></font></td>
    <td valign="top"> 
      <select name="public_event_submit">
      <option value="0">No</option>
      <option value="1">Yes, but hold them for Admin approval.</option>
      <option value="2">Yes, insert them directly into calendar.</option>
      </select>
  </td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Time Zone</b><font size="2"></font><b>:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <select name="timezone">
        <option value="GMT" selected>Select Timzone...</option>
        <option value="GMT">GMT (Greenwich Mean)</option>
        <option value="WET">WET (Western European Time)</option>
        <option value="WAT">WAT (Western Africa)</option>
        <option value="AT">AT (Azores)</option>
        <option value="AST">AST (Atlantic Standard)</option>
        <option value="EDT">EST (Eastern US/CAN)</option>
        <option value="CST">CST (Central US/CAN/MEX)</option>
        <option value="MST">MST (Mountain US/CAN/MEX)</option>
        <option value="PST">PST (Pacific US/CAN/MEX)</option>
        <option value="YST">YST (Yukon Standard)</option>
        <option value="AKST">AKST (Alaska US)</option>
        <option value="AST">AST (Aleutian US)</option>
        <option value="HST">HST (Hawaii US)</option>
        <option value="NZSTT">NZST (New Zealand/Fiji)</option>
        <option value="EAST">EAST (East Australian)</option>
        <option value="WAST">WAST (West Australian)</option>
        <option value="GST">GST (Gua/Russia 9)</option>
        <option value="JST">JST (Japan Standard/Russia 8)</option>
        <option value="CCT">CCT (China Coast/Russia 7)</option>
        <option value="BT">BT (Bagdad/Russia 2)</option>
        <option value="EET">EET (Eastern Europe/Russia 1)</option>
        <option value="CET">CET (Central Europe)</option>
        <option value="MET">MET (Middle Europe)</option>
      </select>
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Show Full-Size 
      Calendar</b><font size="2"></font><b></b><b>:</b></font></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif"> 
      <input type="checkbox" name="show_large_calendar" value="1" CHECKED>
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Calendar Table Name: 
      </b><font size="2">(25 chars max, no spaces)</font><b>:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="calendar" size="25" maxlength="25">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Descriptive 
      Name: </b><font size="2">(255 chars max)</font><b>:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="name" size="25" value="$_[0]->{name}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>HTML Template:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="template" size="25" value="$config->{template}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Site Homepage:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="site_homepage" size="25" value="$config->{site_homepage}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Calendar Homepage:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="calendar_homepage" size="25" value="$config->{calendar_homepage}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Calendar Description 
      </b><font size="2">(255 chars max)</font><b></b><b>:</b></font></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="description" size="25" value="$_[0]->{description}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Admin Notes:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <textarea name="notes" cols="25" rows="3">$_[0]->{notes}</textarea>
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;<input type="hidden" name="Calendar" value="$_[0]->{calendar}">
<input type="hidden" name="Setup" value="NewCal">
<input type="hidden" name="SaveCalendar" value="SaveCalendar">
<input type="hidden" name="session" value="$user->{session}"></td></tr>
</table>
            </td>
          </tr>
        </table>
      </td>
    </tr>
<tr><td colspan=2 align=center bgcolor="#000000"><input type="image" src="images/save.png" border="0" name="Save" width="126" height="15"></td></tr>
  </table>
</form>
<b><font face ="Verdana, Arial, Helvetica"><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">&lt;&lt; Back</a></font></b>
</div>
</body></html>
CALFORM
   return $calform;
} # endsub calendar_form

sub config_form {
   my $is_visible = 'CHECKED' if $_[1]->{is_visible} == 1;
   my $public_sub = qq(\n<option value="0">No</option>);
   if ($_[0]->{public_event_submit} == 1) {
      $public_sub =  qq(\n<option value="1">Yes, but hold them for Admin approval.</option>) if $_[0]->{public_direct_submit} == 0;
      $public_sub = qq(\n<option value="2">Yes, insert them directly into calendar.</option>) if $_[0]->{public_direct_submit} == 1;
   } # if
   my $show_large = 'CHECKED' if $_[0]->{show_large_calendar} == 1;
   my $apply_all = '';
   my $admin_notes = '';
   my $owner_info = '';
   my $delete_calendar = '';
   my $default_cal = '';
   if ($user->{accesslevel} == 1) {
      $delete_calendar = qq(
      <form method="post" action="setup.pl" onSubmit="return confirm('Are you sure you want to delete this calendar?')"><font face="Arial, Helvetica, sans-serif"><b>
      <input type="hidden" name="Setup" value="DeleteCalendar">
      <input type="hidden" name="Calendar" value="$_[0]->{calendar}">
      <input type="hidden" name="session" value="$user->{session}">
      <input type="submit" name="submit" value="Delete Calendar: $_[0]->{calendar}">
      </b></font></form>);
      $delete_calendar = '' if $_[0]->{calendar} eq $config->{default_calendar};
      $admin_notes = qq(
      <tr><td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Admin Notes:</b></font></td>
      <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <textarea name="notes" cols="25" rows="3">$_[1]->{notes}</textarea>
      </font></td></tr>);
      $apply_all = qq(
      <tr><td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Apply Changes to All Calendars:</b></font></td>
      <td valign="top"> <font face="Arial, Helvetica, sans-serif"><input type="checkbox" name="apply_all" value="apply_all">
      </font></td></tr>);
      my $query = "SELECT uid, username, fullname from users ORDER BY username";
      $db->query($query);
      my $selected = '';
      my @users = ();
      while (my $users = $db->result("hashref")) {
         $selected = qq(<option value="$users->{uid}" SELECTED>$users->{username} ($users->{fullname})</option>\n) if $users->{uid} == $_[0]->{uid};
         push(@users, qq(<option value="$users->{uid}">$users->{username} ($users->{fullname})</option>\n));
      } # while
      $db->finish;
      $owner_info = qq(<tr><td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Owner:</b></font></td>
      <td valign="top"><font face="Arial, Helvetica, sans-serif"> 
      <select name="uid">$selected @users
      </select></font></td></tr>\n);
      my $is_default = 'CHECKED' if $_[0]->{is_default} == 1;
      $default_cal = qq(<tr><td colspan=2>&nbsp;</td></tr><tr> 
      <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>This is the default calendar:</b></font></td>
      <td valign="top"><input type="checkbox" name="is_default" value="1" $is_default></td></tr>);
   } # if

return <<"CONFIG";
<html><head><title>Calendar Setup</title></head>
<body bgcolor="#FFFFFF">
<div align=center>
$delete_calendar
<form method="post" action="setup.pl">
  <table cellspacing=0 cellpadding=0 border=0  align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;<b>CONFIGURATION FOR CALENDAR: $http_in->{Calendar}</b><br />
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2">
<table width="450" border="0" cellspacing="0" cellpadding="0">
<tr><td colspan=2>&nbsp;</td></tr>
$owner_info
$default_cal
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>This calendar is visible
    in the calendar list:</b></font></td>
    <td valign="top"> 
      <input type="checkbox" name="is_visible" value="1" $is_visible>
  </td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Allow public submission of events:</b></font></td>
    <td valign="top">
      <select name="public_event_submit">$public_sub
      <option value="0">No</option>
      <option value="1">Yes, but hold them for Admin approval.</option>
      <option value="2">Yes, insert them directly into calendar.</option>
      </select>
  </td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr>
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Descriptive 
      Name </b><font size="2">(255 chars max)</font><b>:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="name" size="25" value="$_[1]->{name}">
      </font></td>
  </tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Calendar Description 
      </b><font size="2">(255 chars max)</font><b></b><b>:</b></font></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="description" size="25" value="$_[1]->{description}">
      </font></td>
  </tr>
$admin_notes
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>HTML Template:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="template" size="25" value="$_[0]->{template}">
      </font></td>
  </tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Site Homepage:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="site_homepage" size="25" value="$_[0]->{site_homepage}">
      </font></td>
  </tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Calendar Homepage:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <input type="text" name="calendar_homepage" size="25" value="$_[0]->{calendar_homepage}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Time Zone</b><font size="2"></font><b>:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <select name="timezone">
        <option value="$_[0]->{timezone}" selected>$_[0]->{timezone}</option>
        <option value="GMT">GMT (Greenwich Mean)</option>
        <option value="WET">WET (Western European Time)</option>
        <option value="WAT">WAT (Western Africa)</option>
        <option value="AT">AT (Azores)</option>
        <option value="AST">AST (Atlantic Standard)</option>
        <option value="EDT">EST (Eastern US/CAN)</option>
        <option value="CST">CST (Central US/CAN/MEX)</option>
        <option value="MST">MST (Mountain US/CAN/MEX)</option>
        <option value="PST">PST (Pacific US/CAN/MEX)</option>
        <option value="YST">YST (Yukon Standard)</option>
        <option value="AKST">AKST (Alaska US)</option>
        <option value="AST">AST (Aleutian US)</option>
        <option value="HST">HST (Hawaii US)</option>
        <option value="NZSTT">NZST (New Zealand/Fiji)</option>
        <option value="EAST">EAST (East Australian)</option>
        <option value="WAST">WAST (West Australian)</option>
        <option value="GST">GST (Gua/Russia 9)</option>
        <option value="JST">JST (Japan Standard/Russia 8)</option>
        <option value="CCT">CCT (China Coast/Russia 7)</option>
        <option value="BT">BT (Bagdad/Russia 2)</option>
        <option value="EET">EET (Eastern Europe/Russia 1)</option>
        <option value="CET">CET (Central Europe)</option>
        <option value="MET">MET (Middle Europe)</option>
      </select>
      </font></td>
  </tr>
<tr><td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Other Timezone</b></font></td>
<td valign="top"><input type="text" name=other_tz size="3" width="4"></td>
</tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Show Full-Size 
      Calendar</b><font size="2"></font><b></b><b>:</b></font></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif"> 
      <input type="checkbox" name="show_large_calendar" value="1" $show_large>
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Large Calendar Width</b> <font size="2">(in pixels)</font><b></b><b>:</b></font></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif"> 
      <select name="large_calendar_width"><option value="$_[0]->{large_calendar_width}">$_[0]->{large_calendar_width}</option>
      <option value="595">595</option><option value="581">581</option><option value="574">574</option><option value="567">567</option></select>
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"> 
      <p><font face="Arial, Helvetica, sans-serif"><b>If you are using the SMALL 
        calendar, how many calendar months should be displayed? </b><font size="2">(default 
        1)</font><b>:</b></font></p>
    </td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <select name="show_calendars">
        <option value="$_[0]->{show_calendars}" selected>$_[0]->{show_calendars}</option>
        <option value="1">1</option>
        <option value="2">2</option>
        <option value="3">3</option>
      </select>
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>If you are using 
      the SMALL calendar, how many days worth of events would you like displayed?:</b></font></td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <select name="show_days">
        <option value="$_[0]->{show_days}" selected>$_[0]->{show_days}</option>
        <option value="0">0</option>
        <option value="1">1</option>
        <option value="2">2</option>
        <option value="3">3</option>
        <option value="4">4</option>
        <option value="5">5</option>
        <option value="6">6</option>
        <option value="7">7</option>
      </select>
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"> 
      <p><font face="Arial, Helvetica, sans-serif"><b>Truncate the lines of subject text in event listing.</b> <font size="2">(default 
        0 = no truncation)</font><b>:</b></font></p>
    </td>
    <td valign="top"> <font face="Arial, Helvetica, sans-serif"> 
      <select name="show_lines">
        <option value="$_[0]->{show_lines}" selected>$_[0]->{show_lines}</option>
        <option value="0">0 Don\'t truncate</option>
        <option value="2">2 lines</option>
        <option value="3">3 lines</option>
        <option value="4">4 lines</option>
        <option value="5">5 lines</option>
      </select>
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><font face="Arial, Helvetica, sans-serif"><b>Page Body Background 
      Color:</b></font></td>
    <td valign="top"> 
      <input type="text" name="body_bg_color" size="25" maxlength="25" value="$_[0]->{body_bg_color}">
    </td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Page Title Font:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="page_title_font" value="$_[0]->{page_title_font}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Page Title Font 
      Size:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="page_title_font_size" value="$_[0]->{page_title_font_size}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Page Title Var 
      Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="page_title_var_color" value="$_[0]->{page_title_var_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Trim Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_trimcolor" value="$_[0]->{cal_trimcolor}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Head 
      Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_head_color" value="$_[0]->{cal_head_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Head 
      Text Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_head_text_color" value="$_[0]->{cal_head_text_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Head 
      Font:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_head_font" value="$_[0]->{cal_head_font}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Head 
      Font Size:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_head_font_size" value="$_[0]->{cal_head_font_size}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Background Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_bg_color" value="$_[0]->{cal_bg_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Text Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_text_color" value="$_[0]->{cal_text_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Font:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_font" value="$_[0]->{cal_font}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Month/Year 
      Font Size:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_month_year_fontsize" value="$_[0]->{cal_month_year_fontsize}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Days 
      Font Size:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_days_font_size" value="$_[0]->{cal_days_font_size}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Dates 
      Font Size:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_dates_font_size" value="$_[0]->{cal_dates_font_size}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Featured Event 
      Head Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="featured_head_color" value="$_[0]->{featured_head_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Featured Event 
      Head Text Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="featured_head_text_color" value="$_[0]->{featured_head_text_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Featured Event 
      Link Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="featured_link_color" value="$_[0]->{featured_link_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Event Head Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="event_head_color" value="$_[0]->{event_head_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Event Head Text 
      Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="event_head_text_color" value="$_[0]->{event_head_text_color}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Event Head Font:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="event_head_font" value="$_[0]->{event_head_font}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Event Head Font 
      Size:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="event_head_font_size" value="$_[0]->{event_head_font_size}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Event Body bgcolor:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="event_body_bgcolor" value="$_[0]->{event_body_bgcolor}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Event Body Text 
      Color Detail:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="event_body_text_color_detail" value="$_[0]->{event_body_text_color_detail}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Event Body Text 
      Color Body:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="event_body_text_color_body" value="$_[0]->{event_body_text_color_body}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Event Body Font:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="event_body_font" value="$_[0]->{event_body_font}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Event Body Font 
      Size:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="event_body_font_size" value="$_[0]->{event_body_font_size}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Select Image:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_img" value="$_[0]->{cal_img}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr>
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Select Image 
      Alt Text:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_img_alt" value="$_[0]->{cal_img_alt}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Select Image 
      Width:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_img_width" value="$_[0]->{cal_img_width}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Calendar Select Image 
      Height:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="cal_img_height" value="$_[0]->{cal_img_height}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Browse Image:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="browse_img" value="$_[0]->{browse_img}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Browse Image 
      Alt Text:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="browse_img_alt" value="$_[0]->{browse_img_alt}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Browse Image 
      Width:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="browse_img_width" value="$_[0]->{browse_img_width}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Browse Image 
      Height:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="browse_img_height" value="$_[0]->{browse_img_height}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Search Image:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="search_img" value="$_[0]->{search_img}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Search Image 
      Alt Text:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="search_img_alt" value="$_[0]->{search_img_alt}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Search Image 
      Width:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="search_img_width" value="$_[0]->{search_img_width}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Search Image 
      Height:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="search_img_height" value="$_[0]->{search_img_height}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Help Image:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="help_img" value="$_[0]->{help_img}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Help Image 
      Alt Text:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="help_img_alt" value="$_[0]->{help_img_alt}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Help Image 
      Width:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="help_img_width" value="$_[0]->{help_img_width}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Help Image 
      Height:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="help_img_height" value="$_[0]->{help_img_height}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">From Address:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="from_address" value="$_[0]->{from_address}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">Mail Message 
      Title:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="mail_message_title" value="$_[0]->{mail_message_title}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">HTML Mail bgcolor:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="html_mail_bgcolor" value="$_[0]->{html_mail_bgcolor}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">HTML Mail Body 
      Font:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="html_mail_body_font" value="$_[0]->{html_mail_body_font}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">HTML Mail Body 
      Font Size:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="html_mail_body_fontsize" value="$_[0]->{html_mail_body_fontsize}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
  <tr> 
    <td valign="top"><b><font face="Arial, Helvetica, sans-serif">HTML Mail Body 
      Text Color:</font></b></td>
    <td valign="top"><font face="Arial, Helvetica, sans-serif">
      <input type="text" name="html_mail_body_textcolor" value="$_[0]->{html_mail_body_textcolor}">
      </font></td>
  </tr>
<tr><td colspan=2>&nbsp;</td></tr>
$apply_all
<tr>
<input type="hidden" name="Setup" value="Config">
<input type="hidden" name="SaveConfig" value="SaveConfig">
<input type="hidden" name="Calendar" value="$http_in->{Calendar}">
<input type="hidden" name="session" value="$user->{session}">
</td></tr>
</table>
            </td>
          </tr>
        </table>
      </td>
    </tr>
<tr><td colspan=2 align=center bgcolor="#000000"><input type="image" src="images/save.png" border="0" name="Save" width="126" height="15"></td></tr>
  </table>
</form>
<b><font face ="Verdana, Arial, Helvetica"><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&session=$user->{session}">&lt;&lt; Back</a></font></b>
</div>
</html>
CONFIG
} # endsub config_form

#-----------------------------------------------------------------------#

sub check_perms {
   if ($user->{accesslevel} != 1
      and $config->{session_type} != 0) {
      my_error("no", "Permission Denied.");
      my_exit();
   }
} # endsub check_perms

sub my_error {
   CyberCalendar::Application::my_error($_[0], $_[1]);
} # endsub my_error

sub my_exit {
   CyberCalendar::Application::my_exit();
} # endsub my_exit

sub DESTROY {
    my $self = shift;
    my $hashref = {};
} # endsub DESTROY
1;
