#!/usr/bin/perl -w
###################################################################
#
# CyberCalendar v1.8.2
#
# Administrator login script
# Copyright 1999, 2000, 2001 Shawn Ewald <shawn@cyberweavers.com>
#
###################################################################
# License:                                                        #
#-----------------------------------------------------------------#
# This program is free software; you can redistribute it and/or   #
# modify it under the terms of the GNU General Public License     #
# as published by the Free Software Foundation; either version 2  #
# of the License, or (at your option) any later version.          #
#                                                                 #
# This program is distributed in the hope that it will be useful, #
# but WITHOUT ANY WARRANTY; without even the implied warranty of  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
###################################################################
# For the full text of the GNU General Public License, go to:     #
# http://www.gnu.org/copyleft/gpl.html                            #
###################################################################
# Script Modules
use CyberCalendar::Application;
use strict;

my $login = '';
my $session = '';
my $config = '';
my $db = '';
my $http_in = '';


go();

sub go {
   $login = CyberCalendar::Application->new();
   $login->init('', 'no_error');

   $session = '';
   $config = $CyberCalendar::Application::config;
   $db = $CyberCalendar::Application::db;
   $http_in = $CyberCalendar::Application::http_in;

   if ($config->{session_type} == 0) {
      admin_calendar_list('null_session');
      CyberCalendar::Application::my_exit();
   }

   elsif ($config->{session_type} == 1) { check_login(); }

   elsif ($http_in->{login}) {
      if ($http_in->{username} eq ''
         or $http_in->{password} eq '') {
         print show_login("You must enter a username AND a password.");
      } # if
      else { check_login(); }
      # else
   } # if
   else { print show_login(); }
# else
}

sub check_login {
   my $calendar_list = ();
   my $query = '';
   if ($config->{session_type} == 1) {
      $query = "SELECT uid, accesslevel from users
                WHERE username = ?";
      $db->query($query, $http_in->{auth_user});
   } # if
   else {
      $query = "SELECT uid, accesslevel from users
                WHERE username = ?
                AND password = password(?)";
      $db->query($query, $http_in->{username}, $http_in->{password});
   } # else
   if ($db->rowcount == 1) {
      my $user = $db->result("hashref");
      $db->finish;
      my $session = make_sessionid();
      my $lastlogin = CyberCalendar::Calendar::datenow() . " " . CyberCalendar::Calendar::timenow();
      if ($config->{session_type} == 1) {
         $query = "UPDATE users set
                   lastlogin = ?,
                   lasthost = ?,
                   sessionid = ?
                   WHERE username = ?";
         $db->query($query, $lastlogin, $http_in->{remote_addr}, $session, $http_in->{auth_user});
         $db->finish;
      } # if
      else {
         $db->finish;
         $query = "UPDATE users set
                   lastlogin = ?,
                   lasthost = ?,
                   sessionid = ?
                   WHERE username = ?
                   AND password = password(?)";
         $db->query($query, $lastlogin, $http_in->{remote_addr}, $session, $http_in->{username}, $http_in->{password});
         $db->finish;
      } # else

      if ($user->{accesslevel} == 1) {
         admin_calendar_list($session);
      } # if
      else {
         $query = "SELECT distinct acl.calendar, acl.full_ctrl, calendars.name from acl, calendars
                   WHERE acl.uid = ?
                   AND acl.calendar = calendars.calendar
                   ORDER BY acl.full_ctrl DESC";
         $db->query($query, $user->{uid});
         my $rows = $db->rowcount;
         if ($rows == 0) { $db->finish; CyberCalendar::Application::my_error("no", "Permission Denied. You do not have access to any calendars."); }
         # if
         else {
            while (my $calendars = $db->result("hashref")) {
               my $full_ctrl = '';
               $full_ctrl = qq( |<a href="$config->{setup_url}?Calendar=$calendars->{calendar}&session=$session">Config</a>) if $calendars->{full_ctrl} == 1;
               push(@{ $calendar_list }, qq(<li>$calendars->{name} <a href="$config->{admin_url}?Calendar=$calendars->{calendar}&session=$session">Edit</a> $full_ctrl</li>));
            } # while
            print show_calendar_select($calendar_list);
         } # else
      } # else
   } # if 
   else { $db->finish; print show_login("Login Incorrect."); }
   # else
} # endsub check_login

sub admin_calendar_list {
      my $query = "SELECT uid, username, fullname from users ORDER BY username";
      $db->query($query);
      my $edit_user = '';
      my @users = ();
      while (my $users = $db->result("hashref")) {
         push(@users, qq(<option value="$users->{uid}">$users->{username} ($users->{fullname})</option>\n));
      } # while
      $db->finish;   
      $edit_user = qq(<form method="post" action="$config->{setup_url}"><font face="Arial, Helvetica, sans-serif"> 
      <select name="uid"><option value="">Edit a User Account</option>\n@users
      </select><input type="submit" name="submit" value="Edit"></font><input type="hidden" name="Setup" value="EditUser">
      <input type="hidden" name="Calendar" value="$config->{default_calendar}"><input type="hidden" name="session" value="$_[0]"></form>\n);
      $edit_user = '' if $config->{session_type} == 0;
      my $new_user = qq(<li><a href="$config->{setup_url}?Calendar=$http_in->{Calendar}&Setup=NewUser&session=$_[0]">Create a New User Account.</a><p></li>);
      $new_user = '' if $config->{session_type} == 0;

      my $admin_options = qq(<p><table cellspacing=0 cellpadding=0 border=0 width=300 align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;<b>ADMINISTRATOR OPTIONS:</b>
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0 width=300>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2"><font face="Arial, Helvetica"><br>
            <font size=2><b>
            <ul>
            <li><a href="$config->{setup_url}?Calendar=$config->{default_calendar}&Setup=NewCal&session=$_[0]">Create a New Calendar.</a><p></li>
            $new_user
            </ul>
            <div align="center">$edit_user</div>
            </b></font></font>
            </td>
          </tr>
        </table>
      </td>
    </tr>
  </table>
</td>
</tr>
</table>);
   my $calendar_list = ();
   $query = "SELECT calendar, name from calendars ORDER BY name ASC";
   $db->query($query);
   while (my $calendars = $db->result("hashref")) {
      push(@{ $calendar_list }, qq(<li>$calendars->{name} <a href="$config->{admin_url}?Calendar=$calendars->{calendar}&session=$_[0]">Edit</a> | <a href="$config->{setup_url}?Calendar=$calendars->{calendar}&session=$_[0]">Config</a></li>));
   } # while
   $db->finish;
   print show_calendar_select($calendar_list, $admin_options);
} # endsub admin_calendar_list

sub make_sessionid {
   my @chars = ("A".."Z", "a".."z", 0..9);
   return join("", @chars[ map { rand @chars } (1..21) ]);
} # endsub make_sessionid

sub show_login {
   return <<"LOGIN";
<html><head><title>Login</title></head>
<body bgcolor="#FFFFFF">
<form method="post" action="index.pl" name="">
  <p align="center"><font face="Verdana, Arial, Helvetica, sans-serif"><b><font color="red">$_[0]</font><br>
Calendar Administrator Login</b></font><br>
  <table cellspacing=0 cellpadding=0 border=0 width=200 align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;<b>USERNAME:</b><br>
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0 width=200>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2">&nbsp;&nbsp; 
              <input type=TEXT maxlength=25 size=25 name="username">
            </td>
          </tr>
        </table>
      </td>
    </tr>
  </table>
  <table cellspacing=0 cellpadding=0 border=0 width=200 align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"> <font face = "Verdana, Arial, Helvetica" color=WHITE size=" 1"> 
        &nbsp;&nbsp;&nbsp;<b>PASSWORD:</b><br>
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0 width=200>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2">&nbsp;&nbsp; 
              <input type=password maxlength=25 size=25 name="password">
            </td>
          </tr>
        </table>
      </td>
    </tr>
  </table>
  <div align="center">
    <input type="hidden" name="login" value="login">
    <input type="submit" name="Submit" value="Login">
  </div>
</form>
</p>
</body>
</html>
LOGIN
} # endsub login

sub show_calendar_select {
   return <<"SELECT";
<html><head><title>Select Calendar</title></head>
<body bgcolor="#FFFFFF">
  <p align="center">
  <table cellspacing=0 cellpadding=0 border=0 width=300 align="center">
    <tr> 
      <td align="LEFT" bgcolor="#000000"><font face = "Verdana, Arial, Helvetica" color=WHITE size="1"> 
        &nbsp;&nbsp;<b>SELECT CALENDAR:</b><br>
        </font></td>
    </tr>
    <tr> 
      <td> 
        <table cellspacing=0 cellpadding=4 border=0 width=300>
          <tr> 
            <td align="LEFT" bgcolor="#FEFEE2"><font face = "Arial, Helvetica" size="2"> 
              <b><ul>@{ $_[0] }</ul></b>
            </font></td>
          </tr>
        </table>
      </td>
    </tr>
  </table>
</p>
$_[1]
</body>
</html>
SELECT
} # endsub show_calendar_select

############################################################################

CyberCalendar::Application::my_exit();
