#!/usr/bin/perl -w
###################################################################
# CyberCalendar v1.8.2
#
# Public Event Submission Form
# Copyright 1999, 2000, 2001 Shawn Ewald <shawn@cyberweavers.com>
#
###################################################################
# License:                                                        #
# ----------------------------------------------------------------#
# This program is free software; you can redistribute it and/or   #
# modify it under the terms of the GNU General Public License     #
# as published by the Free Software Foundation; either version 2  #
# of the License, or (at your option) any later version.          #
#                                                                 #
# This program is distributed in the hope that it will be useful, #
# but WITHOUT ANY WARRANTY; without even the implied warranty of  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
###################################################################
# For the full text of the GNU General Public License, go to:     #
# http://www.gnu.org/copyleft/gpl.html                            #
###################################################################
# Script Modules
use vars qw($config $db $http_in);
use CyberCalendar::Application;
use strict;

###################################################################

my $submit = CyberCalendar::Application->new();
$submit->init();

$config = $CyberCalendar::Application::config;
$db = $CyberCalendar::Application::db;
$http_in = $CyberCalendar::Application::http_in;

if ($config->{public_event_submit} != 1) {
   my_error("Sorry, public event submissions are not allowed for this calendar.");
   $submit->my_exit();
}

if (!exists $http_in->{Add}) {
   add_form();
   $http_in->{View} = 'Message';
   $submit->show_page();
} # if
else {
   process_submission();
} # else

sub process_submission {
   validate();
   $db->finish;
   my $string = '';
   my $table = '';
   my @chars = ( "A" .. "Z", "a" .. "z", 0 .. 9 );
   my $repeatid = join("", @chars[ map { rand @chars } (1 .. 25) ]);
   if ($config->{public_direct_submit} == 1) {
      $table = $http_in->{Calendar};
      my $email = $http_in->{sub_email};
      $email =~ s/\@/ at /g;
      $email =~ s/\./ dot /g;
      $http_in->{desctext} .= qq(\n<p>Submitted by: $http_in->{sub_name} &lt;<a href="mailto:$http_in->{sub_email}">$email</a>&gt;\n);
      my $query = "INSERT INTO $table (repeatid, dateid, enddate, event_day, event_month,
                                       event_year, subject, desctext, url, email,
                                       location, category, starttime, endtime)
                     VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
      $db->query($query, $repeatid, $http_in->{dateid}, $http_in->{enddate}, $http_in->{event_day},
            $http_in->{event_month}, $http_in->{event_year}, $http_in->{subject}, $http_in->{desctext},
            $http_in->{url}, $http_in->{email}, $http_in->{location}, $http_in->{Category}, $http_in->{starttime},
            $http_in->{endtime});
      $db->finish;
   } # if
   else {
      $table = 'submitted_events';
      $string = 'It will be reviewed for approval by the calendar administrator.';
      my $query = "INSERT INTO $table (calendar, sub_name, sub_email, repeatid,
                                       dateid, enddate, event_day, event_month,
                                       event_year, subject, desctext, url, email,
                                       location, category, starttime, endtime)
                     VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
      $db->query($query, $http_in->{Calendar}, $http_in->{sub_name}, $http_in->{sub_email}, $repeatid,
            $http_in->{dateid}, $http_in->{enddate}, $http_in->{event_day}, $http_in->{event_month},
            $http_in->{event_year}, $http_in->{subject}, $http_in->{desctext}, $http_in->{url},
            $http_in->{email}, $http_in->{location}, $http_in->{Category}, $http_in->{starttime},
            $http_in->{endtime});
      $db->finish;
   } # else
   $http_in->{View} = 'Message';
   $http_in->{Message} = qq(<div align="center"><b><font face="$config->{page_title_font}">Your event has been submitted successfully. $string<p><a href="$config->{cal_url}?Calendar=$http_in->{Calendar}" style="text-decoration:none">&lt&lt Back</a></font></b></div>);
   $submit->show_page();
} # endsub process_submission

sub validate {
   my %val = (sub_name => '',
              sub_email => '',
              event_month => 'NULL',
              event_day => 'NULL',
              event_year => 'NULL',
              subject => '',
              location => '',
              desctext => '');
   my %errors = (sub_name => 'YOUR NAME',
                 sub_email => 'YOUR EMAIL',
                 event_month => 'A CORRECT DATE',
                 event_day => 'A CORRECT DATE',
                 event_year => 'A CORRECT DATE',
                 subject => 'A SUBJECT',
                 location => 'A LOCATION',
                 desctext => 'DESCRIPTIVE TEXT');

   if ($http_in->{sub_email} !~ /.+@(.+)\.(\w\w)/o) {
      my_error("You must enter $errors{sub_email} into the form.");
      $submit->my_exit();
   } # if
   while (my($name, $value) = each(%val)) {
      if ($http_in->{$name} eq $value) {
         my_error("You must enter $errors{$name} into the form.");
         $submit->my_exit();
      } # if
   } # while
   $http_in->{dateid} = "$http_in->{event_year}\-$http_in->{event_month}\-$http_in->{event_day}";
if ($http_in->{hour} eq 'NULL'
   or $http_in->{min} eq 'NULL'
   and !exists $http_in->{TBA}) {
      my_error("You must enter A TIME for your event.");
      $submit->my_exit();
   } # if
   elsif (exists $http_in->{TBA}) {
      $http_in->{starttime} = '00:00:00';
   } # elsif
   else {
      $http_in->{starttime} = sprintf("%02d:%02d:00", ($http_in->{hour}, $http_in->{min}));
   } # else
   $http_in->{enddate} = '0000-00-00';
   if (exists $http_in->{end_month}
      and $http_in->{end_month} ne 'NULL'
      and exists $http_in->{end_day}
      and $http_in->{end_day} ne 'NULL'
      and exists $http_in->{end_year}
      and $http_in->{end_year} ne 'NULL') {
      $http_in->{enddate} = "$http_in->{end_year}\-$http_in->{end_month}\-$http_in->{end_day}";
   } # if
   if ($http_in->{end_hour} == 0) {
      $http_in->{endtime} = '00:00:00';
   } # if
   else {
      $http_in->{endtime} = sprintf("%02d:%02d:00", ($http_in->{end_hour}, $http_in->{end_min}));
   } # else
   if ($http_in->{Category} eq "NULL"
      and $http_in->{NewCategory} eq "") {
      my_error("You must enter A CATEGORY for your event.$http_in->{NewCategory}");
      $submit->my_exit();
   } # if
   if ($http_in->{NewCategory} ne "") {
      $http_in->{Category} = $http_in->{NewCategory};
   } # if
   if ($http_in->{url} eq ""
      or $http_in->{url} eq "http://") {
      $http_in->{url} = ""
   } # if
} # endsub validate

sub add_form {

   $http_in->{Message} = <<"ADDFORMA";
<!-- BEGIN EVENT FORM -->
<div align="center"><b><font face="$config->{page_title_font}" size="$config->{page_title_font_size}">Submit an Event</font></b></div>
  <form name="menu" method="post" action="$config->{submit_url}">
          <table cellspacing="0" cellpadding="0" border="0" width="400" align="center">
            <tr>
              <td align="left" bgcolor="$config->{event_head_color}" valign="bottom" width="400"> 
                <font face="$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b> 
                &nbsp;&nbsp;&nbsp;YOUR NAME:<br />
                </b></font></td>
            </tr>
            <tr> 
              <td align="left" bgcolor="$config->{event_body_bgcolor}" width="400">&nbsp;&nbsp; 
                <input type="text" maxlength="255" size="45" name="sub_name" value="" />
              </td>
            </tr>
            <tr> 
              <td align="left" bgcolor="$config->{event_head_color}" valign="bottom" width="400"> 
                <font face="$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b> 
                &nbsp;&nbsp;&nbsp;YOUR E-MAIL:<br />
                </b></font></td>
            </tr>            <tr> 
              <td align="left" bgcolor="$config->{event_body_bgcolor}" width="400">&nbsp;&nbsp; 
                <input type="text" maxlength=255 size=45 name="sub_email" value="" />
              </td>
            </tr>
            <tr> 
               <td align="left" valign="bottom" width="400" height="1">&nbsp;</td>
            </tr>
            <tr> 
              <td align="left" bgcolor="$config->{event_head_color}" valign="bottom" width="400"> 
                <font face="$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b> 
                &nbsp;&nbsp;&nbsp;DATE:<br />
                </b></font></td>
            </tr>
                  <tr valign="top"> 
                    <td align="left" bgcolor="$config->{event_body_bgcolor}" width="400">&nbsp;&nbsp;
                      <select name="event_month">
                        <option value="NULL" selected>Month</option>
                        <option value="01">January</option> 
                        <option value="02">February</option> 
                        <option value="03">March</option> 
                        <option value="04">April</option> 
                        <option value="05">May</option> 
                        <option value="06">June</option> 
                        <option value="07">July</option>
                        <option value="08">August</option> 
                        <option value="09">September</option> 
                        <option value="10">October</option> 
                        <option value="11">November</option> 
                        <option value="12">December</option> 
                      </select>
                      <select name="event_day">
                        <option value="NULL" selected>Day 
                        <option value="01">1</option> 
                        <option value="02">2</option> 
                        <option value="03">3</option> 
                        <option value="04">4</option> 
                        <option value="05">5</option> 
                        <option value="06">6</option> 
                        <option value="07">7</option> 
                        <option value="08">8</option> 
                        <option value="09">9</option> 
                        <option value="10">10</option> 
                        <option value="11">11</option> 
                        <option value="12">12</option> 
                        <option value="13">13</option> 
                        <option value="14">14</option> 
                        <option value="15">15</option> 
                        <option value="16">16</option> 
                        <option value="17">17</option> 
                        <option value="18">18</option> 
                        <option value="19">19</option> 
                        <option value="20">20</option> 
                        <option value="21">21</option> 
                        <option value="22">22</option> 
                        <option value="23">23</option> 
                        <option value="24">24</option> 
                        <option value="25">25</option> 
                        <option value="26">26</option> 
                        <option value="27">27</option> 
                        <option value="28">28</option> 
                        <option value="29">29</option> 
                        <option value="30">30</option> 
                        <option value="31">31</option> 
                      </select>
                      <select name="event_year">
                        <option value="NULL" selected>Year 
                        <option value="1999">1999</option> 
                        <option value="2000">2000</option> 
                        <option value="2001">2001</option> 
                        <option value="2002">2002</option> 
                        <option value="2003">2003</option> 
                        <option value="2004">2004</option> 
                        <option value="2005">2005</option> 
                        <option value="2006">2006</option>
                        <option value="2007">2007</option>
                        <option value="2008">2008</option>
                        <option value="2009">2009</option>
                        <option value="2010">2010</option>
                      </select>
                    </td>
                  </tr>
                  <tr valign="top" bgcolor="$config->{event_head_color}"> 
                    <td align="left" width="275"><font face="$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b>&nbsp;&nbsp;&nbsp;START 
                      TIME:</b></font></td>
                  </tr>
                  <tr valign="top"> 
		     <td align="left" bgcolor="$config->{event_body_bgcolor}" width="400">&nbsp;&nbsp;
                      <select name="hour">
                        <option value="NULL" selected>Hr</option>
                        <option value="24">AM 12</option>
                        <option value="01">AM 1</option>
                        <option value="02">AM 2</option>
                        <option value="03">AM 3</option>
                        <option value="04">AM 4</option>
                        <option value="05">AM 5</option>
                        <option value="06">AM 6</option>
                        <option value="07">AM 7</option>
                        <option value="08">AM 8</option>
                        <option value="09">AM 9</option>
                        <option value="10">AM 10</option>
                        <option value="11">AM 11</option>
                        <option value="12">PM 12</option>
                        <option value="13">PM 1</option>
                        <option value="14">PM 2</option>
                        <option value="15">PM 3</option>
                        <option value="16">PM 4</option>
                        <option value="17">PM 5</option>
                        <option value="18">PM 6</option>
                        <option value="19">PM 7</option>
                        <option value="20">PM 8</option>
                        <option value="21">PM 9</option>
                        <option value="22">PM 10</option>
                        <option value="23">PM 11</option>
                      </select>
                      <select name="min">
                        <option value="NULL" selected>Min</option>
                        <option value="00">00</option>
                        <option value="01">01</option>
                        <option value="02">02</option>
                        <option value="03">03</option>
                        <option value="04">04</option>
                        <option value="05">05</option>
                        <option value="06">06</option>
                        <option value="07">07</option>
                        <option value="08">08</option>
                        <option value="09">09</option>
                        <option value="10">10</option>
                        <option value="11">11</option>
                        <option value="12">12</option>
                        <option value="13">13</option>
                        <option value="14">14</option>
                        <option value="15">15</option>
                        <option value="16">16</option>
                        <option value="17">17</option>
                        <option value="18">18</option>
                        <option value="19">19</option>
                        <option value="20">20</option>
                        <option value="21">21</option>
                        <option value="22">22</option>
                        <option value="23">23</option>
                        <option value="24">24</option>
                        <option value="25">25</option>
                        <option value="26">26</option>
                        <option value="28">28</option>
                        <option value="29">29</option>
                        <option value="30">30</option>
                        <option value="31">31</option>
                        <option value="32">32</option>
                        <option value="33">33</option>
                        <option value="34">34</option>
                        <option value="35">35</option>
                        <option value="36">36</option>
                        <option value="37">37</option>
                        <option value="38">38</option>
                        <option value="39">39</option>
                        <option value="40">40</option>
                        <option value="41">41</option>
                        <option value="42">42</option>
                        <option value="43">43</option>
                        <option value="44">44</option>
                        <option value="45">45</option>
                        <option value="46">46</option>
                        <option value="47">47</option>
                        <option value="48">48</option>
                        <option value="49">49</option>
                        <option value="50">50</option>
                        <option value="51">51</option>
                        <option value="52">52</option>
                        <option value="53">53</option>
                        <option value="54">54</option>
                        <option value="55">55</option>
                        <option value="56">56</option>
                        <option value="57">57</option>
                        <option value="58">58</option>
                        <option value="59">59</option>
                      </select>
                      <input type="checkbox" name="TBA" value="TBA" />
                      <b>To be announced.</b> </td>
                  </tr>
                  <tr> 
                    <td align="left" valign="BOTTOM" width="400" height=1>&nbsp;</td>
                  </tr>
                  <tr valign="top"> 
                    <td align="left" width="400" bgcolor="$config->{event_head_color}"><font face="$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b>&nbsp;&nbsp;&nbsp;END TIME (optional):</b></font></td>
                  </tr>
                  <tr valign="top"> 
                    <td align="left" bgcolor="$config->{event_body_bgcolor}" width="400">&nbsp;&nbsp;
                      <select name="end_hour">
                        <option value="NULL" selected>Hr</option>
                        <option value="24">AM 12</option>
                        <option value="01">AM 1</option>
                        <option value="02">AM 2</option>
                        <option value="03">AM 3</option>
                        <option value="04">AM 4</option>
                        <option value="05">AM 5</option>
                        <option value="06">AM 6</option>
                        <option value="07">AM 7</option>
                        <option value="08">AM 8</option>
                        <option value="09">AM 9</option>
                        <option value="10">AM 10</option>
                        <option value="11">AM 11</option>
                        <option value="12">PM 12</option>
                        <option value="13">PM 1</option>
                        <option value="14">PM 2</option>
                        <option value="15">PM 3</option>
                        <option value="16">PM 4</option>
                        <option value="17">PM 5</option>
                        <option value="18">PM 6</option>
                        <option value="19">PM 7</option>
                        <option value="20">PM 8</option>
                        <option value="21">PM 9</option>
                        <option value="22">PM 10</option>
                        <option value="23">PM 11</option>
                      </select>
                      <select name="end_min">
                        <option value="NULL" selected>Min</option>
                        <option value="00">00</option>
                        <option value="01">01</option>
                        <option value="02">02</option>
                        <option value="03">03</option>
                        <option value="04">04</option>
                        <option value="05">05</option>
                        <option value="06">06</option>
                        <option value="07">07</option>
                        <option value="08">08</option>
                        <option value="09">09</option>
                        <option value="10">10</option>
                        <option value="11">11</option>
                        <option value="12">12</option>
                        <option value="13">13</option>
                        <option value="14">14</option>
                        <option value="15">15</option>
                        <option value="16">16</option>
                        <option value="17">17</option>
                        <option value="18">18</option>
                        <option value="19">19</option>
                        <option value="20">20</option>
                        <option value="21">21</option>
                        <option value="22">22</option>
                        <option value="23">23</option>
                        <option value="24">24</option>
                        <option value="25">25</option>
                        <option value="26">26</option>
                        <option value="28">28</option>
                        <option value="29">29</option>
                        <option value="30">30</option>
                        <option value="31">31</option>
                        <option value="32">32</option>
                        <option value="33">33</option>
                        <option value="34">34</option>
                        <option value="35">35</option>
                        <option value="36">36</option>
                        <option value="37">37</option>
                        <option value="38">38</option>
                        <option value="39">39</option>
                        <option value="40">40</option>
                        <option value="41">41</option>
                        <option value="42">42</option>
                        <option value="43">43</option>
                        <option value="44">44</option>
                        <option value="45">45</option>
                        <option value="46">46</option>
                        <option value="47">47</option>
                        <option value="48">48</option>
                        <option value="49">49</option>
                        <option value="50">50</option>
                        <option value="51">51</option>
                        <option value="52">52</option>
                        <option value="53">53</option>
                        <option value="54">54</option>
                        <option value="55">55</option>
                        <option value="56">56</option>
                        <option value="57">57</option>
                        <option value="58">58</option>
                        <option value="59">59</option>
                      </select>
                     </td>
                  </tr>
                  <tr valign="top"> 
                    <td align="left" bgcolor="$config->{event_head_color}" width="400" height=1><font face = "$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b>&nbsp;&nbsp;&nbsp;END 
                      DATE (optional):</b></font></td>
                  </tr>
                  <tr valign="top"> 
                    <td align="left" bgcolor="$config->{event_body_bgcolor}" width="400">&nbsp;&nbsp;
                      <select name="end_month">
                        <option value="NULL" selected>Month</option>
                        <option value="01">January</option>
                        <option value="02">February</option> 
                        <option value="03">March</option> 
                        <option value="04">April</option> 
                        <option value="05">May</option> 
                        <option value="06">June</option>
                        <option value="07">July</option> 
                        <option value="08">August</option> 
                        <option value="09">September</option> 
                        <option value="10">October</option>
                        <option value="11">November</option> 
                        <option value="12">December</option> 
                      </select>
                      <select name="end_day">
                        <option value="NULL" selected>Day</option>
                        <option value="01">1</option> 
                        <option value="02">2</option>
                        <option value="03">3</option>
                        <option value="04">4</option>
                        <option value="05">5</option>
                        <option value="06">6</option>
                        <option value="07">7</option> 
                        <option value="08">8</option> 
                        <option value="09">9</option> 
                        <option value="10">10</option> 
                        <option value="11">11</option> 
                        <option value="12">12</option> 
                        <option value="13">13</option> 
                        <option value="14">14</option>
                        <option value="15">15</option> 
                        <option value="16">16</option>
                        <option value="17">17</option>
                        <option value="18">18</option> 
                        <option value="19">19</option> 
                        <option value="20">20</option> 
                        <option value="21">21</option> 
                        <option value="22">22</option> 
                        <option value="23">23</option> 
                        <option value="24">24</option> 
                        <option value="25">25</option> 
                        <option value="26">26</option> 
                        <option value="27">27</option> 
                        <option value="28">28</option> 
                        <option value="29">29</option> 
                        <option value="30">30</option> 
                        <option value="31">31</option> 
                      </select>
                      <select name="end_year">
                        <option value="NULL" selected>Year</option>
                        <option value="1999">1999</option> 
                        <option value="2000">2000</option> 
                        <option value="2001">2001</option> 
                        <option value="2002">2002</option> 
                        <option value="2003">2003</option> 
                        <option value="2004">2004</option>
                        <option value="2005">2005</option>
                        <option value="2006">2006</option>
                        <option value="2007">2007</option>
                        <option value="2008">2008</option>
                        <option value="2009">2009</option>
                        <option value="2010">2010</option>
                      </select>
                    </td>
                  </tr>
                </table>
    <br />
    <table cellspacing="0" cellpadding="0" border="0" width="400" align="center">
      <tr> 
        <td align="left" bgcolor="$config->{event_head_color}"><font face="$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b> 
          &nbsp;&nbsp;&nbsp;SUBJECT:<br />
          </b></font></td>
      </tr>
            <tr> 
              <td align="left" bgcolor="$config->{event_body_bgcolor}">&nbsp;&nbsp; 
                <input type="text" maxlength="50" size="45" name="subject" value="" />
              </td>
            </tr>
      <tr> 
        <td align="left" bgcolor="$config->{event_head_color}"><font face = "$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b> 
          &nbsp;&nbsp;&nbsp;LOCATION:<br />
          </b></font></td>
      </tr>
            <tr> 
              <td align="left" bgcolor="$config->{event_body_bgcolor}">&nbsp;&nbsp; 
                <input type="left" maxlength="255" size="45" name="location" value="" />
              </td>
            </tr>
            <tr> 
              <td align="left" bgcolor="$config->{event_head_color}" width="400"><font face = "$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b> 
                &nbsp;&nbsp;&nbsp;CATEGORY:<br />
                </b></font></td>
            </tr>
                  <tr> 
                    <td align="left" bgcolor="$config->{event_body_bgcolor}" width="400">&nbsp;&nbsp;
ADDFORMA

   my $query = "SELECT DISTINCT category from $http_in->{Calendar}";
   $db->query($query);
   
   my $categories = {};
   while (my $tmp = $db->result("hashref")) {
      my ($name, $value) = each(%{ $tmp });
      $categories->{$value} = $value;
   } # while
   $db->finish;

   $http_in->{Message} .= qq(\n<font face ="$config->{event_body_font}" size ="2">\n<select name="Category">\n<option value="NULL" SELECTED>Select a Category</option>\n);
   while (my ($name, $value) = each(%{ $categories })) { $http_in->{Message} .= "<option value=\"$value\">$value</option>\n"; }
   # while
   $http_in->{Message} .= "</select>\n</font>\n";

   $http_in->{Message} .= <<"ADDFORMB";
                  </tr>
                  <tr> 
                    <td align="left" bgcolor="$config->{event_body_bgcolor}" width="400"> <font face="$config->{event_body_font}" size="$config->{event_body_font_size}"><b> 
                      &nbsp;&nbsp;&nbsp;New Category: </b></font> 
                      <input type="text" maxlength="50" size="25" name="NewCategory" />
                    </td>
                  </tr>
      <tr align="center" valign="middle"> 
        <td align="left" bgcolor="$config->{event_head_color}" valign="bottom"><font face = "$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b> 
          &nbsp;&nbsp;&nbsp;TEXT:<br />
          </b></font> </td></tr>
      <tr> 
        <td bgcolor="$config->{event_body_bgcolor}" width="400" align="center" valign="middle"> 
          &nbsp;<br />&nbsp;&nbsp; 
          <textarea cols="45" rows="10" wrap="virtual" name="desctext"></textarea>
        </td>
      </tr>
            <tr> 
              <td align="left" bgcolor="$config->{event_head_color}"><font face = "$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b> 
                &nbsp;&nbsp;&nbsp;WEBSITE (optional):<br />
                </b></font></td>
            </tr>
                  <tr> 
                    <td align="left" bgcolor="$config->{event_body_bgcolor}"> &nbsp;&nbsp; 
                      <input type="text" maxlength="255" size="45" name="url" value="http://" />
        </td>
      </tr>
            <tr> 
              <td align="left" bgcolor="$config->{event_head_color}"><font face = "$config->{event_head_font}" color="$config->{event_head_text_color}" size="$config->{event_head_font_size}"><b> 
                &nbsp;&nbsp;&nbsp;E-MAIL CONTACT (optional):<br />
                </b></font></td>
            </tr>
                  <tr> 
                    <td align="left" bgcolor="$config->{event_body_bgcolor}"> &nbsp;&nbsp; 
                      <input type="text" maxlength="255" size="45" name="email" value="" />
        </td>
      </tr>
    </table>
    <br />
    <table cellspacing="0" cellpadding="0" border="0" width="400" align="CENTER" valign="MIDDLE">
      <tr> 
        <td align="center" valign="middle" bgcolor="$config->{event_head_color}">
          <input type="hidden" name="Add" value="Add" />
          <input type="hidden" name="Calendar" value="$http_in->{Calendar}" />
          <input type="hidden" name="DateID" value="$http_in->{DateID}" />
          <input type="image" src="images/save.png" border="0" width="126" height="15" name="Save"/>
        </td>
      </tr>
    </table>
  </form>
  <p>
<!-- END EVENT FORM -->
ADDFORMB
}

sub my_error {
 CyberCalendar::Application::my_error('no', $_[0]);
} # endsub my_error

$submit->my_exit();
