#!/usr/bin/perl
###################################################################
# CyberCalendar v1.8
#
# Calendar RSS Generation Script
# Copyright 1999, 2000, 2001 Shawn Ewald <shawn@wilshire.net>
#
###################################################################
# License:                                                        #
# ----------------------------------------------------------------#
# This program is free software; you can redistribute it and/or   #
# modify it under the terms of the GNU General Public License     #
# as published by the Free Software Foundation; either version 2  #
# of the License, or (at your option) any later version.          #
#                                                                 #
# This program is distributed in the hope that it will be useful, #
# but WITHOUT ANY WARRANTY; without even the implied warranty of  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
###################################################################
# For the full text of the GNU General Public License, go to:     #
# http://www.gnu.org/copyleft/gpl.html                            #
###################################################################
# Script Modules
use vars qw($db $config);
use CyberCalendar::Config;
use CyberCalendar::Database;
use CyberCalendar::Calendar;
use XML::RSS;
use strict;

my $usage = "USAGE: ./calendar2rss.pl calendar numitems /path/to/rss/file/filename.rdf";
my @args = ();
my $cal = CyberCalendar::Calendar->new();
my $today = $CyberCalendar::Calendar::todaysdate;

# check CLI args
if ($ARGV[0] eq '' or $ARGV[1] eq '' or $ARGV[2] eq '') { print "\n$usage\n"; exit(0); }
else {
   @args = ($ARGV[0], $ARGV[1], $ARGV[2]);
   # connect to database
   $db = CyberCalendar::Database->new();
   $db->connect($config->{datasource},
                $config->{db_user},
                $config->{db_password});
   make_rss();
} # else

sub make_rss {
   my $data = {};
   my $i = 0;
   # get table name and descriptive name
   my $query = "SELECT calendar, name, description from calendars WHERE calendar = ?";
   $db->query($query, $args[0]);
   my $tmp = $db->result("hashref");
   $db->finish;
   $data->{name} = $tmp->{name};
   $data->{calendar} = $tmp->{calendar};
   $data->{description} = $tmp->{description};
   # get calendar configuration
   $query = "SELECT * from config where calendar = ?";
   $db->query($query, $args[0]);
   $tmp = $db->result("hashref");
   $db->finish;
   while ( my($name, $value) = each(%{ $tmp }) ) { $config->{$name} = $value; }
   # while
   # get events
   $query = "SELECT * from $args[0] where dateid = ?";
   $db->query($query, "$today->[0]-$today->[1]-$today->[2]");
   my $numrows = $db->rowcount;
   if ($numrows == 0) {
      $data->{item0} = "No events today.";
      $data->{link0} = "$config->{calendar_homepage}$config->{cal_url}?Calendar=$args[0]";
   } # if
   else {
      $i = 0;
      while ($tmp = $db->result("hashref")) {
         my ($y, $m, $d) = split("-", $tmp->{dateid});
         my $dateid = "$m/$d/$y";
         $data->{"item$i"} = $tmp->{subject};
         $data->{"link$i"} = "$config->{calendar_homepage}$config->{cal_url}?Calendar=$args[0]&View=Event&DateID=$dateid&Repeatid=$tmp->{repeatid}";
         $i++;
      } # while
   } # else
   # make rss channel
   my $thisdate = "$today->[1]/$today->[2]/$today->[0]";
   my $rss = XML::RSS->new();
   $rss->channel(title => "Calendar: $data->{name}",
                 link => "$config->{calendar_homepage}?Calendar=$args[0]",
                 description => "Events for $thisdate");
   $i = 0;
   while ($i != $args[1]) {
      $rss->add_item(title => $data->{"item$i"},
                     link => $data->{"link$i"});
      $i++;
   }
   $rss->textinput(title => 'Calendar Search',
                   name => 'searchtext',
                   link => "$config->{calendar_homepage}$config->{cal_url}?Calendar=$args[0]");
   $rss->save($args[2]);
} # endsub make_rss

exit(0);
