#!/usr/bin/perl
###################################################################
# CyberCalendar v1.8.2
#
# Copyright 1999, 2000, 2001 Shawn Ewald <shawn@cyberweavers.com>
###################################################################
#
# CyberCalendar Event Reminder Script
#
###################################################################
# License:                                                        #
#-----------------------------------------------------------------#
# This program is free software; you can redistribute it and/or   #
# modify it under the terms of the GNU General Public License     #
# as published by the Free Software Foundation; either version 2  #
# of the License, or (at your option) any later version.          #
#                                                                 #
# This program is distributed in the hope that it will be useful, #
# but WITHOUT ANY WARRANTY; without even the implied warranty of  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
###################################################################
# For the full text of the GNU General Public License, go to:     #
# http://www.gnu.org/copyleft/gpl.html                            #
###################################################################
# Script Modules
use vars qw($config $db);
use CyberCalendar::Application;
use strict;

###################################################################
# Begin Script

my $run = CyberCalendar::Application->new();

$config = $CyberCalendar::Application::config;
$db = $CyberCalendar::Application::db;
my $todaysdate = $CyberCalendar::Calendar::todaysdate;
my $today = "$todaysdate->[0]\-$todaysdate->[1]\-$todaysdate->[2]";
$CyberCalendar::Application::http_in->{Calendar} = '';
$CyberCalendar::Application::http_in->{DateID} = $today;
$CyberCalendar::Application::http_in->{Repeatid} = '';


my $query = qq(SELECT * from reminders WHERE remindid = ?);
$db->query($query, $today);
my $rows = $db->rowcount;

if ($rows == 0) {
   print "No reminders sent.\n";
   $db->finish;
   CyberCalendar::Application::my_exit();
} # if
else {
   my $i = 1;
   my $rems = {};
   while ( my $rem = $db->result("hashref") ) {
      $rems->{$i} = $rem;
      $i++;
   } # while
   $db->finish;
   do_reminders($rems);
} # else

sub do_reminders {
   while (my($name, $rem) = each(%{ $_[0] })) {
      $CyberCalendar::Application::http_in->{Calendar} = $rem->{calendar};
      my ($y, $m, $d) = split("-", $rem->{dateid});
      $rem->{DateID} = "$m\/$d\/$y";
      CyberCalendar::Application::calendar_config($rem->{calendar});
      my $cal = CyberCalendar::Calendar->new();
      my $util = CyberCalendar::Util->new();
      my $query = "SELECT * from $rem->{calendar}
                   WHERE DateID = ?
                   AND Repeatid = ?";
      $db->query($query, $rem->{dateid}, $rem->{repeatid});
      my $tmp_event = $db->result("hashref");
      $db->finish;
      my $event = $tmp_event;
      if ($config->{attach_vcal} == 1) {
         my %vcevent = %{ $tmp_event };
         $vcevent{dateid} = $cal->vcal_date($vcevent{dateid},
                                            $vcevent{starttime});
         if ($vcevent{enddate} ne '0000-00-00'
            or $vcevent{enddate} != 0) {
            $vcevent{enddate} = $cal->vcal_date($vcevent{enddate},
                                                $vcevent{starttime});
         } # if
         else { $vcevent{enddate} = $vcevent{dateid}; }
         # else
         $vcevent{Calendar} = $rem->{calendar};
         $vcevent{DateID} = $rem->{DateID};
         $vcevent{Repeatid} = $rem->{repeatid};
         $event->{attach_type} = 'text/x-vcalendar';
         $event->{attach_disposition} = 'attachment';
         $event->{attach} = $util->vcal($config, \%vcevent);
         $event->{attach_filename} = 'event.vcs';
      } # if
      $event = CyberCalendar::Application::process_event($event, $cal);      
      $event->{msg} = sendmail_format_message($tmp_event, $rem);
      $event->{to} = $rem->{email};
      $event->{from} = $config->{from_address};
      $event->{subject} = "Reminder: $event->{subject}";
      my $send_method = $config->{smtp_server};
      $send_method = 'sendmail' if $config->{use_sendmail} == 1;
      $util->sendmail($send_method, $event);
   } # while
} # endsub do_reminders

delete_reminders();

sub sendmail_format_message {
   my $msg = '';
   if ($_[1]->{html} eq "yes") {
      $_[0]->{url} = CyberCalendar::Application::fix_event_url($_[0]->{url});
      my $event = CyberCalendar::Application::event_long($_[0], $config);
      $_[0]->{Type} = 'text/html';
      $msg = <<"HTMLMSG";
<html><title>$config->{mail_message_title}: $_[0]->{subject}</title>
<body bgcolor="$config->{body_bg_color}">
<table border=0 width=420 align="left">
<tr><td>
<b>Reminder from Calendar:</b> <a href="$config->{calendar_homepage}$config->{cal_url}?Calendar=$_[1]->{calendar}">$config->{calendar_name}</a><br>
</td></tr>
<tr><td>
<b>____________________________________________<br>

This is the e-mail reminder you requested<BR>
for the following event:<br>
____________________________________________</b><br>
</tr></td>
<tr><td>$event<BR></td></tr>
</table>
</body></html>
HTMLMSG
   } # if
   else {
      $_[0]->{desctext} =~ s/(<br>|<BR>)/\n/g;
      $_[0]->{Type} = 'TEXT';
      $msg = <<"TEXTMSG";
____________________________________________

This is the e-mail reminder you requested
for the following event:
____________________________________________

Event: $_[0]->{subject}
Date: $_[0]->{datetext}
Time: $_[0]->{starttime}
Location: $_[0]->{location}
Category: $_[0]->{category}
Contact: $_[0]->{email}
Website: $_[0]->{url}

$_[0]->{desctext}

____________________________________________
Calendar: $config->{calendar_name} ($config->{calendar_homepage}$config->{cal_url}?Calendar=$_[1]->{calendar})
Event URL: $config->{calendar_homepage}$config->{cal_url}?Calendar=$_[1]->{calendar}&View=Event&DateID=$_[1]->{DateID}&Repeatid=$_[1]->{repeatid}

TEXTMSG
   } # else
   return $msg;
} # endsub sendmail_format_message


sub delete_reminders {
   my $query = "DELETE from reminders
                WHERE remindid = ?";
   $db->query($query, $today);
   $db->finish;
}

exit(0);
